#
# spec file for package telegraf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _config_dir %{_sysconfdir}/%{name}
Name:           telegraf
Version:        1.31.1
Release:        1.1
Summary:        The plugin-driven server agent for collecting & reporting metrics
License:        MIT
Group:          System/Monitoring
URL:            https://github.com/influxdata/telegraf
Source:         %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Patch0:         harden_telegraf.service.patch
BuildRequires:  git-core
BuildRequires:  golang-packaging
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) >= 1.22
%{?systemd_ordering}

%description
Telegraf is an agent written in Go for collecting, processing, aggregating, and writing metrics.

Design goals are to have a minimal memory footprint with a plugin system so that developers in the community can
easily add support for collecting metrics from local or remote services.

%prep
%setup -q
%setup -q -T -D -a 1
%patch -P 0 -p1

%build
# Build the binary.
go build \
   -mod=vendor \
%ifnarch ppc64 ppc64le
   -buildmode=pie \
%endif
   ./cmd/telegraf;
./telegraf config > etc/telegraf.conf

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

mkdir -p %{buildroot}/%{_config_dir}
mkdir -p %{buildroot}/%{_config_dir}/%{name}.d
install -m644 etc/%{name}.conf %{buildroot}/%{_config_dir}

install -D -m 644 scripts/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
sed -i '/User=/d' %{buildroot}%{_unitdir}/%{name}.service
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%doc CHANGELOG.md CONTRIBUTING.md README.md
%license LICENSE
%dir %{_config_dir}
%config(noreplace) %{_config_dir}/%{name}.conf
%{_bindir}/%{name}

%changelog
* Mon Jul  1 2024 mrueckert@suse.de
- Update to version 1.31.1:
  * Telegraf v1.31.1
  * Update changelog for v1.31.1
  * Update build_version.txt for v1.31.1
  * test(linters): Enable `testifylint`: `blank-import`, `float-compare`, `negative-positive`, `nil-compare` and `useless-assert` (#15566)
  * fix(inputs.gnmi): Handle YANG namespaces in paths correctly (#15565)
  * chore(common.starlark): Print nonconvertible data (#15508)
  * fix(inputs.chrony): Handle ServerStats4 response (#15568)
  * chore(deps): Bump github.com/go-ldap/ldap/v3 from 3.4.6 to 3.4.8 (#15557)
  * chore(deps): Bump github.com/nats-io/nats-server/v2 from 2.10.14 to 2.10.16 (#15561)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest/azure/auth from 0.5.12 to 0.5.13 (#15560)
  * chore(deps): Bump github.com/Azure/azure-kusto-go from 0.15.2 to 0.15.3 (#15559)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb from 1.32.9 to 1.33.2 (#15558)
  * fix(inputs.chrony): Support local (reference) sources (#15551)
  * docs(parsers.binary): Fix wording in README (#15554)
  * test(linters): Enable copyloopvar (#15532)
  * fix(secretstores.oauth2): Ensure endpoint params is not nil (#15531)
  * chore: Run make tidy
  * chore(deps): Bump go.step.sm/crypto from 0.44.1 to 0.47.1 (#15525)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatch from 1.37.0 to 1.38.7 (#15526)
  * chore(deps): Bump github.com/prometheus/common from 0.53.0 to 0.54.0 (#15524)
  * chore(deps): Bump github.com/linkedin/goavro/v2 from 2.12.0 to 2.13.0 (#15523)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb from 1.30.2 to 1.32.9 (#15527)
  * fix(inputs.mysql): Handle custom TLS configs correctly (#15493)
  * chore: Update github.com/gorilla/websocket license (#15520)
  * test(lint): Enable badSyncOnceFunc (#15511)
  * test(linters): Enable sloppyLen (#15512)
  * test(lint): Enable mirror (#15510)
  * fix(logging): Add back constants for backward compatibility (#15514)
  * test(inputs.disk): Set label in test to avoid reading local value (#15507)
  * test(incus): Update image list (#15503)
  * fix(inputs.http_response): Fix for IPv4 and IPv6 addresses when interface is set (#15496)
  * fix(agent): Ignore startup-errors in test mode (#15488)
  * chore(outputs.mqtt): Remove dead code (#15487)
  * chore(linters): Fix non-input/output plugin errcheck warnings  (#15472)
  * chore(deps): Bump github.com/Azure/azure-sdk-for-go/sdk/azidentity from 1.5.1 to 1.6.0 (#15489)
  * chore(deps): Bump cloud.google.com/go/monitoring from 1.18.1 to 1.19.0 (#15483)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.9.0 to 1.10.0 (#15482)
  * chore(deps): Bump github.com/prometheus/procfs from 0.15.0 to 0.15.1 (#15481)
  * chore(deps): Bump github.com/microsoft/go-mssqldb from 1.7.0 to 1.7.2 (#15484)
  * chore(deps): Bump github.com/IBM/sarama from 1.43.1 to 1.43.2 (#15480)
  * chore(deps): Bump super-linter/super-linter from 6.5.1 to 6.6.0 (#15479)
  * chore(linters): Bump golangci-lint to v1.59.1 (#15478)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.161.1 to 1.162.1 (#15448)
* Tue Jun 11 2024 mrueckert@suse.de
- Update to version 1.31.0:
  * Telegraf v1.31.0
  * Update changelog for v1.31.0
  * feat(outputs.elasticsearch): Allow settings extra headers for elasticsearch output (#15477)
  * feat(inputs.openstack): Use service catalog from v3 authentication if available (#15460)
  * chore: Update golangci-lint from v1.58.0 to v1.59.0 (#15473)
  * feat(outputs.influxdb_v2): Preserve custom query parameters on write (#15475)
  * chore(deps): Bump github.com/lxc/incus v0.4.0 to v6.2.0 (#15441)
  * chore(deps): Bump go from v1.22.3 to v1.22.4 (#15470)
  * fix(inputs.ecs): Check for nil pointer before use (#15456)
  * docs(inputs.ldap): Document all TLS options (#15464)
  * fix(processors.snmp_lookup): Return empty tag-map on error to avoid panic (#15466)
  * feat(outputs.mqtt): Add client trace logging, resolve MQTT5 reconnect login (#15429)
  * test(inputs.syslog): Add timeout to closed socket test (#15461)
  * chore(circleci): Build Windows package after linux testing (#15462)
  * chore: Print debug message when no messages generated from parse (#15463)
  * chore: Update removal dates to either v1.35.0 or v1.40.0 (#15452)
  * feat(input.azure_monitor): Use default azure credentials chain when no secret provided (#15395)
  * test(outputs.sql): Update wait for log message (#15459)
  * test(inputs.jolokia2_agent): Update integration test results (#15457)
  * feat(inputs.http_listener): Allow setting custom success return code (#15454)
  * feat(inputs.influxdb): Add metrics for build, crypto and commandline (#15438)
  * docs(inputs.swap): Remove linux only comment (#15451)
  * feat(inputs.snmp): Convert octet string with invalid data to hex (#15439)
  * chore(deps): Bump golang.org/x/net from 0.24.0 to 0.25.0 (#15447)
  * chore(deps): Bump modernc.org/sqlite from 1.29.10 to 1.30.0 (#15445)
  * chore(deps): Bump github.com/openzipkin/zipkin-go from 0.4.2 to 0.4.3 (#15444)
  * chore: Fix errcheck CI warnings outside of plugins directory (#15390)
  * feat(processors.printer): Embed Influx serializer options (#15434)
  * chore(deps): Bump github.com/awnumar/memguard from 0.22.4 to 0.22.5 (#15446)
  * chore(windows): Rework Windows service handling (#15372)
  * feat(config): Allow reloading on URL config change (#15388)
  * fix(inputs.cloudwatch): Add accounts when enabled (#15440)
  * feat(inputs.exec): Add option to ignore return code (#15400)
  * feat(agent): Add uint support in cli test output (#15433)
  * feat(inputs.influxdb_v2_listener): Support Secret for token (#15407)
  * fix(inputs.cloudwatch): Ensure account list is larger than index (#15428)
  * docs(outputs.datadog): Specify API v1 support (#15427)
  * feat(cli): List available parsers and serializers (#15426)
  * docs: Fix typos (#15421)
  * fix(agent): Warn on multple agent configuration tables seen (#15402)
  * fix(inputs.postgresql_extensible): Use same timestamp for each gather (#15401)
  * feat(inputs.kafka_consumer): Add resolve canonical bootstrap server option (#15368)
  * chore: Fix typos throughout codebase (#15338)
  * chore(deps): Switch to github.com/leodido/go-syslog (#15393)
  * chore(deps): Bump super-linter/super-linter from 6.5.0 to 6.5.1 (#15408)
  * chore(deps): Update OpenTelemetry dependencies (#15403)
  * chore(deps): Bump modernc.org/sqlite from 1.29.5 to 1.29.10 (#15409)
  * chore(deps): Bump github.com/fatih/color from 1.16.0 to 1.17.0 (#15413)
  * chore(deps): Bump github.com/prometheus/common from 0.52.2 to 0.53.0 (#15412)
  * chore(deps): Bump golang.org/x/crypto from 0.22.0 to 0.23.0 (#15411)
  * chore(deps): Bump github.com/jhump/protoreflect from 1.15.6 to 1.16.0 (#15410)
  * chore(deps): Bump k8s.io/* from 0.29.3 to 0.30.1 (#15383)
  * chore: Update to Xcode 15 in CI (#15389)
  * feat(inputs.gnmi): Add yang-model decoding of JSON IETF payloads (#15201)
  * feat(inputs.execd): Add option to not restart program on error (#15271)
  * test(processors.parser): Sort test metrics (#15391)
  * feat(processors.parser): Add base64 decode for fields (#15328)
  * chore(deps): Bump github.com/snowflakedb/gosnowflake from 1.7.2 to 1.10.0 (#15384)
  * chore(deps): Bump cloud.google.com/go/storage from 1.40.0 to 1.41.0 (#15385)
  * feat(inputs.statsd): Add support for DogStatsD v1.2 (#12991) (#15380)
  * chore(deps): Bump github.com/showwin/speedtest-go from 1.7.6 to 1.7.7 (#15382)
  * chore(deps): Bump super-linter/super-linter from 6.4.1 to 6.5.0 (#15386)
  * chore(deps): Bump github.com/miekg/dns from 1.1.58 to 1.1.59 (#15381)
  * feat(agent): Introduce CLI option to set config URL retry attempts (#15377)
  * chore(agent): Export internal metric fields (#15376)
  * Update changelog for v1.30.3
  * feat(inputs.statsd): Allow counters to report as float (#15371)
  * docs: Update external plugin docs (#15370)
  * docs: Update profiling docs (#15369)
  * docs: Update supported platforms docs (#15365)
  * docs(secretstores): Add docs for creating (#15360)
  * docs: Add URL config behavior spec (#15321)
  * feat(parsers.openmetrics): Add parser for OpenMetrics format (#15298)
  * feat(inputs.influxdb_v2_listener): Add support for rate limiting (#15361)
  * chore(inputs.net): Clarify option deprecation notice (#15364)
  * docs(agent): Specify jitter value must be non-zero (#15363)
  * docs(processors): Clean up (#15359)
  * docs(outputs): Clean up, reorder (#15358)
  * docs(aggregators): Clean up aggregator docs (#15357)
  * docs(inputs): Clean up, add note about external connections (#15356)
  * chore: Update copyright date, remove extra newline (#15366)
  * chore(deps): Bump github.com/showwin/speedtest-go from 1.7.5 to 1.7.6 (#15362)
  * fix(windows): Make sure to log the final error message (#15346)
  * fix(inputs.cloudwatch): Option to produce dense metrics (#15317)
  * feat(common.opcua): Add session timeout as configuration option (#15341)
  * docs: Update docker page (#15345)
  * chore(deps): Bump github.com/nats-io/nats-server/v2 from 2.10.9 to 2.10.14 (#15347)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config from 1.27.9 to 1.27.13 (#15348)
  * chore(deps): Bump github.com/antchfx/xmlquery from 1.3.18 to 1.4.0 (#15349)
  * chore(deps): Bump github.com/vmware/govmomi from 0.37.0 to 0.37.2 (#15351)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.151.1 to 1.161.1 (#15350)
  * docs: Update aggregator and processor docs (#15343)
  * docs(readme): Add links to plugins (#15342)
  * docs: Remove maintainers folder (#15339)
  * chore(log): Restructure and cleanup logging code (#15234)
  * feat(inputs.win_wmi): Allow to invoke methods (#15300)
  * feat(inputs.netflow): Add support for IPFIX option packets (#15314)
  * feat(inputs.file): Add tag with absolute path of file (#15330)
  * docs(inputs.execd): Add python example, clean up doc (#15337)
  * docs(inputs.kubernetes): Add link to generating bearer token to explore API (#15335)
  * fix(inputs.smartctl): Add additional fields (#15332)
  * feat(inputs.internet_speed): Introduce packet loss field (#15329)
  * chore(deps): Bump go from v1.22.2 to v1.22.3 (#15327)
  * feat(aggregators.merge): Allow to round metric timestamps (#15319)
  * docs(outputs.postgresql): Add example to create index for tag columns (#15322)
  * feat(inputs.procstat): Add option to select properties to collect (#15299)
  * feat(inputs.win_eventlog): Add option to define event batch-size (#15306)
  * fix(inputs.netflow): Log unknown fields only once (#15323)
  * chore(inputs.sflow): Deprecate plugin and add migration to netflow (#15320)
  * chore(parsers.grok): Improve non-matching debug message (#15318)
  * docs: Add install guide (#15289)
  * chore(deps): Migrate to maintained gopacket library (#15316)
  * chore(inputs.gnmi): Add more response information for easier debugging (#15297)
  * docs(inputs.mqtt_consumer): Update topic parsing types naming (#15301)
  * chore(deps): Bump golangci-lint from v1.57.2 to v1.58.0 (#15303)
  * docs(inputs.postgresql): Add permissions section (#15302)
  * chore(deps): Bump github.com/grid-x/modbus from v0.0.0-20211113184042-7f2251c342c9 to v0.0.0-20240503115206-582f2ab60a18 (#15276)
  * fix(input.redis): Discard invalid errorstat lines (#15312)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.59.1 to 1.61.0 (#15262)
  * chore(deps): Bump google.golang.org/api from 0.171.0 to 0.177.0 (#15309)
  * chore(deps): Bump github.com/Azure/azure-kusto-go from 0.15.0 to 0.15.2 (#15308)
  * chore(deps): Bump github.com/coocood/freecache from 1.2.3 to 1.2.4 (#15307)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.2.10 to 2.2.11 (#15310)
  * docs: Add releases documentation (#15287)
  * feat(inputs.gnmi): Allow to pass accepted cipher suites (#15256)
  * docs: Revamp readme (#15290)
  * feat(inputs.redis): Add latency percentiles metric (#15293)
  * docs: Update docs readme with all links (#15291)
  * docs: Add quick start (#15288)
  * docs: Split changelog (#15292)
  * feat(inputs.gnmi): Add option to create more descriptive tags (#15278)
  * feat(inputs.nvidia_smi): Add power-limit field for v12 scheme (#15282)
  * chore(deps): Bump github.com/shirou/gopsutil/v3 from v3.24.3 to v3.24.4 (#15272)
  * feat(inputs.ceph): Use perf schema to determine metric type (#15233)
  * feat(inputs.opentelemetry): Add option to set max receive message size (#15231)
  * feat(serializers.influx): Add option to omit timestamp (#15220)
  * fix(inputs.gnmi): Ensure path contains elements to avoid panic (#15259)
  * feat(aggregators.final): Add option to disable appending _final (#15268)
  * fix(inputs.procstat): Do not report dead processes as running for orphan PID files (#15260)
  * fix(outputs.loki): Option to sanitize label names (#15277)
  * chore(deps): Bump github.com/prometheus/procfs from 0.13.0 to 0.14.0 (#15265)
  * docs: Clarify multi-file behavior (#15254)
  * feat(inputs.mock): Add baseline option to sine (#15270)
  * docs(inputs.opcua_listener): Remove invalid inline notation (#15261)
  * chore(deps): Bump github.com/antchfx/xpath from 1.2.5 to 1.3.0 (#15263)
  * chore(deps): Bump github.com/testcontainers/testcontainers-go/modules/kafka from 0.26.1-0.20231116140448-68d5f8983d09 to 0.30.0 (#15264)
  * chore(deps): Bump golang.org/x/sync from 0.6.0 to 0.7.0 (#15266)
  * fix(inputs.http_listener_v2): Wrap timestamp parsing error messages (#15239)
  * feat(outputs.influxdb_v2): Add option to set local address (#15228)
  * feat(outputs.influxdb): Add option to define local address (#15225)
  * chore(deps): Bump github.com/google/cel-go from 0.18.1 to 0.20.1 (#15205)
  * docs(inputs.prometheus): Remove invalid deprecation statement (#15229)
  * fix(outputs.graphite): Handle local address without port correctly (#15224)
  * feat(processors.starlark): Allow persistence of global state (#15170)
  * fix(Makefile): Use go's dependency checker for 'per platform' builds (#15223)
  * fix(http): Stop plugins from leaking file descriptors on telegraf reload (#15213)
  * chore(inputs.amd_rocm_smi): Consolidate startup_retry_behavior to model implementation (#15216)
  * chore(inputs.nvidia_smi): Consolidate startup_retry_behavior to model implementation (#15215)
  * docs(inputs.netflow): Clarify and document 'template not found' warnings (#15214)
  * fix(inputs.sysstat): Prevent default sadc_interval from increasing on reload (#15212)
  * feat(inputs.netflow): Add support for netflow v9 option packets (#15180)
  * feat(inputs.procstat): Report consistent I/O  on Linux (#15186)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.17.9 to 1.17.11 (#15202)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.713 to 1.62.721 (#15203)
  * chore(deps): Bump golang.org/x/mod from 0.16.0 to 0.17.0 (#15206)
  * chore(deps): Bump super-linter/super-linter from 6.3.1 to 6.4.1 (#15207)
  * Update changelog for v1.30.2
  * fix(outputs.sql): Enable the use of krb5 with mssql driver (#15196)
  * fix(inputs.sqlserver): Honor timezone on backup metrics  (#15154)
  * fix(inputs.opcua): Make sure to always create a request (#15178)
  * chore(CI): Add check for PR target branch (#15197)
  * fix(inputs.prometheus): Correctly handle host header (#15195)
  * chore(deps): Bump golang.org/x/net from 0.22.0 to 0.23.0 (#15193)
  * fix(outputs.opensearch): Correctly error during failures or disconnect (#15157)
  * feat(inputs.procstat): Allow multiple selection criteria (#14948)
  * docs(aggregators.final): Swap useful statements (#15159)
  * docs(outputs.kafka): Add metadata options to docs (#15182)
  * feat(inputs): Add framework to retry on startup errors (#15145)
  * fix(inputs.phpfpm): Check error before continue processing (#15176)
  * feat(inputs.gnmi): Add secret store support for username and password (#15173)
  * feat(inputs.gnmi): Add keepalive settings (#15171)
  * feat(inputs.smartctl): Introduce smartctl JSON  input plugin (#15066)
  * fix(inputs.nvidia): Include power limit field for v11 (#15144)
  * fix(inputs.diskio): Update path to in /sys (#15155)
  * docs: Add missing formats (#15166)
  * chore(deps): Bump github.com/vmware/govmomi from 0.33.1 to 0.37.0 (#15160)
  * fix(systemd): Remove 5 second timeout, use default (90) (#15168)
  * feat(inputs.knx_listener): Add support for string data type (#15169)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/timestreamwrite from 1.25.2 to 1.25.5 (#15161)
  * chore(deps): Bump github.com/go-sql-driver/mysql from 1.7.1 to 1.8.1 (#15162)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.708 to 1.62.713 (#15163)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.27.1 to 1.27.4 (#15164)
  * feat(inputs.http_response): Add cookie authentication (#15110)
  * docs(agent): Add README (#15150)
  * fix(inputs.systemd_units): Revert to only gather loaded units by default (#15108)
  * test(circleci): Ensure make docs is always run (#15140)
  * fix(inputs.modbus): Avoid overflow when calculating with uint16 addresses (#15146)
  * docs(processors.clone): Clarify filtering applies to all metrics (#15147)
  * feat(processors.timestamp): Introduce timestamp processor (#15094)
  * chore: Remove executable bit from files (#15143)
  * feat(inputs.sqlserver): Add persistent version store metrics (#15137)
  * docs(inputs.jolokia2_agent): Add example configs for table and all table metrics (#15141)
  * docs(processors.scale): Correct example configuration (#15135)
  * chore(inputs.diskio): Add udev properties only if available (#15122)
  * fix(inputs.systemd_units): Reconnect if connection is lost (#15129)
  * feat(parsers.parquet): Add Apache Parquet Parser (#15008)
  * fix(inputs.win_eventlog): Handle empty query correctly (#15132)
  * chore: Fix typos (#15114)
  * chore(deps): Bump super-linter/super-linter from 6.3.0 to 6.3.1 (#15123)
  * chore(deps): Bump k8s.io/client-go from 0.29.2 to 0.29.3 (#15124)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatch from 1.36.1 to 1.37.0 (#15125)
  * chore(deps): Bump github.com/jackc/pgtype from 1.14.2 to 1.14.3 (#15126)
  * chore(deps): Bump github.com/redis/go-redis/v9 from 9.2.1 to 9.5.1 (#15127)
  * chore(deps): Bump golang.org/x/oauth2 from 0.18.0 to 0.19.0 (#15128)
  * test(inputs.postgresql): Add unit-test for #8586 (#15105)
  * fix(inputs.prometheus): Remove duplicate response_timeout option (#15078)
  * chore: Upgrade Go to 1.22.2 (#15109)
  * chore(inputs.postgresql): Factor out common code and cleanup (#15103)
  * chore(deps): Bump github.com/prometheus/client_golang from 1.18.0 to 1.19.0 (#15100)
  * docs(inputs.x509_cert): Explain expiry field (#15099)
  * chore(deps): Bump github.com/testcontainers/testcontainers-go from 0.27.0 to 0.29.1 (#15085)
  * chore(deps): Bump github.com/apache/iotdb-client-go from 0.12.2-0.20220722111104-cd17da295b46 to 1.2.0-tsbs (#15086)
  * chore(deps): Bump github.com/shirou/gopsutil from v3.23.11 to v3.24.3 (#15082)
  * chore(deps): Bump github.com/gophercloud/gophercloud from 1.9.0 to 1.11.0 (#15084)
  * chore(deps): Bump tj-actions/changed-files from 43 to 44 (#15083)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.563 to 1.62.708 (#15087)
  * fix(agent): Ensure import of required package for pprof support (#15054)
  * Update changelog for v1.30.1
  * chore(linters): Bump golangci-lint to v1.57.2 (#15080)
  * docs(specs): Add specification for configuration migration (#15050)
  * feat(outputs.postgresql): Allow configuration of startup error handling (#15073)
  * docs(outputs.cratedb): Document startup error behavior options (#15072)
  * docs(inputs.win_services): Specify case-insensitive naming (#15077)
  * chore(deps): Bump github.com/IBM/sarama from v1.42.2 to v1.43.1 (#15071)
  * feat(outputs.cratedb): Allow configuration of startup error handling (#15065)
  * feat(inputs.knx_listener): Allow usage of DPT string representation (#15069)
  * fix(inputs.mysql): Parse boolean values in metric v1 correctly (#15063)
  * feat(outputs.postgresql): Add secret store support (#15041)
  * docs(outputs.kafka): Document startup error behavior options (#15070)
  * feat(inputs.lustre2): Skip brw_stats in case of insufficient permissions (#15045)
  * feat(outputs): Add framework to retry on startup errors (#14884)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config from 1.27.5 to 1.27.9 (#15058)
  * chore(deps): Bump go.step.sm/crypto from 0.43.0 to 0.44.1 (#15061)
  * chore(deps): Bump google.golang.org/api from 0.165.0 to 0.171.0 (#15057)
  * chore(deps): Bump github.com/prometheus-community/pro-bing from 0.3.0 to 0.4.0 (#15059)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds from 1.15.2 to 1.16.0 (#15060)
  * chore: tweak wording and don't reference gpg key in SECURITY.md (#15056)
  * feat(inputs.kubernetes): Add option to node metric name (#15049)
  * feat(inputs.lustre2): Add eviction_count field (#15044)
  * test(inputs.syslog): Skip test on Windows (#15048)
  * feat(inputs.lustre2): Add health-check metric (#15042)
  * fix(inputs.phpfpm): Add timeout for fcgi (#15036)
  * fix(windows): Ensure watch-config is passed to service (#15040)
  * docs(specs): Add specification for state-persistence (#15037)
  * feat(aggregators.basicstats): Add "last" field (#15030)
  * docs(config): Clarify metric-routing example (#15033)
  * chore(deps): Bump github.com/docker/docker from 25.0.0+incompatible to 25.0.5+incompatible (#15029)
  * feat(inputs.dns_query): Allow ignoring errors of specific types (#14992)
  * feat(inputs.win_wmi): Add support for remote queries (#14973)
  * fix(inputs.ping): Add option to force ipv4 (#15011)
  * fix(inputs.dns_query): Include the canonical CNAME target (#15025)
  * fix(inputs.nvidia_smi): Add process info metrics (#15023)
  * fix(inputs.prometheus): Initialize logger of parser (#15021)
  * chore(deps): Bump gonum.org/v1/gonum from 0.14.0 to 0.15.0 (#15015)
  * chore(deps): Bump tj-actions/changed-files from 42 to 43 (#15013)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.149.3 to 1.151.1 (#15014)
  * chore(deps): Bump github.com/jackc/pgtype from 1.14.0 to 1.14.2 (#15016)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2 from 1.25.3 to 1.26.0 (#15017)
  * chore(deps): Bump golang.org/x/crypto from 0.20.0 to 0.21.0 (#15018)
  * fix(inputs.knx_listener): Ignore GroupValueRead requests (#15007)
  * chore(readme_linter): Update plugin type guess logic (#15010)
  * fix(inputs.diskio): Add missing udev properties (#15003)
  * fix(inputs.mysql): Use correct column-types for Percona 8 userstats (#15012)
  * chore(deps): Bump github.com/stretchr/testify v1.8.4 to v1.9.0 (#15009)
  * fix(inputs.knx_listener): Reconnect after connection loss (#14959)
  * feat(inputs.lustre2): Add support for bulk read/write stats (#14813)
  * fix(inputs.smart): Improve regexp to support flags with a plus (#14996)
  * feat(inputs.s7comm):  Add optional connection type setting (#15000)
  * feat(inputs.radius): Provide setting to set request IP address (#14981)
  * docs(specs): Add specification for output buffer persistence strategy (#14928)
  * fix(inputs.dns_query): Fill out additional record fields (#14979)
  * fix(secrets): Avoid count underflow by only counting initialized secrets (#14991)
  * docs: Add how to parse guide (#14947)
  * fix(inputs.openstack): Resolve regression in block storage and server info (#14977)
  * fix(inputs.systemd_units): Handle disabled multi-instance units correctly (#14987)
  * chore: Remove govulncheck (#14988)
  * chore(deps): Bump google.golang.org/protobuf from 1.32.0 to 1.33.0 (#14989)
  * feat(parser.prometheusremotewrite): Parse and generate histogram buckets (#14952)
  * feat(parsers.binary): Allow base64-encoded input data (#14961)
  * feat(snmp): Add secret support for auth_password and priv_password (#14975)
  * chore(deps): Bump github.com/jackc/pgx/v4 from 4.18.1 to 4.18.2 (#14978)
  * chore(inputs.win_wmi): Cleanup and refactor code (#14965)
  * fix(outputs.bigquery): Add scope to bigquery and remove timeout context (#14958)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.2.8 to 2.2.10 (#14967)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts from 1.28.2 to 1.28.4 (#14971)
  * chore(deps): Bump github.com/prometheus/procfs from 0.12.0 to 0.13.0 (#14970)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.34.2 to 1.34.3 (#14969)
  * chore(deps): Bump github.com/klauspost/compress from 1.17.6 to 1.17.7 (#14968)
  * feat(inputs.chrony): Remove chronyc depdendency in documentation (#14966)
  * chore: Update govulncheck timeout (#14960)
  * chore(inputs.win_wmi): Cleanup unit-tests (#14955)
  * Update changelog for v1.30.0
  * Update build version to 1.31.0
* Wed May 22 2024 mrueckert@suse.de
- Update to version 1.30.3:
  * Telegraf v1.30.3
  * Update changelog for v1.30.3
  * Update changelog
  * Update build_version.txt for v1.30.3
  * docs: Update external plugin docs (#15370)
  * docs: Update profiling docs (#15369)
  * docs: Update supported platforms docs (#15365)
  * docs(secretstores): Add docs for creating (#15360)
  * docs: Add URL config behavior spec (#15321)
  * chore(inputs.net): Clarify option deprecation notice (#15364)
  * docs(agent): Specify jitter value must be non-zero (#15363)
  * docs(processors): Clean up (#15359)
  * docs(outputs): Clean up, reorder (#15358)
  * docs(aggregators): Clean up aggregator docs (#15357)
  * docs(inputs): Clean up, add note about external connections (#15356)
  * chore: Update copyright date, remove extra newline (#15366)
  * fix(windows): Make sure to log the final error message (#15346)
  * fix(inputs.cloudwatch): Option to produce dense metrics (#15317)
  * docs: Update docker page (#15345)
  * chore(deps): Bump github.com/nats-io/nats-server/v2 from 2.10.9 to 2.10.14 (#15347)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config from 1.27.9 to 1.27.13 (#15348)
  * chore(deps): Bump github.com/antchfx/xmlquery from 1.3.18 to 1.4.0 (#15349)
  * chore(deps): Bump github.com/vmware/govmomi from 0.37.0 to 0.37.2 (#15351)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.151.1 to 1.161.1 (#15350)
  * docs: Update aggregator and processor docs (#15343)
  * docs(readme): Add links to plugins (#15342)
  * docs: Remove maintainers folder (#15339)
  * docs(inputs.execd): Add python example, clean up doc (#15337)
  * docs(inputs.kubernetes): Add link to generating bearer token to explore API (#15335)
  * chore(deps): Bump go from v1.22.2 to v1.22.3 (#15327)
  * docs(outputs.postgresql): Add example to create index for tag columns (#15322)
  * fix(inputs.netflow): Log unknown fields only once (#15323)
  * chore(inputs.sflow): Deprecate plugin and add migration to netflow (#15320)
  * chore(parsers.grok): Improve non-matching debug message (#15318)
  * docs: Add install guide (#15289)
  * chore(deps): Migrate to maintained gopacket library (#15316)
  * chore(inputs.gnmi): Add more response information for easier debugging (#15297)
  * docs(inputs.mqtt_consumer): Update topic parsing types naming (#15301)
  * chore(deps): Bump golangci-lint from v1.57.2 to v1.58.0 (#15303)
  * docs(inputs.postgresql): Add permissions section (#15302)
  * chore(deps): Bump github.com/grid-x/modbus from v0.0.0-20211113184042-7f2251c342c9 to v0.0.0-20240503115206-582f2ab60a18 (#15276)
  * fix(input.redis): Discard invalid errorstat lines (#15312)
  * go mod tidy
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.59.1 to 1.61.0 (#15262)
  * chore(deps): Bump google.golang.org/api from 0.171.0 to 0.177.0 (#15309)
  * chore(deps): Bump github.com/Azure/azure-kusto-go from 0.15.0 to 0.15.2 (#15308)
  * chore(deps): Bump github.com/coocood/freecache from 1.2.3 to 1.2.4 (#15307)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.2.10 to 2.2.11 (#15310)
  * docs: Add releases documentation (#15287)
  * docs: Revamp readme (#15290)
  * docs: Update docs readme with all links (#15291)
  * docs: Add quick start (#15288)
  * docs: Split changelog (#15292)
  * chore(deps): Bump github.com/shirou/gopsutil/v3 from v3.24.3 to v3.24.4 (#15272)
  * fix(inputs.gnmi): Ensure path contains elements to avoid panic (#15259)
  * fix(outputs.loki): Option to sanitize label names (#15277)
  * chore(deps): Bump github.com/prometheus/procfs from 0.13.0 to 0.14.0 (#15265)
  * docs: Clarify multi-file behavior (#15254)
  * docs(inputs.opcua_listener): Remove invalid inline notation (#15261)
  * chore(deps): Bump github.com/antchfx/xpath from 1.2.5 to 1.3.0 (#15263)
  * chore(deps): Bump github.com/testcontainers/testcontainers-go/modules/kafka from 0.26.1-0.20231116140448-68d5f8983d09 to 0.30.0 (#15264)
  * chore(deps): Bump golang.org/x/sync from 0.6.0 to 0.7.0 (#15266)
  * fix(inputs.http_listener_v2): Wrap timestamp parsing error messages (#15239)
  * chore(deps): Bump github.com/google/cel-go from 0.18.1 to 0.20.1 (#15205)
  * docs(inputs.prometheus): Remove invalid deprecation statement (#15229)
  * fix(outputs.graphite): Handle local address without port correctly (#15224)
  * fix(Makefile): Use go's dependency checker for 'per platform' builds (#15223)
  * fix(http): Stop plugins from leaking file descriptors on telegraf reload (#15213)
  * docs(inputs.netflow): Clarify and document 'template not found' warnings (#15214)
  * fix(inputs.sysstat): Prevent default sadc_interval from increasing on reload (#15212)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.17.9 to 1.17.11 (#15202)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.713 to 1.62.721 (#15203)
  * chore(deps): Bump golang.org/x/mod from 0.16.0 to 0.17.0 (#15206)
  * chore(deps): Bump super-linter/super-linter from 6.3.1 to 6.4.1 (#15207)
* Mon Apr 22 2024 mrueckert@suse.de
- Update to version 1.30.2:
  * chore: Run go mod tidy
  * Telegraf v1.30.2
  * Update changelog for v1.30.2
  * Update build_version.txt for v1.30.2
  * fix(outputs.sql): Enable the use of krb5 with mssql driver (#15196)
  * test(inputs.postgresql): Remove error on startup integration test
  * fix(inputs.sqlserver): Honor timezone on backup metrics  (#15154)
  * fix(inputs.opcua): Make sure to always create a request (#15178)
  * chore(CI): Add check for PR target branch (#15197)
  * fix(inputs.prometheus): Correctly handle host header (#15195)
  * chore(deps): Bump golang.org/x/net from 0.22.0 to 0.23.0 (#15193)
  * fix(outputs.opensearch): Correctly error during failures or disconnect (#15157)
  * docs(aggregators.final): Swap useful statements (#15159)
  * docs(outputs.kafka): Add metadata options to docs (#15182)
  * fix(inputs.phpfpm): Check error before continue processing (#15176)
  * fix(inputs.nvidia): Include power limit field for v11 (#15144)
  * fix(inputs.diskio): Update path to in /sys (#15155)
  * docs: Add missing formats (#15166)
  * chore(deps): Bump github.com/vmware/govmomi from 0.33.1 to 0.37.0 (#15160)
  * fix(systemd): Remove 5 second timeout, use default (90) (#15168)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/timestreamwrite from 1.25.2 to 1.25.5 (#15161)
  * chore(deps): Bump github.com/go-sql-driver/mysql from 1.7.1 to 1.8.1 (#15162)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.708 to 1.62.713 (#15163)
  * Add go.sum changes
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.27.1 to 1.27.4 (#15164)
  * docs(agent): Add README (#15150)
  * fix(inputs.systemd_units): Revert to only gather loaded units by default (#15108)
  * test(circleci): Ensure make docs is always run (#15140)
  * fix(inputs.modbus): Avoid overflow when calculating with uint16 addresses (#15146)
  * docs(processors.clone): Clarify filtering applies to all metrics (#15147)
  * chore: Remove executable bit from files (#15143)
  * docs(inputs.jolokia2_agent): Add example configs for table and all table metrics (#15141)
  * docs(processors.scale): Correct example configuration (#15135)
  * chore(inputs.diskio): Add udev properties only if available (#15122)
  * fix(inputs.systemd_units): Reconnect if connection is lost (#15129)
  * fix(inputs.win_eventlog): Handle empty query correctly (#15132)
  * chore: Fix typos (#15114)
  * chore(deps): Bump super-linter/super-linter from 6.3.0 to 6.3.1 (#15123)
  * chore(deps): Bump k8s.io/client-go from 0.29.2 to 0.29.3 (#15124)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatch from 1.36.1 to 1.37.0 (#15125)
  * chore(deps): Bump github.com/jackc/pgtype from 1.14.2 to 1.14.3 (#15126)
  * chore(deps): Bump github.com/redis/go-redis/v9 from 9.2.1 to 9.5.1 (#15127)
  * chore(deps): Bump golang.org/x/oauth2 from 0.18.0 to 0.19.0 (#15128)
  * test(inputs.postgresql): Add unit-test for #8586 (#15105)
  * fix(inputs.prometheus): Remove duplicate response_timeout option (#15078)
  * chore: Upgrade Go to 1.22.2 (#15109)
  * chore(inputs.postgresql): Factor out common code and cleanup (#15103)
  * chore(deps): Bump github.com/prometheus/client_golang from 1.18.0 to 1.19.0 (#15100)
  * docs(inputs.x509_cert): Explain expiry field (#15099)
  * chore(deps): Bump github.com/testcontainers/testcontainers-go from 0.27.0 to 0.29.1 (#15085)
  * chore(deps): Bump github.com/apache/iotdb-client-go from 0.12.2-0.20220722111104-cd17da295b46 to 1.2.0-tsbs (#15086)
  * chore(deps): Bump github.com/shirou/gopsutil from v3.23.11 to v3.24.3 (#15082)
  * chore(deps): Bump github.com/gophercloud/gophercloud from 1.9.0 to 1.11.0 (#15084)
  * chore(deps): Bump tj-actions/changed-files from 43 to 44 (#15083)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.563 to 1.62.708 (#15087)
  * fix(agent): Ensure import of required package for pprof support (#15054)
  * Revert "feat(inputs.gnmi): Add keepalive settings (#15149)"
  * feat(inputs.gnmi): Add keepalive settings (#15149)
* Tue Apr  9 2024 mrueckert@suse.de
- Update to version 1.30.1:
  * Telegraf v1.30.1
  * Update changelog for v1.30.1
  * Add go.sum
  * Update build_version.txt for v1.30.1
  * chore(linters): Bump golangci-lint to v1.57.2 (#15080)
  * docs(specs): Add specification for configuration migration (#15050)
  * docs(outputs.cratedb): Document startup error behavior options (#15072)
  * docs(inputs.win_services): Specify case-insensitive naming (#15077)
  * chore(deps): Bump github.com/IBM/sarama from v1.42.2 to v1.43.1 (#15071)
  * fix(inputs.mysql): Parse boolean values in metric v1 correctly (#15063)
  * docs(outputs.kafka): Document startup error behavior options (#15070)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config from 1.27.5 to 1.27.9 (#15058)
  * chore(deps): Bump go.step.sm/crypto from 0.43.0 to 0.44.1 (#15061)
  * chore(deps): Bump google.golang.org/api from 0.165.0 to 0.171.0 (#15057)
  * chore(deps): Bump github.com/prometheus-community/pro-bing from 0.3.0 to 0.4.0 (#15059)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds from 1.15.2 to 1.16.0 (#15060)
  * chore: tweak wording and don't reference gpg key in SECURITY.md (#15056)
  * test(inputs.syslog): Skip test on Windows (#15048)
  * fix(inputs.phpfpm): Add timeout for fcgi (#15036)
  * fix(windows): Ensure watch-config is passed to service (#15040)
  * docs(specs): Add specification for state-persistence (#15037)
  * docs(config): Clarify metric-routing example (#15033)
  * chore(deps): Bump github.com/docker/docker from 25.0.0+incompatible to 25.0.5+incompatible (#15029)
  * fix(inputs.ping): Add option to force ipv4 (#15011)
  * fix(inputs.dns_query): Include the canonical CNAME target (#15025)
  * fix(inputs.nvidia_smi): Add process info metrics (#15023)
  * fix(inputs.prometheus): Initialize logger of parser (#15021)
  * chore(deps): Bump gonum.org/v1/gonum from 0.14.0 to 0.15.0 (#15015)
  * chore(deps): Bump tj-actions/changed-files from 42 to 43 (#15013)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.149.3 to 1.151.1 (#15014)
  * chore(deps): Bump github.com/jackc/pgtype from 1.14.0 to 1.14.2 (#15016)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2 from 1.25.3 to 1.26.0 (#15017)
  * chore(deps): Bump golang.org/x/crypto from 0.20.0 to 0.21.0 (#15018)
  * fix(inputs.knx_listener): Ignore GroupValueRead requests (#15007)
  * chore(readme_linter): Update plugin type guess logic (#15010)
  * fix(inputs.diskio): Add missing udev properties (#15003)
  * fix(inputs.mysql): Use correct column-types for Percona 8 userstats (#15012)
  * chore(deps): Bump github.com/stretchr/testify v1.8.4 to v1.9.0 (#15009)
  * fix(inputs.knx_listener): Reconnect after connection loss (#14959)
  * fix(inputs.smart): Improve regexp to support flags with a plus (#14996)
  * docs(specs): Add specification for output buffer persistence strategy (#14928)
  * fix(inputs.dns_query): Fill out additional record fields (#14979)
  * fix(secrets): Avoid count underflow by only counting initialized secrets (#14991)
  * docs: Add how to parse guide (#14947)
  * fix(inputs.openstack): Resolve regression in block storage and server info (#14977)
  * fix(inputs.systemd_units): Handle disabled multi-instance units correctly (#14987)
  * chore: Remove govulncheck (#14988)
  * chore(deps): Bump google.golang.org/protobuf from 1.32.0 to 1.33.0 (#14989)
  * chore(deps): Bump github.com/jackc/pgx/v4 from 4.18.1 to 4.18.2 (#14978)
  * chore(inputs.win_wmi): Cleanup and refactor code (#14965)
  * fix(outputs.bigquery): Add scope to bigquery and remove timeout context (#14958)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.2.8 to 2.2.10 (#14967)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts from 1.28.2 to 1.28.4 (#14971)
  * chore(deps): Bump github.com/prometheus/procfs from 0.12.0 to 0.13.0 (#14970)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.34.2 to 1.34.3 (#14969)
  * chore(deps): Bump github.com/klauspost/compress from 1.17.6 to 1.17.7 (#14968)
  * feat(inputs.chrony): Remove chronyc depdendency in documentation (#14966)
  * chore: Update govulncheck timeout (#14960)
  * chore(inputs.win_wmi): Cleanup unit-tests (#14955)
* Mon Mar 11 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.30.0:
  * fix(inputs.gnmi): Add option to guess path tag from subscription (#14951)
  * fix(inputs.gnmi): Handle canonical field-name correctly (#14953)
  * docs(specs): Add specification for startup-error behavior (#14920)
  * fix(inputs.prometheus): List namespaces only when filtering by namespace (#14871)
  * chore(deps): Bump github.com/cloudevents/sdk-go/v2 from 2.15.0 to 2.15.2 (#14949)
  * chore: Update to go1.22.1 (#14940)
  * chore(parsers.xpath): Add tracing mode to output empty-node-selection messages (#14939)
  * chore(deps): Update all github.com/aws/aws-sdk-go-v2 dependencies (#14931)
  * fix(statefile): Ensure valid statefile (#14937)
  * chore(deps): Bump modernc.org/sqlite from 1.28.0 to 1.29.2 (#14930)
  * docs(inputs.upsd): Document pitfalls (#14938)
  * test(processors.snmp_lookup): Fix race in test (#14924)
  * feat(inputs.systemd_units): Allow to query unloaded/disabled units (#14814)
  * chore(deps): Bump github.com/eclipse/paho.golang from 0.20.0 to 0.21.0 (#14929)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb from 1.27.0 to 1.30.2 (#14932)
  * chore(deps): Bump super-linter/super-linter from 6.2.0 to 6.3.0 (#14934)
  * chore(deps): Bump github.com/prometheus/client_model from 0.5.0 to 0.6.0 (#14933)
  * chore(lint): Add gosec G602 - slice out of bounds (#14927)
  * docs(Changelog): Add note about removed deprecated plugin options (#14921)
  * chore(deps): Bump github.com/netsampler/goflow2 from v1.3.6 to v2.1.2 (#14923)
  * fix(inputs.netflow): Fallback to IPFIX mappings for Netflow v9 (#14910)
  * chore(deps): Bump github.com/vapourismo/knx-go from v0.0.0-20240107135439-816b70397a00 to v0.0.0-20240217175130-922a0d50c241 (#14918)
  * docs(specs): Add specification for custom-builder (#14901)
  * docs(spec): Add specification for deprecations (#14896)
  * fix(inputs.postgres*)!: Prevent leaking sensitive data in server tag (#14829)
  * chore(outputs.influxdb)!: Remove deprecated 'url' option (#14916)
  * chore(inputs.nats_consumer)!: Remove deprecated 'metric_buffer' option (#14915)
  * chore(inputs.mqtt_consumer)!: Remove deprecated 'metric_buffer' option (#14914)
  * chore(inputs.disk)!: Remove deprecated 'mountpoints' option (#14913)
  * feat(processors.snmp_lookup): New SNMP lookup processor (#14223)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.58.0 to 1.59.1 (#14894)
  * docs(changelog): Add note about removed deprecated plugins (#14898)
  * chore(deps): Bump github.com/microsoft/go-mssqldb from 1.6.0 to 1.7.0 (#14892)
  * chore(deps): Bump golang.org/x/crypto from 0.19.0 to 0.20.0 (#14891)
  * chore(deps): Bump super-linter/super-linter from 6.1.1 to 6.2.0 (#14897)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.13.1 to 1.14.0 (#14893)
  * chore(deps): Bump github.com/peterbourgon/unixtransport from 0.0.3 to 0.0.4 (#14895)
  * fix(agent): Catch panics in inputs goroutine (#14840)
  * chore(inputs.cassandra)!: Remove deprecated plugin (#14859)
  * chore(inputs.httpjson)!: Remove deprecated plugin (#14860)
  * chore(inputs.io)!: Remove deprecated plugin (#14861)
  * chore(inputs.jolokia)!: Remove deprecated plugin (#14862)
  * chore(inputs.kafka_consumer_legacy)!: Remove deprecated plugin (#14863)
  * chore(inputs.snmp_legacy)!: Remove deprecated plugin (#14864)
  * chore(inputs.tcp_listener)!: Remove deprecated plugin (#14865)
  * chore(inputs.udp_listener)!: Remove deprecated plugin (#14866)
  * chore(inputs.riemann_legacy)!: Remove deprecated plugin (#14867)
  * docs(inputs.syslog): Document change of default read timeout to infinite (#14828)
  * chore(inputs.syslog): Use common/socket implementation (#14837)
  * feat(agent): Add option to skip re-running processors after aggregators (#14882)
  * fix(inputs.docker_log): Use correct name when matching container (#14874)
  * docs: Introduce spec overview and template (#14839)
  * docs(inputs.modbus): Remove extra comma (#14883)
  * fix(processors.override): Correct TOML tag name (#14880)
  * feat(serializers.csv): Allow specifying fixed column order (#14870)
  * test(config): Add unit-test for comments in arrays (#14875)
  * test(inputs.syslog): Add unit-tests for long app-names (#14876)
  * feat(inputs.amd_rocm_smi): Add startup_error_behavior config option (#14872)
  * feat(outputs.nebius_cloud_monitoring): Add 'service' configuration setting (#14658)
  * fix(inputs.phpfpm): Continue despite erroneous sockets (#14852)
  * chore(circleci): Use latest mingw (#14843)
  * chore(snmp): Refactor SNMP translation and data-structures (#14830)
  * chore(inputs.minecraft): Migrate plugin to new maintained version of rcon (#14868)
  * feat(inputs.sqlserver): Add stolen target memory ratio (#14792)
  * chore(deps): Bump github.com/srebhan/cborquery from v0.0.0-20230626165538-38be85b82316 to v1.0.1 (#14857)
  * fix(config): Reword error message about missing config option (#14858)
  * test(inputs.procstat): Resolve flaky test when PID exists (#14856)
  * test(internal): Try multiple timezone abbrevations (#14854)
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Feb 20 2024 Marcus Rueckert <mrueckert@suse.de>
- Bump go dependency to 1.22 to follow upstream
* Tue Feb 20 2024 mrueckert@suse.de
- Update to version 1.29.5:
  * Telegraf v1.29.5
  * Update changelog for v1.29.5
  * Update build_version.txt for v1.29.5
  * test(inputs.procstat): Resolve flaky test when pid actually exists
  * chore: Resolve lint issues
  * test(processors): Fix unit-test for tracking metrics (#14844)
  * chore(deps): Bump google.golang.org/api from 0.162.0 to 0.165.0 (#14849)
  * chore(deps): Bump github.com/gophercloud/gophercloud from 1.7.0 to 1.9.0 (#14848)
  * chore(deps): Bump google.golang.org/grpc from 1.61.0 to 1.61.1 (#14847)
  * chore(deps): Bump k8s.io/client-go from 0.29.1 to 0.29.2 (#14846)
  * chore(deps): Bump super-linter/super-linter from 6.0.0 to 6.1.1 (#14850)
  * chore(deps): Bump github.com/DATA-DOG/go-sqlmock from 1.5.0 to 1.5.2 (#14845)
  * fix(inputs.gnmi): Normalize path for inline origin handling (#14838)
  * fix(processors.unpivot): Handle tracking metrics correctly (#14832)
  * test(processors.strings): Add unit test for tracking metrics (#14831)
  * test(processors.reverse_dns): Add unit-tests for tracking metrics (#14822)
  * test(processors.split): Add unit-tests for tracking metrics (#14821)
  * test(processors.topk): Add unit-test for tracking metrics (#14810)
  * chore(deps): Bump github.com/IBM/sarama from 1.42.1 to 1.42.2 (#14820)
  * chore(deps): Bump cloud.google.com/go/storage from 1.36.0 to 1.38.0 (#14819)
  * chore(deps): Bump go.opentelemetry.io/collector/pdata (#14818)
  * chore(deps): Bump github.com/miekg/dns from 1.1.57 to 1.1.58 (#14817)
  * chore(deps): Bump github.com/jhump/protoreflect from 1.15.4 to 1.15.6 (#14816)
  * chore: Update dependabot labels (#14807)
  * test(processors.tag_limit): Add unit-tests for tracking metrics (#14812)
  * test(processors.rename): Add unit-tests for tracking metrics (#14811)
  * test(processors.s2geo): Add unit-test for tracking metrics (#14809)
  * test(processors.scale): Add unit-test for tracking metrics (#14808)
  * chore(deps): Bump github.com/google/uuid from 1.5.0 to 1.6.0 (#14775)
  * chore(deps): Bump github.com/eclipse/paho.golang from 0.11.0 to 0.20.0 (#14769)
  * test(processors.port_name): Add unit-test for tracking metrics (#14790)
  * test(processors.aws_ec2): Add unit-test for tracking metrics (#14788)
  * test(processors.pivot): Add unit-test for tracking metrics (#14789)
  * test(processors.printer): Add unit-test for tracking metrics (#14791)
  * test(inputs.syslog): Migrate unit-tests to test-cases (#14784)
  * test(processors.noise): Add unit-test for tracking metrics (#14779)
  * test(processors.ifname): Add unit-test for tracking metrics (#14778)
  * test(processors.filepath): Add unit-test for tracking metrics (#14776)
  * test(processors.override): Add unit-test for tracking metrics (#14781)
  * chore(processors.aws_ec2): Rename processor to adhere to the standard directory structure (#14780)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.33.0 to 1.36.1 (#14772)
  * chore(deps): Bump github.com/klauspost/compress from 1.17.4 to 1.17.6 (#14773)
  * chore(deps): Bump github.com/awnumar/memguard (#14774)
  * chore(deps): Bump tj-actions/changed-files from 41 to 42 (#14771)
  * chore(linters): Bump golangci-lint to v1.56.1 (#14759)
  * ci: Check for updates to GitHub actions (#14761)
  * chore(deps): Bump github.com/urfave/cli/v2 from 2.25.7 to 2.27.1 (#14765)
  * chore(deps): Bump github.com/showwin/speedtest-go from 1.6.7 to 1.6.10 (#14766)
  * chore(deps): Bump k8s.io/client-go from 0.29.0 to 0.29.1 (#14767)
  * chore(deps): Bump golang.org/x/oauth2 from 0.16.0 to 0.17.0 (#14768)
  * fix(processors.execd): Accept tracking metrics instead of dropping them (#14770)
  * chore(common.tls): Replace unmaintained github.com/youmark/pkcs8 with go.step.sm/crypto/pemutil (#14760)
  * docs: Fix broken link (#14762)
  * fix(outputs.mqtt): Retry metrics for server timeout (#14752)
  * chore: Fix readme linter not using correct Go version (#14758)
  * chore(deps): Get rid of golang.org/x/exp and use stable versions instead (#14757)
  * chore(inputs.csgo): Migrate plugin to new maintained version of rcon (#14756)
  * chore(deps): Bump github.com/gwos/tcg/sdk from v0.0.0-20220621192633-df0eac0a1a4c to v8.7.2 (#14755)
  * chore: Install go on nightly package testing (#14754)
  * chore(linters): Bump golangci-lint to v1.56.0 (#14742)
  * chore(deps): Use github.com/coreos/go-systemd/v22 instead of git version (#14753)
  * test(processors.filter): Add unit-test for tracking metrics (#14747)
  * test(processors.defaults): Add unit-test for tracking metrics (#14746)
  * test(processors.dedup): Add unit-test for tracking metrics (#14745)
  * chore(processors.converter): Cleanup code (#14744)
  * fix(inputs.postgresql_extensible): Add support for bool tags (#14707)
  * chore(deps): Bump github.com/gopcua/opcua from 0.4.0 to 0.5.3 (#14686)
  * chore: Update to go1.22.0 (#14697)
  * test(processors.enum): Add unit-test for tracking metrics (#14736)
  * test(processors.regex): Add unit-test for tracking metrics (#14739)
  * test(processors.converter): Add unit-test for tracking metrics (#14740)
  * test(processors.date): Add unit-test for tracking metrics (#14738)
  * test(processors.clone): Add unit-test for tracking metrics (#14737)
  * chore(linters): replace 'fmt.Sprintf' with string addition (#14699)
  * chore(secrets): Warn if settings look like secrets but use invalid characters (#14706)
  * chore(linters): Replace 'fmt.Errorf' with 'errors.New' wherever possible (#14698)
  * chore: fix timezone test case failure on macOS (#14693)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.57.1 to 1.58.0 (#14690)
  * fix(inputs.filecount): Respect symlink files with FollowSymLinks (#14669)
  * fix(inputs.kafka_consumer): Correctly setting name to msg_headers_as_tags (#14679)
  * chore(deps): Bump github.com/cloudevents/sdk-go/v2 from 2.14.0 to 2.15.0 (#14687)
  * chore(deps): Bump github.com/Azure/azure-event-hubs-go/v3 from 3.6.1 to 3.6.2 (#14688)
  * chore(deps): Bump k8s.io/apimachinery from 0.29.0 to 0.29.1 (#14689)
  * fix(inputs.snmp_trap): Enable SHA ciphers (#14665)
  * chore: Remove tumbleweed from nightly (#14667)
  * fix(inputs.vsphere): Use guest.guestId value if set for guest name (#14635)
  * fix(inputs.redfish): Resolve iLO4 fan data (#14659)
  * fix(rpm): Ensure telegraf is installed after useradd (#14654)
* Wed Jan 31 2024 mrueckert@suse.de
- Update to version 1.29.4:
  * Telegraf v1.29.4
  * Update changelog for v1.29.4
  * Update build_version.txt for v1.29.4
  * chore(deps): Bump all AWS deps (#14651)
  * chore(inputs.temp): Convert warning on missing sensors to debug message (#14656)
  * fix(processors.parser): Drop original tracking metrics (#14655)
  * fix(inputs.temp): Fix regression in metric formats (#14649)
  * chore: Disable firewall during nightly package tests (#14652)
  * chore(linters): Speed up golangci-lint runs for non-Linux OSes (#14639)
  * fix(inputs.snmp_trap): Handle octet strings (#14619)
  * chore(deps): Bump github.com/yuin/goldmark from 1.5.6 to 1.6.0 (#14640)
  * chore(deps): Bump github.com/gosnmp/gosnmp from 1.36.1 to 1.37.0 (#14641)
  * chore(deps): Bump github.com/compose-spec/compose-go from 1.20.0 to 1.20.2 (#14642)
  * chore(deps): Bump github.com/microsoft/go-mssqldb from 1.5.0 to 1.6.0 (#14643)
  * chore(deps): Bump github.com/nats-io/nats-server/v2 from 2.10.6 to 2.10.9 (#14644)
* Tue Jan 30 2024 mrueckert@suse.de
- Update to version 1.29.3:
  * Telegraf v1.29.3
  * Update changelog for v1.29.3
  * Update build_version.txt for v1.29.3
  * docs: Resolve table column count lint issues (#14637)
  * chore: Disable IPv6 on incus nightly (#14638)
  * docs: Add notes about TOML (#14624)
  * fix(common.encoding): Remove locally-defined errors and use upstream ones (#14627)
  * fix(inputs.gnmi): Refactor alias handling (#14553)
  * chore: Drop windows lint gogc value to 1 (#14626)
  * docs(inputs.snmp): Clarify the deprecation of agent tag setting (#14622)
  * docs(config): Add comment about single vs double quotes (#14621)
  * docs(inputs.mysql): Add section on how to convert string to numeric (#14620)
  * chore: Make directory before saving key (#14623)
  * chore(internal): Handle ranges in type-conversion and add missing types (#14618)
  * chore(deps): Bump github.com/testcontainers/testcontainers-go from 0.26.0 to 0.27.0 (#14608)
  * chore(deps): Bump github.com/docker/docker from 24.0.7+incompatible to 25.0.0+incompatible (#14607)
  * chore: Update incus nightly image (#14615)
  * fix(outputs.iotdb): Handle paths that contain illegal characters (#14519)
  * chore(internal.snmp): Rephrase error message on translating OID (#14612)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.31.0 to 1.32.0 (#14611)
  * chore(deps): Bump modernc.org/sqlite from 1.24.0 to 1.28.0 (#14610)
  * chore(deps): Bump github.com/fatih/color from 1.15.0 to 1.16.0 (#14609)
  * fix(outputs.loki): Do not close body before reading it (#14604)
  * chore: Use 20.04 over 22.04 due to networking issues (#14605)
  * chore(inputs.opcua): Add option to collect client debug logging (#14595)
  * chore: Update incus group/signing path (#14600)
  * docs(inputs.redis): Add more examples for TLS (#14599)
  * fix(outputs.mqtt): Preserve leading slash in topic (#14582)
  * fix(inputs.temp): Recover pre-v1.22.4 temperature sensor readings (#14575)
  * chore: Correct Windows signing artifact dir (#14594)
  * chore: Update incus group and mark script executable (#14593)
  * chore: Drop gogc further for Windows lint to 10 (#14592)
  * chore: Update github.com/gorilla/websocket license (#14591)
  * chore(circleci): Update gogc values to reduce memory pressure (#14589)
  * chore: Switch from lxd to incus (#14495)
  * chore: Attach workspace in current directoy, avoid non-existing dir (#14587)
  * chore(deps): Bump github.com/gorilla/mux from 1.8.0 to 1.8.1 (#14546)
  * fix(inputs.win_perf_counters): Ignore PdhCstatusNoInstance as well (#14570)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts from 1.26.5 to 1.26.7 (#14576)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.29.5 to 1.31.0 (#14578)
  * chore(deps): Bump github.com/clarify/clarify-go from 0.2.4 to 0.3.1 (#14577)
  * chore(deps): Bump go.opentelemetry.io/collector/pdata from 1.0.0-rcv0016 to 1.0.1 (#14574)
  * chore(deps): bump github.com/github.com/vapourismo/knx-go from v0.0.0-20220829185957-fb5458a5389d to 20240107135439-816b70397a00 (#14573)
  * chore(deps): Bump github.com/intel/powertelemetry from 1.0.0 to 1.0.1 (#14562)
  * chore: Update Windows signing process (#14565)
  * chore: Update to go1.21.6 (#14559)
  * chore(deps): Bump github.com/docker/go-connections from 0.4.0 to 0.5.0 (#14545)
  * chore(deps): Bump github.com/prometheus/common from 0.44.0 to 0.45.0 (#14544)
  * chore(deps): Bump k8s.io/client-go from 0.28.3 to 0.29.0 (#14543)
  * chore(deps): Bump go.starlark.net from go.starlark.net v0.0.0-20220328144851-d1966c6b9fcd to v0.0.0-20231121155337-90ade8b19d09 (#14541)
  * fix(inputs.win_perf_counters): Check errors post-collection for skip (#14526)
  * test(inputs.http_listener_v2): Skip test on Windows due to hang (#14572)
  * docs(outputs.opensearch): Correct sample config format (#14538)
  * chore(inputs.cisco_telemetry_mdt): Actually fix lint issue (#14554)
  * chore(inputs.cisco_telemetry_mdt): Resolve linter with error check (#14552)
  * test(inputs.influxdb_v2_listener): Skip on Windows after hang (#14551)
* Tue Jan  9 2024 Marcus Rueckert <mrueckert@suse.de>
- refresh harden_telegraf.service.patch to apply cleanly again
* Tue Jan  9 2024 mrueckert@suse.de
- Update to version 1.29.2:
  * Telegraf v1.29.2
  * Update changelog for v1.29.2
  * Update build_version.txt for v1.29.2
  * docs(readme): Update minimum system requirements (#14536)
  * docs(inputs.directory_monitor): Correct regex for files_to_monitor config option (#14532)
  * docs: Fix typos (#14376)
  * fix(inputs.upsd): Add additional fields to upsd from NUT (#14447)
  * fix(processors.starlark): Use tracking ID to identify tracking metrics (#14523)
  * fix(inputs.phpfpm): Add pid field to differentiate metrics (#14462)
  * fix(common.kafka): Correctly set gssapi username/password (#14522)
  * chore(deps): bump collectd.org from v0.5.0 to v0.6.0 (#14525)
  * fix(outputs.prometheus_client): Always default to TCP (#14471)
  * fix(systemd): Allow notify access from all (#14517)
  * chore(linters): Enable `appendCombine` checker for gocritic (#14451)
  * test: Switch DNS server to avoid misbehaving test (#14520)
  * fix(inputs.phpfpm): Use logger without causing panic (#14489)
  * chore(deps): Bump google.golang.org/protobuf from 1.31.1-0.20231027082548-f4a6c1f6e5c1 to 1.32.0 (#14505)
  * chore(deps): Bump github.com/prometheus/prometheus from 0.48.0 to 0.48.1 (#14503)
  * chore(deps): Bump github.com/Azure/azure-kusto-go from 0.13.1 to 0.15.0 (#14506)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.2.7 to 2.2.8 (#14504)
  * chore(deps): Bump github.com/sijms/go-ora/v2 from 2.7.18 to 2.8.4 (#14515)
  * docs(inputs.opcua_listener): Fix nodes example (#14508)
  * chore: Bump GitHub workflow options to latest versions (#14513)
  * chore(deps): Bump github.com/dvsekhvalnov/jose2go from v1.5.0 to v1.5.1-0.20231206184617-48ba0b76bc88 (#14496)
  * fix(inputs.procstat): Correctly set tags on procstat_lookup (#14493)
  * fix(inputs.vsphere): Resolve occasional serverFault (#14463)
  * chore(linters): Enable more checkers for gocritic (#14449)
  * chore: Remove all CircleCI caching (#14494)
  * chore(deps): Bump github.com/containerd/containerd from 1.7.7 to 1.7.11 (#14483)
  * test: Revert caching changes, drop linting on windows/macos (#14465)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.12.1 to 1.13.1 (#14475)
  * chore(deps): Bump github.com/djherbis/times from 1.5.0 to 1.6.0 (#14476)
  * chore(deps): Bump github.com/jhump/protoreflect from 1.15.3 to 1.15.4 (#14477)
  * chore(deps): Bump github.com/google/uuid from 1.4.0 to 1.5.0 (#14478)
  * chore(deps): Bump golang.org/x/net from 0.17.0 to 0.19.0 (#14479)
  * chore(deps): Bump golang.org/x/crypto from 0.16.0 to 0.17.0 (#14480)
  * fix(outputs.influxdb*): Support setting Host header (#14481)
  * chore: Update pull request template (#14470)
  * fix(outputs.bigquery): Ignore fields containing NaN or infinity (#14458)
  * chore(linters): Enable rangeValCopy and hugeParams checkers for gocritic (#14454)
  * chore(linters): Enable `preferDecodeRune` and `preferFprint` checkers for gocritic (#14453)
  * chore(linters): Enable equalFold, preferStringWriter, and stringXbytes checkers for gocritic. (#14452)
  * test(inputs.dpdk): Cleanup directories after unit tests (#14457)
  * fix(processors.filter): Rename processors.Filter -> processors.filter (#14460)
* Wed Dec 13 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.29.1:
  * Telegraf v1.29.1
  * Update changelog for v1.29.1
  * Update build_version.txt for v1.29.1
  * fix(inputs.clickhouse): Omit zookeeper metrics on clickhouse cloud (#14443)
  * docs(inputs.memcached): Correct typo in README.md (#14448)
  * fix(inputs.php-fpm): Parse JSON output (#14430)
  * docs(inputs.ldap): Correct plugin name in sample config (#14446)
  * chore(deps): Update all github.com/aws/aws-sdk-go-v2 dependencies (#14441)
  * fix(inputs.procstat): Revert unintended renaming of 'systemd_unit' option (#14440)
  * chore(deps): Bump github.com/go-ldap/ldap/v3 from 3.4.5 to 3.4.6 (#14435)
  * chore(deps): Bump github.com/klauspost/compress from 1.17.3 to 1.17.4 (#14433)
  * chore(deps): Bump github.com/openzipkin/zipkin-go from 0.4.1 to 0.4.2 (#14432)
  * chore(deps): Bump github.com/tidwall/gjson from 1.14.4 to 1.17.0 (#14431)
* Mon Dec 11 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.29.0:
  * Telegraf v1.29.0
  * Update changelog for v1.29.0
  * fix(outputs.bigquery): Correct use of auto-detected project ID (#14416)
  * docs(Changelog): Fix reference to python-syntax removal #14427 (#14429)
  * fix(inputs.intel_powerstat): Unit tests should work on every CPU/platform (#14420)
  * fix(license): Correct spelling of jmhodges/clock license (#14419)
  * feat(common.opcua): Add option to include OPC-UA DataType as a Field (#14345)
  * feat(migrations): Add migration for fieldpass/fielddrop (#14401)
  * feat(inputs.intel_powerstat): Extract business logic to external library (#14363)
  * fix(processors.starlark): Avoid negative refcounts for tracking metrics (#14395)
  * chore(linters): Remove blank identifiers and errors which are not needed to handle (#14399)
  * docs(outputs.dynatrace) Update links to documentation (#14400)
  * feat(outputs.stackdriver): Enable histogram support (#14275)
  * fix(inputs.s7comm): Reconnect if query fails (#14394)
  * chore: Add .uuid to gitignore (#14393)
  * fix(inputs.modbus): Split large request correctly at field borders (#14388)
  * chore: Update go1.21.5 (#14391)
  * chore(inputs.rabbitmq): Remove useless comment (#14389)
  * chore(inputs.statsd): Do not deprecate convert_names as there is no replacement (#14390)
  * chore(deps): Bump github.com/influxdata/tail from 1.0.1-0.20210707231403-b283181d1fa7 to 1.0.1-0.20221130111531-19b97bffd978 (#14384)
  * chore(deps): Bump github.com/golang-jwt/jwt/v5 from 5.0.0 to 5.2.0 (#14382)
  * chore(deps): Bump github.com/IBM/sarama from 1.41.3 to 1.42.1 (#14385)
  * chore(deps): Bump github.com/nats-io/nats-server/v2 from 2.9.23 to 2.10.6 (#14386)
  * chore(deps): Bump github.com/jackc/pgconn from 1.14.0 to 1.14.1 (#14383)
  * test: Update lxc images (#14380)
  * feat(inputs.nats_consumer): Add nkey-seed-file authentication (#14375)
  * feat(inputs.dpdk): Add options to customize error-behavior and metric layout (#14308)
  * feat(secrets): Add unprotected secret implementation (#13998)
  * feat(config): Deprecate `fieldpass` and `fielddrop` modifiers (#14012)
  * fix(inputs.netflow): Handle malformed inputs gracefully (#14373)
  * feat(outputs.bigquery): Allow to add metrics in one compact table (#14342)
  * docs(inputs.fireboard): Revert typo fix as the typo is returned in the actual code too (#14379)
  * chore(inputs.procstat): Convert bool tagging settings to a list (#14333)
  * feat(agent): Allow separators for namepass and namedrop filters (#14361)
  * fix(inputs.tail): Retry opening file after permission denied (#14357)
  * fix(parsers.json_v2): Reset state before parsing (#14344)
  * test(inputs.vault): Remove metric comparison in integration test (#14369)
  * docs(inputs.mqtt_consumer): Clarify persistent session and topic refresh (#14366)
  * fix(outputs.prometheus_client): Ensure v1 collector data expires promptly (#14232)
  * docs: Fix typos (#14359)
  * chore(inputs.procstat): Use plural for supervisor_units option (#14329)
  * docs(parsers.json_v2): Add links to testdata folder (#14358)
  * docs: Update PR checklist, make clear AI generated code not accepted (#14362)
  * fix(parsers.json v2): Correct wrong name of config option (#14351)
  * chore(deps): Bump github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/resources/armresources from 1.1.1 to 1.2.0 (#14355)
  * chore(deps): Bump github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/monitor/armmonitor (#14354)
  * chore(deps): Bump golang.org/x/text from 0.13.0 to 0.14.0 (#14353)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.56.0 to 1.57.1 (#14352)
  * feat(secretstores): Add systemd-credentials plugin (#13657)
  * chore(inputs.procstat): Cleanup code (#14326)
  * feat(processors.filter): Convert noop processor to filter processor (#14330)
  * fix(inputs.http): Use correct token variable (#14350)
  * chore(deps): Point kafka dependency to IBM organization (#14349)
  * chore(deps): Bump github.com/prometheus/prometheus from 0.46.0 to 0.48.0 (#14321)
  * fix(outputs.opensearch): Expose TLS setting correctly (#14340)
  * feat(migrations): Add option migration for outputs.influxdb (#14341)
  * docs(inputs.kafka_consumer): Remove whitespace (#14348)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.26.0 to 1.27.2 (#14324)
  * docs: Fix typos (#14339)
  * fix(common.oauth): Initialize 'EndpointParams' to avoid panic with 'audience' settings (#14331)
  * test(inputs.netstat): Move tests from inputs.net (#14328)
  * feat(inputs.kafka_consumer): Add option to set metric name from message header (#14320)
  * chore(deps): Bump github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/monitor/armmonitor from 0.10.1 to 0.10.2 (#14323)
  * chore(deps): Bump k8s.io/api from 0.28.3 to 0.28.4 (#14322)
  * chore(deps): Bump github.com/vmware/govmomi from 0.32.0 to 0.33.1 (#14325)
  * test(kafka): Use dynamic ports with integration tests (#14301)
  * chore(parsers.influx): Add benchmark (#14315)
  * chore(parsers.xpath): Add benchmark for CBOR format (#14314)
  * chore(parsers.xpath): Add benchmark for msgpack format (#14313)
  * chore(parsers.xpath): Add benchmark for protocol-buffer format (#14312)
  * test(inputs.vault): Wait for minimum number of metrics (#14302)
  * chore(parsers.avro): Add benchmark for binary format (#14311)
  * chore(parsers.binary): Add benchmark (#14310)
  * chore: Add benchmark tests for XML and JSON xpath (#14304)
  * feat(inputs.sql): Add support for IBM Netezza (#14200)
  * chore(parsers): Add benchmarks for avro, collectd, prometheus remote write (#14303)
  * chore: Enable bad regex gocritic linter (#14295)
  * fix(processors.starlark): Maintain tracking information post-apply (#14137)
  * Update changelog for v1.28.5
  * feat(processors.noop): Noop processor (#14297)
  * fix(parsers.json_v2): Log inner errors (#14296)
  * fix(inputs.ecs): Correct v4 metadata URLs (#14294)
  * fix(inputs.intel_rdt): Do not fail on missing PIDs (#14274)
  * chore: Fix lint in changelog (#14298)
  * feat(inputs.procstat): Obtain process information through supervisor (#13417)
  * feat: Use HTTPClientConfig struct in elastic stack plugins (#14207)
  * fix(inputs.s7comm): Truncate strings to reported length (#14283)
  * chore(deps): Bump github.com/Masterminds/semver/v3 from 3.2.0 to 3.2.1 (#14286)
  * chore(deps): Bump github.com/gosnmp/gosnmp from 1.35.1-0.20230602062452-f30602b8dad6 to 1.36.1 (#14287)
  * chore(deps): Bump google.golang.org/api from 0.149.0 to 0.150.0 (#14288)
  * chore(deps): Bump golang.org/x/mod from 0.13.0 to 0.14.0 (#14289)
  * chore(deps): Bump golang.org/x/sync from 0.4.0 to 0.5.0 (#14285)
  * Update changelog for v1.28.4
  * test(parsers): Sort metrics to avoid flaky tests (#14284)
  * fix(inputs.zfs): Support gathering metrics on zfs 2.2.0 and later (#14280)
  * fix(inputs.s7comm): Fix bit queries (#14068)
  * feat(inputs.snmp): Hint to use source tag (#14111)
  * chore(parsers): Add additional parser benchmarks (#14276)
  * chore: Add metric and batch benchmark to serializers (#14277)
  * fix(inputs.disk): Add inodes_used_percent field (#14267)
  * chore(parsers.csv): Add benchmark test (#14257)
  * docs(inputs.intel_powerstat): Add notes about hw/sw dependencies (#14263)
  * fix(inputs.ipset): Parse lines with timeout (#14262)
  * chore(deps): Bump github.com/showwin/speedtest-go from 1.6.6 to 1.6.7 (#14250)
  * chore: Update to go1.21.4 (#14268)
  * docs(inputs.powerdns): Document additonal permissions (#14256)
  * docs(inputs.temp): Add additional troubleshooting steps (#14255)
  * fix(inputs.win_perf_counter): Do not rely on returned buffer size (#14241)
  * feat(inputs.modbus): Add support for string-fields (#14145)
  * chore(deps): Bump cloud.google.com/go/storage from 1.30.1 to 1.34.1 (#14253)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.8.1 to 1.9.0 (#14252)
  * chore(deps): Bump github.com/hashicorp/consul/api from 1.25.1 to 1.26.1 (#14251)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.23.5 to 1.26.0 (#14249)
  * fix(config): Fix comment removal in TOML files (#14240)
  * feat(outputs.prometheus_client): Support listen on vsock (#14108)
  * fix(inputs.mqtt_consumer): Resolve could not mark message delivered (#14243)
  * chore(linters): Fix findings found by testifylint for Windows and enable it. (#14238)
  * feat(migrations): Add option migration for inputs.nats_consumer (#14234)
  * feat(migrations): Add option migration for inputs.mqtt_consumer (#14233)
  * test(inputs.jolokia2_agent): Sort metrics as order is not consistent (#14227)
  * chore(linters): Fix findings found by testifylint: expected-actual (#14229)
  * chore(deps): Bump github.com/nats-io/nkeys from 0.4.5 to 0.4.6 (#14225)
  * feat(inputs.procstat)!: Remove useless zero cpu_times (#14224)
  * feat(inputs.gnmi): Rework plugin (#14091)
  * fix(outputs.timestream): Clip uint64 values (#14213)
  * fix(inputs.cgroup): Escape backslashes (#14187)
  * test(outputs.kafka): Use private network for testing (#14220)
  * test(inputs.vault): Fix integration test by only testing for subset (#14222)
  * fix(outputs.elasticsearch): Print error status value (#14115)
  * feat(inputs.openweathermap): Add per-city query scheme for current weather  (#14214)
  * docs(inputs.cpu): Clarify 'time_active' contains 'iowait' (#14215)
  * chore(deps): Bump github.com/benbjohnson/clock from 1.3.3 to 1.3.5 (#14219)
  * chore(deps): Bump github.com/antchfx/xpath from 1.2.5-0.20230505064641-588960cceeac to 1.2.5 (#14217)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config from 1.18.42 to 1.19.1 (#14218)
  * chore(deps): Bump github.com/compose-spec/compose-go from 1.16.0 to 1.20.0 (#14216)
  * chore(linters): Fix findings found by testifylint: len (#14203)
  * chore(deps): Bump github.com/docker/docker from 24.0.6 to 24.0.7 (#14211)
  * chore(inputs.openweathermap): Convert unit-tests to test-cases (#14210)
  * fix(inputs.ecs): Fix cgroupv2 CPU metrics (#14197)
  * chore(linters): Enable perfsprint linter and fix all findings. (#14208)
  * fix(inputs.netflow): Fix sFlow metric timestamp (#14195)
  * fix(inputs.ecs): Test for v4 metadata endpoint (#14194)
  * fix(input.prometheus): Read bearer token from file every time (#14191)
  * feat(inputs.http_response): Add body form option (#14189)
  * fix(parsers.json_v2): Prevent race condition in parse function (#14149)
  * docs(outputs.cratedb): Correct required SQL table schema (#13934)
  * chore: Bump github.com/google/gnxi from 20221016143401 to 20231026134436 (#14201)
  * chore(linters): Fix findings found by testifylint: error-nil (#14198)
  * test(parsers): Add benchmarks (#14148)
  * chore(deps): Bump google.golang.org/grpc from 1.58.2 to 1.58.3 (#14192)
  * fix(inputs.zfs): Parse metrics correctly on FreeBSD 14 (#14176)
  * feat(socket_listener): Add vsock support to socket listener and writer (#14172)
  * chore(linters): Fix findings found by testifylint: empty (#14179)
  * chore(linters): Fix findings found by testifylint: require-error (#14181)
  * chore(linters): Fix findings found by testifylint: error-is-as (#14180)
  * test(opensearch): Disable perf analyzer in test images (#14178)
  * chore(linters): Fix findings found by testifylint: compares (#14177)
  * chore(linters): Fix findings found by testifylint: bool-compare (#14163)
  * test(inputs.zfs): Rework and fix unit-tests for FreeBSD (#14175)
  * chore(deps): Bump k8s.io/client-go from 0.28.2 to 0.28.3 (#14165)
  * chore(deps): Bump github.com/hashicorp/consul/api from 1.24.0 to 1.25.1 (#14164)
  * chore(deps): Bump github.com/antchfx/xmlquery from 1.3.17 to 1.3.18 (#14166)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.13.40 to 1.13.43 (#14167)
  * chore(deps): Bump github.com/prometheus/client_golang from 1.16.0 to 1.17.0 (#14168)
  * chore(tools): Cache rework for CircleCI (#14156)
  * docs(openstack): Update examples with quote around time intervals (#14174)
  * docs(inputs.swap): Add message about plugin limitation (#14139)
  * test(outputs.kafka): Rework integration test to use bitnami/kafka (#14161)
  * Update changelog for v1.28.3
  * chore(tools): Bump golangci-lint from v1.54.2 to v1.55.0 (#14155)
  * feat(outputs.wavefront): Use common/http to configure http client (#14136)
  * fix(inputs.vault): Use http client to handle redirects correctly (#14153)
  * fix(outputs.kafka): Simplify send-error handling (#14154)
  * feat(migrations): Add option migration for inputs.disk (#14141)
  * fix(serializers.json): Append newline for batch-serialization (#14150)
  * fix(outputs.nebius_cloud_monitoring): Use correct endpoint (#14135)
  * chore(deps): Bump github.com/nats-io/nats-server/v2 from 2.9.9 to 2.9.23 (#14146)
  * fix(inputs.jenkins): Filter after searching sub-folders (#14105)
  * feat(inputs.redfish): Allow specifying with metrics to collect (#14143)
  * feat(common.http): Add support for connecting over unix-socket (#14103)
  * fix(inputs.jolokia2_agent): Trim quotes around tags (#14132)
  * docs(processors.ifname): Document better agent tag name (#14117)
  * fix(metricpass): Use correct logic expression in benchmark (#14131)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.28.0 to 1.31.0 (#14124)
  * chore(deps): Bump github.com/google/go-cmp from 0.5.9 to 0.6.0 (#14127)
  * chore(deps): Bump google.golang.org/api from 0.139.0 to 0.147.0 (#14126)
  * chore(deps): Bump github.com/google/cel-go from 0.14.1-git to 0.18.1 (#14125)
  * chore(packaging): Remove unnecessary service file removal (#14106)
  * feat(migrations): Add migration for inputs.jolokia (#14114)
  * feat(migrations): Add migration for inputs.kafka_consumer_legacy (#14122)
  * feat(migrations): Add migration for inputs.snmp_legacy (#14123)
  * feat(migrations): Add migration for outputs.riemann_legacy (#14121)
  * feat(migrations): Add migration for inputs.udp_listener (#14120)
  * feat(migrations): Add migration for inputs.tcp_listener (#14119)
  * chore(deps): Remove replacement for gos7 (#14032)
  * feat(outputs.bigquery): Project is no longer a required field (#14086)
  * feat(inputs.win_service): Reduce required rights to GENERIC_READ (#14073)
  * chore(processors.regex): Inform and warn user on operation modus (#14084)
  * fix(inputs.postgresql_extensible): Restore default db name (#14010)
  * feat(processors.dedup): Add state persistence between runs (#14065)
  * fix(outputs.exec): Resolve lint issues with tests (#14101)
  * fix(outputs.redistimeseries): Handle string fields correctly (#14060)
  * feat(outputs.exec): Add ability to exec command once per metric (#13672)
  * feat(aggregators.final): Allow to specify output strategy (#14062)
  * chore(deps): Bump golang.org/x/mod from 0.12.0 to 0.13.0 (#14075)
  * chore(deps): Bump gonum.org/v1/gonum from 0.13.0 to 0.14.0 (#14078)
  * docs(outputs.influxdb): Add help message about multiple influxdb (#14053)
  * docs(outputs.mqtt): Correct typo in protocol config parameter (#14071)
  * docs(processors.split): Fix example (#14087)
  * chore(deps): Bump golang.org/x/net from 0.15.0 to 0.17.0 (#14095)
  * chore: Update go to 1.21.3 (#14093)
  * feat(inputs.ldap): Collect additional fields (#14092)
  * docs(inputs.docker): Add help message about permissions for container (#14094)
  * chore(deps): Bump github.com/jhump/protoreflect from 1.15.1 to 1.15.3 (#14085)
  * chore(deps): Bump github.com/miekg/dns from 1.1.55 to 1.1.56 (#14077)
  * chore(deps): Bump github.com/testcontainers/testcontainers-go from 0.22.0 to 0.25.0 (#14076)
  * chore(deps): Bump golang.org/x/oauth2 from 0.11.0 to 0.13.0 (#14074)
  * feat(inputs.ldap): Add LDAP input plugin supporting OpenLDAP and 389ds (#13995)
  * feat(inputs.opcua_listener): Add monitoring params (#13923)
  * chore(CI): Add 'test' as bugfix label and remove 'dependencies' (#14061)
  * feat(inputs.sql): Add oracle driver (#13978)
  * test(inputs.redis_sentinel): Resolve timeout looking for port (#14051)
  * feat(inputs.kube_inventory): Support using kubelet to get pods data  (#13996)
  * feat(inputs.kube_inventory): Support filtering pods and nodes by node name (#13993)
  * chore: Add build tags to buildbin Makefile target (#14034)
  * fix(inputs.mqtt): Reference correct password variable (#14041)
  * chore(deps): Bump github.com/signalfx/golib/v3 from 3.3.50 to 3.3.53 (#14040)
  * chore(deps): Bump github.com/klauspost/compress from 1.16.7 to 1.17.0 (#14039)
  * chore(deps): Bump github.com/netsampler/goflow2 from 1.3.3 to 1.3.6 (#14037)
  * chore(deps): Bump github.com/yuin/goldmark from 1.5.4 to 1.5.6 (#14038)
  * chore(deps): Bump github.com/apache/arrow/go/v13 from 13.0.0-git to 13.0.0 (#14036)
  * fix(inputs.s7comm): Allow PDU-size to be set as config option (#14045)
  * feat(outputs.azure_data_explorer): Set user agent string (#14047)
  * fix(inputs.infiniband): Handle devices without counters (#14049)
  * feat(input.intel_pmt): Add pci_bdf tag to uniquely identify GPUs and other peripherals (#14004)
  * Update changelog for v1.28.2
  * chore: Restore log directory behavior (#14026)
  * fix(inputs.openstack): Handle dependencies between enabled services and available endpoints (#14011)
  * chore(deps): Bump github.com/vmware/govmomi from v0.28.0 to v0.32.0 (#14022)
  * chore(inputs.modbus): Deprecate aggressive optimization (#14030)
  * chore: Force previous version of mingw (#14035)
  * feat(outputs.stackdriver): Add metric type config options (#14017)
  * fix(parsers.json_v2): Properly handle optional fields (#14008)
  * fix(outputs.opensearch): Migrate to new secrets API (#14021)
  * feat(outputs.opensearch): Add OpenSearch output plugin (#11958)
  * docs(outputs.http): Document proxy settings (#14016)
  * docs(apparmor): Add page explaining apparmor denials (#14014)
  * chore: Update Windows zip archive creation (#14015)
  * feat(processors.regex): Allow batch transforms using named groups (#13971)
  * docs(outputs.prometheus_client): Fix metric-type parameter naming (#14013)
  * feat(parsers.avro): Support multiple modes for union handling (#13945)
  * feat(inputs.docker): Add disk usage (#13894)
  * feat(inputs.rabbitmq): Add secretstore support for username and password (#13991)
  * fix(outputs.stackdriver): Do not shallow copy map (#14009)
  * feat(inputs.amqp_consumer): Add secretstore support for username and password (#14001)
  * fix(inputs.postgresql_extensible): Restore outputaddress behavior (#13972)
  * fix(inputs.mock): Plugin not aligned with documentation (#13997)
  * feat(parsers/json_v2): Improve json path log messages (#13994)
  * fix(inputs.jti_openconfig_telemetry): Do not block GRPC dial (#13958)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config from 1.18.27 to 1.18.42 (#13988)
  * fix(input.intel_pmt): Handle telem devices without numa_node attribute (#13977)
  * chore(deps): Bump github.com/google/uuid from 1.3.0 to 1.3.1 (#13989)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds from 1.13.8 to 1.13.11 (#13987)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.80.1 to 1.120.0 (#13986)
  * chore(deps): Bump github.com/eclipse/paho.mqtt.golang (#13985)
  * chore(secrets): Abstract secret implementation (#13953)
  * chore(processors.starlark): Add benchmark for field-value filter (#13983)
  * fix(inputs.nfsclient): Avoid panics, better error messages (#13982)
  * fix(outputs.stackdriver): Drop metrics on InvalidArgument gRPC error (#13931)
  * fix(inputs.exec): Clean up grandchildren processes (#13937)
  * docs(processors.lookup): Fix wrong word usage (#13970)
  * fix(inputs.cisco_telemetry_mdt): Print string message on decode failure (#13963)
  * fix(inputs.nvidia_smi): Add legacy power readings to v12 schema (#13962)
  * chore(deps): Bump golang.org/x/net from 0.14.0 to 0.15.0 (#13940)
  * chore: Update macOS CircleCI runner (#13932)
  * fix(parsers.avro): Clean up Warnf error wrapping error (#13961)
  * feat(parsers.avro): Get metric name from the message field (#13914)
  * chore: Remove whitespace, update variable naming (#13952)
  * fix(processors.template): Handle tracking metrics correctly (#13947)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.470 to 1.62.563 (#13941)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.20.9 to 1.23.5 (#13943)
  * chore(deps): Bump github.com/shirou/gopsutil/v3 from 3.23.6 to 3.23.8 (#13942)
  * chore(deps): Bump k8s.io/api from 0.28.1 to 0.28.2 (#13944)
  * feat(inputs.kafka_consumer): Add message headers as metric tags. (#13924)
  * fix(parsers.avro): Only attempt to read CA cert file if filename is not empty string (#13939)
  * fix(outputs.cloudwatch): Increase number of metrics per write (#13930)
  * fix(inputs.smart): Remove parsing error message (#13927)
  * docs(inputs.procstat): Add docs on permissions and metric details (#13921)
  * test(outputs.sql): Fix clean up of sql database file (#13918)
  * chore: Clean up results from make check-deps (#13919)
  * fix(inputs.systemd_units): Add missing upstream states (#13915)
  * Update changelog for v1.28.1
  * fix(packaging): Revert permission change on configs (#13909)
  * docs(inputs.vsphere): fix config name typo in example (#13907)
  * fix(inputs.redis): Fix password typo (#13910)
  * feat(parsers.avro): Allow connection to https schema registry (#13903)
  * Update changelog for v1.28.0
* Mon Dec 11 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.28.5:
  * Telegraf v1.28.5
  * Update changelog for v1.28.5
  * Update build_version.txt for v1.28.5
  * fix(parsers.json_v2): Log inner errors (#14296)
  * fix(inputs.ecs): Correct v4 metadata URLs (#14294)
  * fix(inputs.intel_rdt): Do not fail on missing PIDs (#14274)
  * chore: Fix lint in changelog (#14298)
  * fix(inputs.s7comm): Truncate strings to reported length (#14283)
  * chore(deps): Bump github.com/Masterminds/semver/v3 from 3.2.0 to 3.2.1 (#14286)
  * chore(deps): Bump github.com/gosnmp/gosnmp from 1.35.1-0.20230602062452-f30602b8dad6 to 1.36.1 (#14287)
  * chore(deps): Bump google.golang.org/api from 0.149.0 to 0.150.0 (#14288)
  * chore(deps): Bump golang.org/x/mod from 0.13.0 to 0.14.0 (#14289)
  * chore(deps): Bump golang.org/x/sync from 0.4.0 to 0.5.0 (#14285)
* Mon Dec 11 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.28.4:
  * Telegraf v1.28.4
  * Update changelog for v1.28.4
  * Update build_version.txt for v1.28.4
  * test(parsers): Sort metrics to avoid flaky tests (#14284)
  * fix(inputs.zfs): Support gathering metrics on zfs 2.2.0 and later (#14280)
  * fix(inputs.s7comm): Fix bit queries (#14068)
  * chore(parsers): Add additional parser benchmarks (#14276)
  * chore: Add metric and batch benchmark to serializers (#14277)
  * fix(inputs.disk): Add inodes_used_percent field (#14267)
  * chore(parsers.csv): Add benchmark test (#14257)
  * docs(inputs.intel_powerstat): Add notes about hw/sw dependencies (#14263)
  * fix(inputs.ipset): Parse lines with timeout (#14262)
  * chore(deps): Bump github.com/showwin/speedtest-go from 1.6.6 to 1.6.7 (#14250)
  * chore: Update to go1.21.4 (#14268)
  * docs(inputs.powerdns): Document additonal permissions (#14256)
  * docs(inputs.temp): Add additional troubleshooting steps (#14255)
  * fix(inputs.win_perf_counter): Do not rely on returned buffer size (#14241)
  * chore(deps): Bump cloud.google.com/go/storage from 1.30.1 to 1.34.1 (#14253)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.8.1 to 1.9.0 (#14252)
  * chore(deps): Bump github.com/hashicorp/consul/api from 1.25.1 to 1.26.1 (#14251)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.23.5 to 1.26.0 (#14249)
  * fix(config): Fix comment removal in TOML files (#14240)
  * fix(inputs.mqtt_consumer): Resolve could not mark message delivered (#14243)
  * chore(linters): Fix findings found by testifylint for Windows and enable it. (#14238)
  * test(inputs.jolokia2_agent): Sort metrics as order is not consistent (#14227)
  * chore(linters): Fix findings found by testifylint: expected-actual (#14229)
  * chore(deps): Bump github.com/nats-io/nkeys from 0.4.5 to 0.4.6 (#14225)
  * fix(outputs.timestream): Clip uint64 values (#14213)
  * fix(inputs.cgroup): Escape backslashes (#14187)
  * test(outputs.kafka): Use private network for testing (#14220)
  * test(inputs.vault): Fix integration test by only testing for subset (#14222)
  * fix(outputs.elasticsearch): Print error status value (#14115)
  * docs(inputs.cpu): Clarify 'time_active' contains 'iowait' (#14215)
  * chore(deps): Bump github.com/benbjohnson/clock from 1.3.3 to 1.3.5 (#14219)
  * chore(deps): Bump github.com/antchfx/xpath from 1.2.5-0.20230505064641-588960cceeac to 1.2.5 (#14217)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config from 1.18.42 to 1.19.1 (#14218)
  * chore(deps): Bump github.com/compose-spec/compose-go from 1.16.0 to 1.20.0 (#14216)
  * chore(linters): Fix findings found by testifylint: len (#14203)
  * chore(deps): Bump github.com/docker/docker from 24.0.6 to 24.0.7 (#14211)
  * chore(inputs.openweathermap): Convert unit-tests to test-cases (#14210)
  * fix(inputs.ecs): Fix cgroupv2 CPU metrics (#14197)
  * chore(linters): Enable perfsprint linter and fix all findings. (#14208)
  * fix(inputs.netflow): Fix sFlow metric timestamp (#14195)
  * fix(inputs.ecs): Test for v4 metadata endpoint (#14194)
  * fix(input.prometheus): Read bearer token from file every time (#14191)
  * fix(parsers.json_v2): Prevent race condition in parse function (#14149)
  * docs(outputs.cratedb): Correct required SQL table schema (#13934)
  * chore: Bump github.com/google/gnxi from 20221016143401 to 20231026134436 (#14201)
  * chore(linters): Fix findings found by testifylint: error-nil (#14198)
  * test(parsers): Add benchmarks (#14148)
  * chore(deps): Bump google.golang.org/grpc from 1.58.2 to 1.58.3 (#14192)
  * fix(inputs.zfs): Parse metrics correctly on FreeBSD 14 (#14176)
  * chore(linters): Fix findings found by testifylint: empty (#14179)
  * chore(linters): Fix findings found by testifylint: require-error (#14181)
  * chore(linters): Fix findings found by testifylint: error-is-as (#14180)
  * chore(linters): Fix findings found by testifylint: compares (#14177)
  * chore(linters): Fix findings found by testifylint: bool-compare (#14163)
  * test(inputs.zfs): Rework and fix unit-tests for FreeBSD (#14175)
  * chore(deps): Bump k8s.io/client-go from 0.28.2 to 0.28.3 (#14165)
  * chore(deps): Bump github.com/hashicorp/consul/api from 1.24.0 to 1.25.1 (#14164)
  * chore(deps): Bump github.com/antchfx/xmlquery from 1.3.17 to 1.3.18 (#14166)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.13.40 to 1.13.43 (#14167)
  * chore(deps): Bump github.com/prometheus/client_golang from 1.16.0 to 1.17.0 (#14168)
  * chore(tools): Cache rework for CircleCI (#14156)
  * docs(openstack): Update examples with quote around time intervals (#14174)
  * docs(inputs.swap): Add message about plugin limitation (#14139)
  * test(outputs.kafka): Rework integration test to use bitnami/kafka (#14161)
* Mon Oct 23 2023 mrueckert@suse.de
- Update to version 1.28.3:
  * Telegraf v1.28.3
  * Update changelog for v1.28.3
  * Update build_version.txt for v1.28.3
  * chore: Remove unnecessary license
  * chore(tools): Bump golangci-lint from v1.54.2 to v1.55.0 (#14155)
  * fix(inputs.vault): Use http client to handle redirects correctly (#14153)
  * fix(outputs.kafka): Simplify send-error handling (#14154)
  * fix(serializers.json): Append newline for batch-serialization (#14150)
  * fix(outputs.nebius_cloud_monitoring): Use correct endpoint (#14135)
  * chore(deps): Bump github.com/nats-io/nats-server/v2 from 2.9.9 to 2.9.23 (#14146)
  * fix(inputs.jenkins): Filter after searching sub-folders (#14105)
  * fix(inputs.jolokia2_agent): Trim quotes around tags (#14132)
  * docs(processors.ifname): Document better agent tag name (#14117)
  * fix(metricpass): Use correct logic expression in benchmark (#14131)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.28.0 to 1.31.0 (#14124)
  * chore(deps): Bump github.com/google/go-cmp from 0.5.9 to 0.6.0 (#14127)
  * chore(deps): Bump google.golang.org/api from 0.139.0 to 0.147.0 (#14126)
  * chore(deps): Bump github.com/google/cel-go from 0.14.1-git to 0.18.1 (#14125)
  * chore(packaging): Remove unnecessary service file removal (#14106)
  * chore(deps): Remove replacement for gos7 (#14032)
  * fix(inputs.postgresql_extensible): Restore default db name (#14010)
  * fix(outputs.redistimeseries): Handle string fields correctly (#14060)
  * chore(deps): Bump golang.org/x/mod from 0.12.0 to 0.13.0 (#14075)
  * chore(deps): Bump gonum.org/v1/gonum from 0.13.0 to 0.14.0 (#14078)
  * docs(outputs.influxdb): Add help message about multiple influxdb (#14053)
  * docs(outputs.mqtt): Correct typo in protocol config parameter (#14071)
  * docs(processors.split): Fix example (#14087)
  * chore(deps): Bump golang.org/x/net from 0.15.0 to 0.17.0 (#14095)
  * chore: Update go to 1.21.3 (#14093)
  * docs(inputs.docker): Add help message about permissions for container (#14094)
  * chore(deps): Bump github.com/jhump/protoreflect from 1.15.1 to 1.15.3 (#14085)
  * chore(deps): Bump github.com/miekg/dns from 1.1.55 to 1.1.56 (#14077)
  * chore(deps): Bump github.com/testcontainers/testcontainers-go from 0.22.0 to 0.25.0 (#14076)
  * chore(deps): Bump golang.org/x/oauth2 from 0.11.0 to 0.13.0 (#14074)
  * chore(CI): Add 'test' as bugfix label and remove 'dependencies' (#14061)
  * test(inputs.redis_sentinel): Resolve timeout looking for port (#14051)
  * chore: Add build tags to buildbin Makefile target (#14034)
  * fix(inputs.mqtt): Reference correct password variable (#14041)
  * chore(deps): Bump github.com/signalfx/golib/v3 from 3.3.50 to 3.3.53 (#14040)
  * chore(deps): Bump github.com/klauspost/compress from 1.16.7 to 1.17.0 (#14039)
  * chore(deps): Bump github.com/netsampler/goflow2 from 1.3.3 to 1.3.6 (#14037)
  * chore(deps): Bump github.com/yuin/goldmark from 1.5.4 to 1.5.6 (#14038)
  * chore(deps): Bump github.com/apache/arrow/go/v13 from 13.0.0-git to 13.0.0 (#14036)
  * fix(inputs.s7comm): Allow PDU-size to be set as config option (#14045)
  * fix(inputs.infiniband): Handle devices without counters (#14049)
* Wed Oct  4 2023 mrueckert@suse.de
- Update to version 1.28.2:
  * Telegraf v1.28.2
  * Update changelog for v1.28.2
  * Update build_version.txt for v1.28.2
  * chore: Restore log directory behavior (#14026)
  * fix(inputs.openstack): Handle dependencies between enabled services and available endpoints (#14011)
  * chore(deps): Bump github.com/vmware/govmomi from v0.28.0 to v0.32.0 (#14022)
  * chore(inputs.modbus): Deprecate aggressive optimization (#14030)
  * fix(parsers.json_v2): Properly handle optional fields (#14008)
  * chore: Force previous version of mingw (#14035)
  * docs(outputs.http): Document proxy settings (#14016)
  * docs(apparmor): Add page explaining apparmor denials (#14014)
  * chore: Update Windows zip archive creation (#14015)
  * docs(outputs.prometheus_client): Fix metric-type parameter naming (#14013)
  * fix(outputs.stackdriver): Do not shallow copy map (#14009)
  * fix(inputs.postgresql_extensible): Restore outputaddress behavior (#13972)
  * fix(inputs.mock): Plugin not aligned with documentation (#13997)
  * fix(inputs.jti_openconfig_telemetry): Do not block GRPC dial (#13958)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config from 1.18.27 to 1.18.42 (#13988)
  * fix(input.intel_pmt): Handle telem devices without numa_node attribute (#13977)
  * chore(deps): Bump github.com/google/uuid from 1.3.0 to 1.3.1 (#13989)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds from 1.13.8 to 1.13.11 (#13987)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.80.1 to 1.120.0 (#13986)
  * chore(deps): Bump github.com/eclipse/paho.mqtt.golang (#13985)
  * chore(secrets): Abstract secret implementation (#13953)
  * chore(processors.starlark): Add benchmark for field-value filter (#13983)
  * fix(inputs.nfsclient): Avoid panics, better error messages (#13982)
  * fix(outputs.stackdriver): Drop metrics on InvalidArgument gRPC error (#13931)
  * fix(inputs.exec): Clean up grandchildren processes (#13937)
  * docs(processors.lookup): Fix wrong word usage (#13970)
  * fix(inputs.cisco_telemetry_mdt): Print string message on decode failure (#13963)
  * fix(inputs.nvidia_smi): Add legacy power readings to v12 schema (#13962)
  * chore(deps): Bump golang.org/x/net from 0.14.0 to 0.15.0 (#13940)
  * chore: Update macOS CircleCI runner (#13932)
  * fix(processors.template): Handle tracking metrics correctly (#13947)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.470 to 1.62.563 (#13941)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.20.9 to 1.23.5 (#13943)
  * chore(deps): Bump github.com/shirou/gopsutil/v3 from 3.23.6 to 3.23.8 (#13942)
  * chore(deps): Bump k8s.io/api from 0.28.1 to 0.28.2 (#13944)
  * fix(outputs.cloudwatch): Increase number of metrics per write (#13930)
  * fix(inputs.smart): Remove parsing error message (#13927)
  * docs(inputs.procstat): Add docs on permissions and metric details (#13921)
  * test(outputs.sql): Fix clean up of sql database file (#13918)
  * chore: Clean up results from make check-deps (#13919)
  * fix(inputs.systemd_units): Add missing upstream states (#13915)
* Tue Sep 12 2023 mrueckert@suse.de
- Update to version 1.28.1:
  * Telegraf v1.28.1
  * Update changelog for v1.28.1
  * Update build_version.txt for v1.28.1
  * fix(packaging): Revert permission change on configs (#13909)
  * docs(inputs.vsphere): fix config name typo in example (#13907)
  * fix(inputs.redis): Fix password typo (#13910)
* Tue Sep 12 2023 mrueckert@suse.de
- Update to version 1.28.0:
  * Telegraf v1.28.0
  * Update changelog for v1.28.0
  * Update build version to 1.29.0
  * feat(inputs): New Intel PMT plugin (#13801)
  * feat(outputs.prometheus_client): Add secretstore support for basic_password (#13899)
  * fix(inputs.kafka_consumer): Use per-message parser to avoid races (#13886)
  * fix(parsers.avro): Do not force addition of timestamp as a field (#13856)
  * feat(prometheus): Allow to specify metric type (#13874)
  * chore(deps): Bump github.com/showwin/speedtest-go from 1.6.2 to 1.6.6 (#13895)
  * feat(inputs.redis_sentinel): Allow username and password (#13864)
  * feat(outputs.wavefront): Add more auth options and update SDK (#13857)
  * feat(inputs.vsphere): Allow to set vSAN sampling interval (#13890)
  * fix(sql): Allow sqlite on Windows (amd64 and arm64) (#13865)
  * feat(inputs.redis): Add additional commandstat fields (#13866)
  * fix(inputs.sqlserver): Cast max_size to bigint (#13870)
  * fix(inputs.procstat): Collect swap via /proc/$pid/smaps (#13779)
  * chore: Update to go1.21.1 (#13887)
  * fix(parsers.avro): Handle timestamp format checking correctly (#13855)
  * docs: Improve behavior documentation of metricpass (#13883)
  * fix(rpm): Resolve nightly rpm tests (#13884)
  * chore: Force reinstall of go on Windows (#13879)
  * chore: Update all cache strings with go version (#13871)
  * feat(inputs.cisco_telemetry_mdt): Add microbust support (#13877)
  * fix(outputs.sql): Move 'conversion_style' option to the right place (#13875)
  * chore: Update go cache key to include go version (#13867)
  * fix: Change the systemd KillMode from control-group to mixed (#13849)
  * feat(inputs.opentelemetry): Add configurable log record dimensions (#13846)
  * fix(inputs.opcua): Verify groups or root nodes included in config (#13840)
  * fix(tools.license_checker): Determine version correctly and whitelist gorilla/websocket (#13839)
  * fix(inputs.sysstat): Remove tmpfile to avoid file-descriptor leak (#13833)
  * chore: Add InfluxDB and InfluxData branding to log output (#13819)
  * chore(inputs.modbus): Improve deprecation documentation (#13832)
  * feat(inputs.internal): Add Go metric collection option (#13793)
  * feat(processors): Add processor to split a metric into multiple (#13785)
  * feat(cli): Add plugins subcommand to list available and deprecated (#13787)
  * feat(inputs.couchbase): Add failover metrics (#13825)
  * chore(tools): Bump golangci-lint from v1.53.2 to v1.54.2 (#13838)
  * fix(metricpass): Remove python logic compatibility (#13791)
  * feat(inputs.fibaro): Support HC3 device types (#13754)
  * chore: Update to go1.21.0 (#13794)
  * docs: Clean up markdown add warning about tables (#13792)
  * feat(inputs.nvidia_smi): Add additional fields (#13783)
  * chore(deps): Bump k8s.io/api from 0.27.4 to 0.28.1 (#13810)
  * chore: Update permissions on new installs (#13778)
  * chore: Cache rework for `.circleci` jobs (#13753)
  * fix(inputs.amqp_consumer): Print error on connection failure (#13777)
  * chore(deps): Bump github.com/hashicorp/consul/api from 1.20.0 to 1.24.0 (#13811)
  * feat(agent): Watch default config files if none specified (#13774)
  * feat(inputs.nvidia_smi): Add Nvidia DCGM MIG usage values (#13733)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.27.0 to 1.28.0 (#13809)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.18.2 to 1.18.5 (#13808)
  * chore(deps): Bump github.com/prometheus/prometheus from 0.42.0 to 0.46.0 (#13765)
  * feat(outputs.postgresql): Add option to create time column with timezone (#13763)
  * chore: Update license URL for collectd (#13802)
  * Update changelog for v1.27.4
  * chore: Update lxd package testing images (#13780)
  * feat(outputs.postgresql): Add option to rename time column (#13750)
  * chore: go mod tidy (#13773)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.18.0 to 1.18.2 (#13769)
  * chore(deps): Bump github.com/miekg/dns from 1.1.51 to 1.1.55 (#13768)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.13.26 to 1.13.32 (#13767)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.32.0 to 1.33.0 (#13766)
  * fix(inputs.processes): Comment out default option (#13762)
  * chore: Enable filepathJoin checker for gocritic (#13758)
  * chore: Update link to consul API license (#13761)
  * chore: Spell endianness correctly (#13752)
  * docs: Update FAQ around release dates (#13751)
  * chore(inputs): Remove unnecessary nil check (#13749)
  * feat(inputs.redfish): Add additional chassis tags (#13727)
  * fix(outputs.stackdriver): Regenerate time interval for unkown metrics (#13745)
  * chore: Check logging functions like printf (#13743)
  * feat(inputs.kernel): Collect KSM metrics (#13728)
  * feat(inputs): Add new S7comm plugin (#13731)
  * fix(inputs.opcua_listener): Avoid segfault if subscription was not successful (#13742)
  * feat(inputs.redis): Support of redis 6.2 ERRORSTATS (#13723)
  * feat(inputs.vsphere): Support explicit proxy setting (#13720)
  * feat(serializers.nowmetric): Add option for JSONv2 format (#13722)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.11.6 to 1.12.1 (#13736)
  * chore: Update to go1.20.7 (#13740)
  * Increase timeout for govulncheck
  * chore(deps): Bump github.com/gophercloud/gophercloud from 1.2.0 to 1.5.0 (#13735)
  * chore(deps): Bump golang.org/x/oauth2 from 0.10.0 to 0.11.0 (#13738)
  * chore(deps): Bump github.com/microsoft/go-mssqldb (#13737)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts (#13734)
  * fix(parsers.xpath): Handle protobuf maps correctly (#13719)
  * fix(inputs.opcua): Register node IDs again on reconnect (#13682)
  * feat(inputs.jti_openconfig_telemetry): Add keep-alive setting (#13709)
  * feat(inputs.tacacs): Add tacacs plugin for simple tacacs auth response time monitoring (#12747)
  * chore: Enable additional gocritic (#13714)
  * chore: Resolves gocritic sloppyReassign (#13712)
  * chore: Enable additional gocritic options (#13711)
  * chore: Enable additional gocritic (#13713)
  * feat(inputs.solr): Support version 7.x to 9.3 (#13699)
  * docs(config): Add notes for secret-store pitfalls (#13707)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds from 1.13.4 to 1.13.7 (#13703)
  * chore(deps): Bump github.com/openconfig/gnmi from 0.9.1 to 0.10.0 (#13706)
  * chore(deps): Bump github.com/santhosh-tekuri/jsonschema/v5 from 5.3.0 to 5.3.1 (#13705)
  * chore(deps): Bump google.golang.org/api from 0.129.0 to 0.134.0 (#13704)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.17.14 to 1.18.0 (#13702)
  * fix(inputs.cisco_telemetry_mdt): Fix MDT source field overwrite (#13693)
  * docs(testutil): Fix documentation of IgnoreTags (#13700)
  * Update changelog for v1.27.3
  * fix(inputs.jti_openconfig_telemetry): Reauthenticate connection (#13647)
  * feat(inputs.nvidia_smi): Support newer data schema versions (#13678)
  * test(inputs.solr): Rework testing (#13692)
  * docs(inputs.conntrack): Explain different collection methods (#13691)
  * feat(serializers.template): Add new template based serializer (#13656)
  * feat(parsers.xpath): Add option to store fields as base64 (#13690)
  * chore(tools): Fix doc inclusion tools on Windows (#13685)
  * feat(inputs.jenkins): Add option for node labels as tag (#13649)
  * test(inputs.radius): Use random port for test (#13683)
  * feat(outputs.execd): Add option for batch format (#13673)
  * chore(deps): Bump github.com/antchfx/xpath from v1.2.4 to latest master (#13679)
  * fix(inputs.mqtt_consumer): Client logs via option (#13663)
  * docs(outputs.azure_data_explorer): Update supported Azure Data Explorer flavors (#13677)
  * fix(config): Handle escaping and quotation correctly (#13675)
  * fix(parsers.xpath): Ensure precedence of explicitly defined tags and fields (#13662)
  * fix(parsers.xpath): Improve handling of complex-type nodes (#13660)
  * fix(config): Setup logger for secret-stores (#13671)
  * fix(parsers.xpath): Fix field-names for arrays of simple types (#13665)
  * chore(deps): Bump github.com/eclipse/paho.golang from 0.10.0 to 0.11.0 (#13670)
  * chore(deps): Bump github.com/shirou/gopsutil/v3 from 3.23.5 to 3.23.6 (#13666)
  * chore(deps): Bump k8s.io/api from 0.27.2 to 0.27.4 (#13667)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go (#13668)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts (#13669)
  * feat(inputs.influxdb_listener): Add token based authentication (#13610)
  * fix(inputs.docker): Add restart count (#13646)
  * chore(infrastructure): Bump github.com/testcontainers/testcontainers-go from v0.18.0 to v0.21.0 (#13628)
  * feat(outputs.http): Allow PATCH method (#13651)
  * chore(deps): Bump github.com/antchfx/jsonquery from 1.3.1 to 1.3.2 (#13640)
  * docs(inputs.postgresql_extensible): Document 'measurement' query config option (#13631)
  * fix(inputs.prometheus): Don't collect metrics from finished pods (#13629)
  * fix(inputs.prometheus): Fix missing metrics when multiple plugin instances specified (#13627)
  * feat(inputs.prometheus): Always apply kubernetes label and field selectors (#13624)
  * feat(inputs.postgresql_extensible): Introduce max_version for query (#13620)
  * chore(deps): Bump modernc.org/sqlite from 1.23.1 to 1.24.0 (#13641)
  * chore(deps): Bump github.com/antchfx/xmlquery from 1.3.15 to 1.3.17 (#13639)
  * chore(deps): Bump github.com/thomasklein94/packer-plugin-libvirt from 0.3.4 to 0.5.0 (#13638)
  * Revert "chore: Update to go1.20.6 (#13618)" (#13625)
  * feat(secretstores): Add secret-store to access OAuth2 services (#13621)
  * fix(outputs.opentelemetry): group metrics by age and timestamp (#13292)
  * feat(kafka): Set and send SASL extensions (#13411)
  * feat(inputs.http): Rework token options (#13622)
  * chore: Update to official govulncheck github action (#13623)
  * fix(agent): Respect processor order in file (#13614)
  * chore: Update to go1.20.6 (#13618)
  * Revert "feat(inputs.kafka_consumer): Refresh regexp topics periodically (#13410)" (#13617)
  * feat(parsers.avro): Add support for JSON format (#13607)
  * feat(agent): Add option to avoid filtering of global tags (#13605)
  * chore: Enable multi-os golanglint-ci (#13599)
  * fix(outputs.nebius_cloud_monitoring): Replace reserved label names (#13597)
  * fix(outputs.stackdriver): Add tag as resource label option (#13575)
  * feat(parsers.influx): Allow a user to set the timestamp precision (#13419)
  * fix(test): Increase waiting for network time (#13613)
  * chore: Update sarma repo URL post-swap to IBM (#13612)
  * fix(tools.custom_builder): Ignore non-plugin sections during configuration (#13604)
  * fix(inputs.postgresql): Default database definition (#13602)
  * feat(processors.template): Unify template metric (#13606)
  * chore(inputs.net): Deprecate 'ignore_protocol_stats' value 'false' (#13608)
  * chore(deps): Bump github.com/jaegertracing/jaeger from 1.38.0 to 1.47.0 (#13603)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb from 1.17.3 to 1.20.0 (#13589)
  * chore(deps): Bump github.com/prometheus-community/pro-bing from 0.2.0 to 0.3.0 (#13585)
  * chore(deps): Bump github.com/opensearch-project/opensearch-go/v2 from 2.2.0 to 2.3.0 (#13586)
  * chore(deps): Bump k8s.io/apimachinery from 0.27.2 to 0.27.3 (#13587)
  * chore(deps): Bump github.com/go-ldap/ldap/v3 from 3.4.4 to 3.4.5 (#13588)
  * chore: Trigger on PR's base and restrict permissions (#13584)
  * Update changelog for v1.27.2
  * chore: Update milestone action and fix permissions (#13583)
  * docs(inputs.gnmi): Add troubleshooting section for Juniper devices  (#13582)
  * fix(outputs.influxdb_v2): Expose HTTP/2 client timeouts (#13562)
  * fix(config): Replace environment variables if existing but empty (#13570)
  * test(outputs.instrumental): Allow setting custom port (#13576)
  * fix(inputs.mqtt_consumer): Print warning on no metrics generated (#13574)
  * feat(processors.parser): Allow also non-string fields (#13553)
  * fix: replace github.com/denisenkom/go-mssqldb with github.com/microsoft/go-mssqldb (#13524)
  * feat(inputs.kafka_consumer): Refresh regexp topics periodically (#13410)
  * chore(deps): Bump github.com/snowflakedb/gosnowflake from 1.6.13 to 1.6.22 (#13544)
  * fix(inputs.mqtt_consumer): Correctly handle semaphores on messages (#13478)
  * fix(tools.custom_builder): Error out for unknown plugins in configuration (#13563)
  * fix(processors.printer): Convert output to string (#13564)
  * feat(outputs.file): Add compression (#13245)
  * chore(inputs.opentelemetry): Unbreak after interface change (#13559)
  * fix(parsers.xpath): Handle explicitly defined fields correctly (#13550)
  * fix(inputs.vpshere): Compare versions as a string (#13557)
  * feat(CI): Automatically assign milestones to pull-requests (#13551)
  * fix(inputs.gnmi): Add option to explicitly trim field-names (#13517)
  * docs: remove newline (#13558)
  * docs: revert table example change (#13556)
  * chore(deps): Bump golang.org/x/text from 0.10.0 to 0.11.0 (#13554)
  * fix(outputs.graphite): Rework connection handling (#13527)
  * feat(migrations): Add migration for 'inputs.io' (#13536)
  * feat(migrations): Add migration for 'inputs.httpjson' (#13532)
  * fix(parsers.binary): Fix binary parser example in README.md (#13547)
  * feat(inputs.pgbouncer): Added show_commands to select the collected pgbouncer metrics (#13436)
  * fix(inputs.snmp_trap): Copy GoSNMP global defaults to prevent side-effects (#13542)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.17.8 to 1.17.14 (#13537)
  * chore(deps): Bump golang.org/x/text from 0.9.0 to 0.10.0 (#13538)
  * chore(deps): Bump google.golang.org/api from 0.126.0 to 0.129.0 (#13540)
  * chore(deps): Bump github.com/urfave/cli/v2 from 2.25.5 to 2.25.7 (#13541)
  * fix(outputs.sumologic): Unwrap serializer for type check (#13522)
  * fix(inputs.opcua): Ensure we are connected after reconnect (#13514)
  * feat(inputs.modbus): Add per-metric configuration style (#13507)
  * fix(parsers.grok): Use UTC as the default timezone (#13526)
  * fix(inputs.cloud_pubsub): Properly lock for decompression (#13525)
  * feat(internal): Add gather_timeouts metric (#13471)
  * docs(intel_baseband): Remove ACC101 mentions from documentation (#13518)
  * feat(parsers.value): Add support for automatic fallback for numeric types (#13506)
  * feat(parsers.xpath): Add Concise Binary Object Representation parser (#13480)
  * chore(deps): Bump github.com/gopcua/opcua from 0.3.7 to 0.4.0 (#13509)
  * fix(serializers.splunkmetric): Fix TOML option name for multi-metric (#13511)
  * feat(inputs.amqp_consumer): Add support to rabbitmq stream queue (#13496)
  * docs(inputs.ravendb): Change metrics requirements in readme (#13494)
  * fix(secretstores): Skip dbus connection with kwallet (#13489)
  * feat(inputs.procstat): Add status field (#13505)
  * chore(deps): Bump github.com/prometheus/client_golang (#13502)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.51.1 to 1.52.0 (#13501)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go (#13500)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config (#13504)
  * fix(inputs.internet_speed): Add location as a field (#13497)
  * fix(inputs.phpfpm): Check address length to avoid crash (#13495)
  * fix(outputs.stackdriver): Options to use official path and types (#13454)
  * fix(inputs.modbus): Fix optimization of overlapping requests and add warning (#13486)
  * fix(inputs.modbus): Check number of register for datatype (#13485)
  * feat(internal): Add zstd to internal content_coding (#13423)
  * Update changelog for v1.27.1
  * fix(config): Restore old environment var behavior with option (#13457)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatch from 1.25.9 to 1.26.2 (#13468)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/timestreamwrite from 1.16.0 to 1.17.2 (#13465)
  * fix: Handle compression level correctly for different algorithms (#13434)
  * fix(custom_builder): Correctly handle serializers and parsers (#13446)
  * feat(inputs.sqlserver): Add IsHadrEnabled server property (#13448)
  * chore(deps): Bump github.com/prometheus-community/pro-bing from 0.1.0 to 0.2.0 (#13467)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.13.20 to 1.13.26 (#13469)
  * chore(deps): Bump github.com/go-sql-driver/mysql from 1.6.0 to 1.7.1 (#13466)
  * feat(inputs.openstack): Gather cinder services (#13443)
  * test: Use -e to print newlines on yum tests (#13450)
  * feat(inputs.fail2ban): Allow specification of socket (#13452)
  * fix(config): Move bracketed environment variable substitution to double-dollar (#13451)
  * chore: replace altool with notarytool for macOS signing (#13453)
  * test: Do not use hard-coded /tmp/telegraf (#13444)
  * chore: Update golanglint-ci (#13445)
  * test(package): fix set up of yum files (#13435)
  * feat(inputs.ravendb): Add new disk metrics fields (#13433)
  * chore(deps): Bump modernc.org/sqlite from 1.21.0 to 1.23.1 (#13430)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.24.0 to 1.27.0 (#13429)
  * chore(deps): Bump github.com/jackc/pgx/v4 from 4.17.1 to 4.18.1 (#13427)
  * test: Fix capturing the timestamp warning (#13426)
  * chore(deps): Bump golang.org/x/term from 0.8.0 to 0.9.0 (#13431)
  * chore(deps): Bump golang.org/x/crypto from 0.8.0 to 0.9.0 (#13428)
  * Update changelog for v1.27.0
* Sat Aug 26 2023 mrueckert@suse.de
- Update to version 1.27.4:
  * go mod tidy
  * Telegraf v1.27.4
  * Update changelog for v1.27.4
  * Update build_version.txt for v1.27.4
  * chore: Update lxd package testing images (#13780)
  * chore: go mod tidy (#13773)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.18.0 to 1.18.2 (#13769)
  * chore(deps): Bump github.com/miekg/dns from 1.1.51 to 1.1.55 (#13768)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.13.26 to 1.13.32 (#13767)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.32.0 to 1.33.0 (#13766)
  * fix(inputs.processes): Comment out default option (#13762)
  * chore: Enable filepathJoin checker for gocritic (#13758)
  * chore: Update link to consul API license (#13761)
  * chore: Spell endianness correctly (#13752)
  * docs: Update FAQ around release dates (#13751)
  * chore(inputs): Remove unnecessary nil check (#13749)
  * fix(outputs.stackdriver): Regenerate time interval for unkown metrics (#13745)
  * chore: Check logging functions like printf (#13743)
  * fix(inputs.opcua_listener): Avoid segfault if subscription was not successful (#13742)
  * feat(serializers.nowmetric): Add option for JSONv2 format (#13722)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.11.6 to 1.12.1 (#13736)
  * chore: Update to go1.20.7 (#13740)
  * chore(deps): Bump github.com/gophercloud/gophercloud from 1.2.0 to 1.5.0 (#13735)
  * chore(deps): Bump golang.org/x/oauth2 from 0.10.0 to 0.11.0 (#13738)
  * chore(deps): Bump github.com/microsoft/go-mssqldb (#13737)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts (#13734)
  * fix(parsers.xpath): Handle protobuf maps correctly (#13719)
  * fix(inputs.opcua): Register node IDs again on reconnect (#13682)
  * chore: Enable additional gocritic (#13714)
  * chore: Resolves gocritic sloppyReassign (#13712)
  * chore: Enable additional gocritic options (#13711)
  * chore: Enable additional gocritic (#13713)
  * docs(config): Add notes for secret-store pitfalls (#13707)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds from 1.13.4 to 1.13.7 (#13703)
  * chore(deps): Bump github.com/openconfig/gnmi from 0.9.1 to 0.10.0 (#13706)
  * chore(deps): Bump github.com/santhosh-tekuri/jsonschema/v5 from 5.3.0 to 5.3.1 (#13705)
  * chore(deps): Bump google.golang.org/api from 0.129.0 to 0.134.0 (#13704)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.17.14 to 1.18.0 (#13702)
  * fix(inputs.cisco_telemetry_mdt): Fix MDT source field overwrite (#13693)
  * docs(testutil): Fix documentation of IgnoreTags (#13700)
  * chore: Update to go1.20.6 (#13618)
* Tue Aug  1 2023 mrueckert@suse.de
- Update to version 1.27.3:
  * Telegraf v1.27.3
  * Update changelog for v1.27.3
  * Update build_version.txt for v1.27.3
  * fix(inputs.jti_openconfig_telemetry): Reauthenticate connection (#13647)
  * test(inputs.solr): Rework testing (#13692)
  * docs(inputs.conntrack): Explain different collection methods (#13691)
  * chore(tools): Fix doc inclusion tools on Windows (#13685)
  * test(inputs.radius): Use random port for test (#13683)
  * chore(deps): Bump github.com/antchfx/xpath from v1.2.4 to latest master (#13679)
  * fix(inputs.mqtt_consumer): Client logs via option (#13663)
  * docs(outputs.azure_data_explorer): Update supported Azure Data Explorer flavors (#13677)
  * fix(config): Handle escaping and quotation correctly (#13675)
  * fix(parsers.xpath): Ensure precedence of explicitly defined tags and fields (#13662)
  * fix(parsers.xpath): Improve handling of complex-type nodes (#13660)
  * fix(config): Setup logger for secret-stores (#13671)
  * test: Add IgnoreTags function
  * fix(parsers.xpath): Fix field-names for arrays of simple types (#13665)
  * chore(deps): Bump github.com/eclipse/paho.golang from 0.10.0 to 0.11.0 (#13670)
  * chore(deps): Bump github.com/shirou/gopsutil/v3 from 3.23.5 to 3.23.6 (#13666)
  * chore(deps): Bump k8s.io/api from 0.27.2 to 0.27.4 (#13667)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go (#13668)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts (#13669)
  * fix(inputs.docker): Add restart count (#13646)
  * chore(infrastructure): Bump github.com/testcontainers/testcontainers-go from v0.18.0 to v0.21.0 (#13628)
  * chore(deps): Bump github.com/antchfx/jsonquery from 1.3.1 to 1.3.2 (#13640)
  * docs(inputs.postgresql_extensible): Document 'measurement' query config option (#13631)
  * fix(inputs.prometheus): Don't collect metrics from finished pods (#13629)
  * fix(inputs.prometheus): Fix missing metrics when multiple plugin instances specified (#13627)
  * chore(deps): Bump modernc.org/sqlite from 1.23.1 to 1.24.0 (#13641)
  * chore(deps): Bump github.com/antchfx/xmlquery from 1.3.15 to 1.3.17 (#13639)
  * chore(deps): Bump github.com/thomasklein94/packer-plugin-libvirt from 0.3.4 to 0.5.0 (#13638)
  * fix(outputs.opentelemetry): group metrics by age and timestamp (#13292)
  * chore: Update to official govulncheck github action (#13623)
  * fix(agent): Respect processor order in file (#13614)
  * chore: Enable multi-os golanglint-ci (#13599)
  * fix(outputs.nebius_cloud_monitoring): Replace reserved label names (#13597)
  * fix(outputs.stackdriver): Add tag as resource label option (#13575)
  * fix(test): Increase waiting for network time (#13613)
  * chore: Update sarma repo URL post-swap to IBM (#13612)
  * fix(tools.custom_builder): Ignore non-plugin sections during configuration (#13604)
  * chore(inputs.net): Deprecate 'ignore_protocol_stats' value 'false' (#13608)
  * chore(deps): Bump github.com/jaegertracing/jaeger from 1.38.0 to 1.47.0 (#13603)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb from 1.17.3 to 1.20.0 (#13589)
  * chore(deps): Bump github.com/prometheus-community/pro-bing from 0.2.0 to 0.3.0 (#13585)
  * chore(deps): Bump github.com/opensearch-project/opensearch-go/v2 from 2.2.0 to 2.3.0 (#13586)
  * chore(deps): Bump k8s.io/apimachinery from 0.27.2 to 0.27.3 (#13587)
  * chore(deps): Bump github.com/go-ldap/ldap/v3 from 3.4.4 to 3.4.5 (#13588)
  * chore: Trigger on PR's base and restrict permissions (#13584)
* Tue Jul 18 2023 mrueckert@suse.de
- Update to version 1.27.2:
  * Telegraf v1.27.2
  * Update changelog for v1.27.2
  * Update build_version.txt for v1.27.2
  * chore: remove cbor tests, feat not backported
  * chore: Update milestone action and fix permissions (#13583)
  * docs(inputs.gnmi): Add troubleshooting section for Juniper devices  (#13582)
  * fix(outputs.influxdb_v2): Expose HTTP/2 client timeouts (#13562)
  * fix(config): Replace environment variables if existing but empty (#13570)
  * test(outputs.instrumental): Allow setting custom port (#13576)
  * fix(inputs.mqtt_consumer): Print warning on no metrics generated (#13574)
  * fix: replace github.com/denisenkom/go-mssqldb with github.com/microsoft/go-mssqldb (#13524)
  * update go.sum
  * chore(deps): Bump github.com/snowflakedb/gosnowflake from 1.6.13 to 1.6.22 (#13544)
  * fix(inputs.mqtt_consumer): Correctly handle semaphores on messages (#13478)
  * fix(tools.custom_builder): Error out for unknown plugins in configuration (#13563)
  * fix(processors.printer): Convert output to string (#13564)
  * chore(inputs.opentelemetry): Unbreak after interface change (#13559)
  * fix(parsers.xpath): Handle explicitly defined fields correctly (#13550)
  * fix(inputs.vpshere): Compare versions as a string (#13557)
  * feat(CI): Automatically assign milestones to pull-requests (#13551)
  * fix(inputs.gnmi): Add option to explicitly trim field-names (#13517)
  * docs: remove newline (#13558)
  * docs: revert table example change (#13556)
  * chore(deps): Bump golang.org/x/text from 0.10.0 to 0.11.0 (#13554)
  * fix(outputs.graphite): Rework connection handling (#13527)
  * fix(parsers.binary): Fix binary parser example in README.md (#13547)
  * fix(inputs.snmp_trap): Copy GoSNMP global defaults to prevent side-effects (#13542)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.17.8 to 1.17.14 (#13537)
  * chore(deps): Bump golang.org/x/text from 0.9.0 to 0.10.0 (#13538)
  * chore(deps): Bump google.golang.org/api from 0.126.0 to 0.129.0 (#13540)
  * chore(deps): Bump github.com/urfave/cli/v2 from 2.25.5 to 2.25.7 (#13541)
  * fix(outputs.sumologic): Unwrap serializer for type check (#13522)
  * fix(inputs.opcua): Ensure we are connected after reconnect (#13514)
  * fix(parsers.grok): Use UTC as the default timezone (#13526)
  * fix(inputs.cloud_pubsub): Properly lock for decompression (#13525)
  * docs(intel_baseband): Remove ACC101 mentions from documentation (#13518)
  * chore(deps): Bump github.com/gopcua/opcua from 0.3.7 to 0.4.0 (#13509)
  * fix(serializers.splunkmetric): Fix TOML option name for multi-metric (#13511)
  * docs(inputs.ravendb): Change metrics requirements in readme (#13494)
  * fix(secretstores): Skip dbus connection with kwallet (#13489)
  * chore(deps): Bump github.com/prometheus/client_golang (#13502)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.51.1 to 1.52.0 (#13501)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go (#13500)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/config (#13504)
  * fix(inputs.internet_speed): Add location as a field (#13497)
  * fix(inputs.phpfpm): Check address length to avoid crash (#13495)
  * fix(outputs.stackdriver): Options to use official path and types (#13454)
  * fix(inputs.modbus): Fix optimization of overlapping requests and add warning (#13486)
  * fix(inputs.modbus): Check number of register for datatype (#13485)
* Thu Jun 22 2023 mrueckert@suse.de
- Update to version 1.27.1:
  * Telegraf v1.27.1
  * Update changelog for v1.27.1
  * Update build_version.txt for v1.27.1
  * fix(config): Restore old environment var behavior with option (#13457)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatch from 1.25.9 to 1.26.2 (#13468)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/timestreamwrite from 1.16.0 to 1.17.2 (#13465)
  * fix: Handle compression level correctly for different algorithms (#13434)
  * fix(custom_builder): Correctly handle serializers and parsers (#13446)
  * chore(deps): Bump github.com/prometheus-community/pro-bing from 0.1.0 to 0.2.0 (#13467)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.13.20 to 1.13.26 (#13469)
  * chore(deps): Bump github.com/go-sql-driver/mysql from 1.6.0 to 1.7.1 (#13466)
  * test: Use -e to print newlines on yum tests (#13450)
  * fix(config): Move bracketed environment variable substitution to double-dollar (#13451)
  * chore: replace altool with notarytool for macOS signing (#13453)
  * test: Do not use hard-coded /tmp/telegraf (#13444)
  * chore: Update golanglint-ci (#13445)
  * test(package): fix set up of yum files (#13435)
  * chore(deps): Bump modernc.org/sqlite from 1.21.0 to 1.23.1 (#13430)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.24.0 to 1.27.0 (#13429)
  * chore(deps): Bump github.com/jackc/pgx/v4 from 4.17.1 to 4.18.1 (#13427)
  * test: Fix capturing the timestamp warning (#13426)
  * chore(deps): Bump golang.org/x/term from 0.8.0 to 0.9.0 (#13431)
  * chore(deps): Bump golang.org/x/crypto from 0.8.0 to 0.9.0 (#13428)
* Tue Jun 13 2023 mrueckert@suse.de
- Update to version 1.27.0:
  * Telegraf v1.27.0
  * Update changelog for v1.27.0
  * Update build version to 1.28.0
  * feat(inputs.netflow): Allow to specify custom PEN field mappings (#13360)
  * feat(inputs): New Intel Baseband Accelerator Input Plugin (#13397)
  * fix(inputs.upsd): Handle float battery.runtime value (#13412)
  * feat(internal): Add additional faster compression options (#13316)
  * feat(outputs): Add Nebius Cloud Monitoring plugin (#13379)
  * chore: Fix linter findings for Windows (part4) (#13246)
  * fix(outputs.sql): Use config.duration to correctly parse toml config (#13408)
  * feat(inputs.opentelemetry): Add configurable span dimensions (#13404)
  * chore: Enable dynamicFmtString and sprintfQuotedString checkers for gocritic (#13279)
  * feat(config): Add framework for migrating deprecated plugins (#13377)
  * fix(inputs.mqtt): ACK messages when persistence enabled (#13350)
  * docs: Add generic secret store usage (#13400)
  * chore(secretstores): Clean up secret store usage (#13398)
  * docs(secretstores.os): Clarify windows credential usage (#13399)
  * chore(deps): Bump github.com/shirou/gopsutil from 3.23.4 to 3.23.5 (#13396)
  * chore(deps): Bump github.com/Mellanox/rdmamap (#13392)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts (#13391)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds (#13390)
  * chore(deps): Bump github.com/prometheus/common from 0.43.0 to 0.44.0 (#13389)
  * chore(deps): Bump github.com/urfave/cli/v2 from 2.23.5 to 2.25.5 (#13388)
  * chore: Update to go1.20.5 (#13401)
  * docs(inputs.prometheus): Add example for prometheus timestamps (#13362)
  * fix(tests): Replace last 'cat' instance in tests (#13394)
  * chore(inputs.gnmi): Test plugin and subscription options (#13384)
  * chore: Another try to fix CI (#13387)
  * docs(outputs.sql): improve the documentation (#13385)
  * feat(outputs.wavefront): Add TLS and HTTP Timeout configuration fields (#13349)
  * chore(processors.execd): Remove JSON test due to problematic 'cat' command (#13383)
  * fix(internal): Fix time parsing for abbreviated timezones (#13363)
  * chore: Add generator for sample-config includes (#13348)
  * chore(deps): Bump github.com/influxdata/influxdb-observability libraries from 0.3.3 to 0.3.15 (#13265)
  * chore: update removal and deprecations for v1.30.0 (#13351)
  * chore(config): Split tests to avoid cyclic import (#13371)
  * chore(serializers): Cleanup after migration (#13378)
  * fix(inputs.gnmi): Handle canonical field-name correctly for non-explicit subscriptions (#13332)
  * feat(inputs.sqlserver): Check SQL Server "encryptionEnforce" with xp_instance_regread (#13284)
  * chore(deps): Bump github.com/showwin/speedtest-go from 1.5.2 to 1.6.2 (#13369)
  * chore: Fix touch command (#13372)
  * feat(common.tls): Add support for passphrase-protected private key (#13262)
  * feat(inputs.netflow): Add sFlow decoder (#13047)
  * feat(agent): Add option to avoid filtering of explicit plugin tags (#13364)
  * chore(serializers.prometheus): Migrate to new-style framework (#13347)
  * chore: Produce single digest file with sha256sum (#13366)
  * fix(inputs.mysql): Update MariaDB Dialect regex version check (#13361)
  * docs: remove whitespace (#13367)
  * docs: Fix markdownlinter issues (#13365)
  * docs(inputs.cisco_telemetry_mdt): Specify max msg upper limit (#13346)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.2.6 to 2.2.7 (#13356)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.8.0 to 1.8.1 (#13355)
  * chore(deps): Bump github.com/jackc/pgtype from 1.12.0 to 1.14.0 (#13357)
  * chore(deps): Bump cloud.google.com/go/monitoring from 1.13.0 to 1.14.0 (#13359)
  * chore(serializers.wavefront): Migrate to new-style framework (#13344)
  * chore(serializers.splunkmetric): Migrate to new-style framework (#13342)
  * chore(serializers.prometheusremotewrite): Migrate to new-style framework (#13341)
  * chore(serializers.nowmetric): Migrate to new-style framework (#13340)
  * feat: Add input plugin for ctrlX Data Layer (#11155)
  * fix: remove unused imports (#13339)
  * chore(serializers.json): Migrate to new-style framework (#13335)
  * chore(serializers.msgpack): Migrate to new-style framework (#13336)
  * chore(serializers.graphite): Migrate to new-style framework (#13321)
  * feat(secretstores): Add http plugin (#13150)
  * feat(inputs.gnmi): Allow canonical field names (#13326)
  * fix(inputs.netflow): Handle PEN messages correctly (#13320)
  * chore: Create default statefile and folder during package install (#13306)
  * fix(inputs.netflow): Fix field mappings (#13325)
  * fix(outputs.wavefront): Flush metric buffer before reaching overflow (#13252)
  * chore(docs): Clarify how taginclude/tagexclude work with processors (#13243)
  * feat(config): Support shell like syntax for environment variable substitution (#13229)
  * feat(inputs.cloudwatch): Add support for cross account oberservability (#12448)
  * chore(parsers)!: Remove old-style creation (#13310)
  * feat(inputs.kafka_consumer): Add regular expression support for topics (#11831)
  * chore(serializers.csv): Migrate to new-style framework (#13319)
  * fix(inputs.gnmi): Allow optional origin for update path (#13304)
  * chore(deps): Bump github.com/jackc/pgconn from 1.13.0 to 1.14.0 (#13311)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.193 to 1.62.337 (#13312)
  * chore(deps): Bump github.com/Azure/azure-event-hubs-go/v3 from 3.4.0 to 3.5.0 (#13313)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest from 0.11.28 to 0.11.29 (#13314)
  * chore(deps): Bump k8s.io/client-go from 0.26.2 to 0.27.2 (#13315)
  * fix(processors.lookup): Do not strip tracking info (#13301)
  * fix(inputs.temp): Ignore warnings, return errors (#13307)
  * feat: Add Clarify output plugin (#13220)
  * chore(circleci): remove dry run flag (#13302)
  * Update changelog for v1.26.3
  * fix(inputs.socket_listener): Fix race in tests (#13300)
  * chore(docs): Remove repetitive "the" (#13295)
  * feat(inputs.sql): Add 'disconnected_servers_behavior' field in the configuration (#13289)
  * chore(serializers.carbon2): Migrate to new-style framework (#13291)
  * feat(inputs.nats_consumer): Add receiver subject as tag (#13293)
  * feat(inputs.kubernetes): Extend kube_inventory plugin to include and extend resourcequota, secrets, node, and pod measurement (#13040)
  * fix(inputs.socket_listener): Avoid noisy logs on closed connection (#13288)
  * chore: Enable deferInLoop, exitAfterDefer and unnecessaryDefer checkers for gocritic (#13280)
  * fix(inputs.vsphere): specify the correct option for disconnected_servers_behavior (#13286)
  * docs: Clarify watch config behavior (#13285)
  * feat(processors.template): Allow `tag` to be a template (#13253)
  * feat(inputs.sqlserver): Add Azure Arc-enabled SQL MI support (#13261)
  * fix(inputs.socket_listener): Fix loss of connection tracking (#13056)
  * feat(inputs.directory_monitor): Improve internal stats (#13089)
  * feat(test): Allow to capture all messages during test (#13275)
  * chore(deps): Bump github.com/aerospike/aerospike-client-go/v5 from 5.10.0 to 5.11.0 (#13258)
  * chore(deps): Bump go.opentelemetry.io/collector/pdata from 1.0.0-rc7 to 1.0.0-rcv0011 (#13257)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.30.0 to 1.30.1 (#13256)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2 from 1.17.8 to 1.18.0 (#13255)
  * chore(deps): Bump github.com/benbjohnson/clock from 1.3.0 to 1.3.3 (#13254)
  * chore: Enable gocritic with initial set of rules (#13247)
  * chore(deps): Bump golang.org/x/net from 0.9.0 to 0.10.0 (#13276)
  * chore(deps): Bump github.com/docker/distribution from 2.8.1 to 2.8.2 (#13269)
  * feat(processors.scale):  Add scaling by factor and offset (#13227)
  * fix(inputs.prometheus): Avoid race when creating informer factory (#13231)
  * feat(serializers): Add CloudEvents serializer (#13224)
  * feat(inputs.sql): Add FlightSQL support (#13091)
  * feat(parsers.opentsdb): Add OpenTSDB data format parser (#13167)
  * chore(deps): Bump github.com/antchfx/xpath to latest master for string-join() (#13242)
  * chore(deps): bump signalfx/golib from 3.3.46 to 3.3.50 (#13230)
  * chore(deps): Bump google.golang.org/api from 0.106.0 to 0.120.0 (#13170)
  * fix(outputs.stackdriver): Allow for custom metric type prefix (#13168)
  * fix(outputs.graphite): Fix logic to reconnect with servers that were not up on agent startup (#13228) (#13239)
  * fix(inputs.cloud_pubsub): Fix gzip decompression (#13238)
  * docs(common.kafka): Remove experimental notes (#13232)
  * chore: Update to go1.20.4 (#13226)
  * chore: Fix linter findings for Windows (part3) (#13143)
  * feat(outputs.loki): Add option for metric name label (#13157)
  * fix(outputs.stackdriver): Group batches by timestamp (#12994)
  * chore: sort go.mod (#13234)
  * feat(processors.parser): Add merge with timestamp option (#13147)
  * chore(deps): Bump prometheus from v1.8.2 to v2.42.0 (#13225)
  * chore(deps): Bump govulncheck-action from 0.10.0 to 0.10.1 (#13223)
  * feat(cloud_pubsub): Add support for gzip compression (#13094)
  * feat(inputs.statsd): Add optional temporality and start_time tag for statsd metrics (#13087)
  * feat(inputs.suricata): Add ability to parse drop or rejected (#13048)
  * chore: Finish gosec activities (#13222)
  * chore: Enable G404 rule for gosec (#13095)
  * deps(outputs.wavefront): Bump wavefront sdk from 0.12.0 to 0.13.0 (#13213)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest/adal from 0.9.22 to 0.9.23 (#13215)
  * chore(deps): Bump github.com/fatih/color from 1.13.0 to 1.15.0 (#13216)
  * chore(deps): Bump golang.org/x/oauth2 from 0.5.0 to 0.7.0 (#13217)
  * fix(outputs.prometheus_client): Fix export_timestamp for v1 metric type (#13169)
  * fix(serializers.influx): Restore disabled uint support by default (#13164)
  * feat(inputs.filecount): Add oldestFileTimestamp and newestFileTimestamp (#13163)
  * docs(inputs.vsphere): Resolve copy/paste typo with resource pools (#13162)
  * fix(processors.starlark): Ddo not reject tracking metrics twice (#13156)
  * fix(inputs.gnmi): Create selfstat to track connection state (#13149)
  * feat(aggregators.basicstats): Add percentage change (#13118)
  * feat: Add common expression language metric filtering (#13144)
  * feat(inputs.gnmi): Support Juniper GNMI Extension Header (#13116)
  * fix(inputs.intel_pmu): Fix handling of the json perfmon format (#13139)
  * chore(deps): Bump github.com/yuin/goldmark from 1.5.3 to 1.5.4 (#13138)
  * chore(deps): Bump golang.org/x/net from 0.8.0 to 0.9.0 (#13137)
  * feat(inputs.nvidia_smi): Add additional memory related fields (#13133)
  * chore: Bump golangci-lint from v1.51.2 to v1.52.2 (#13142)
  * fix: update release workflow (#13141)
  * feat(secretstores): Add Docker secrets (#13035)
  * chore: Fix linter findings for Windows (part1) (#13057)
  * docs(inputs.knx_listener): Add link to config generation project (#13128)
  * chore(deps): Bump github.com/netsampler/goflow2 from 1.1.1 to 1.3.3 (#13104)
  * chore: Fix linter findings for Windows (part2) (#13096)
  * fix(outputs.warp10): Support Infinity/-Infinity/NaN values (#13126)
  * Update changelog for v1.26.2
  * docs(inputs.mysql): remove duplicate settings from config (#13131)
  * docs: use single quotes for multi-line literal TOML (#13124)
  * chore: update license URLs (#13113)
  * chore: update golangci-lint (#13110)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.15.13 to 1.20.9 (#13107)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.13.15 to 1.13.20 (#13106)
  * chore(deps): Bump github.com/docker/docker from 23.0.0 to 23.0.4 (#13105)
  * feat(inputs.vsphere): Adding vSAN extension to vSphere plugin (#11955)
  * feat(processors): Adding scale processor plugin (#13061)
  * fix(processors.lookup): Fix tracking metrics (#13092)
  * feat(processors.aws_ec2): Add caching of imds and ec2 tags (#13075)
  * chore: Enable G110 rule for gosec (#13044)
  * fix(inputs.socket_listener): Fix TLS socket initialization(#13050)
  * test: Check correct build tags for each plugin registered (#13019)
  * fix(parsers.grok): Fix nil metric for multiline inputs (#13078)
  * fix(inputs.prometheus): Add namespace option in k8s informer factory (#13063)
  * chore: Enable G601 rule for gosec (#13042)
  * chore: Enable G103 rule for gosec (#13038)
  * chore(serializers): Add new-style framework and migrate influx (#12920)
  * fix: Correct spelling of "fingerprints" in circleci config (#13074)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatch from 1.21.6 to 1.25.9 (#13072)
  * chore(deps): Bump github.com/wavefronthq/wavefront-sdk-go from 0.11.0 to 0.12.0 (#13070)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts from 1.18.5 to 1.18.9 (#13069)
  * chore(deps): Bump github.com/vishvananda/netns from 0.0.2 to 0.0.4 (#13071)
  * fix(inputs.socket_listener): Fix tracking of unix sockets (#13059)
  * chore: Update to go1.20.3 (#13055)
  * feat: implement remote artifact signing (#13066)
  * chore: Update lxd images for testing (#13064)
  * chore: Enable G303 and G305 rules for gosec (#13039)
  * chore: Enable G301, G302 and G306 rules for gosec (#13022)
  * fix(agent): pass quiet flag earlier (#13020)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis (#13027)
  * chore(deps): Bump github.com/prometheus/common from 0.41.0 to 0.42.0 (#13026)
  * chore(deps): Bump github.com/safchain/ethtool from 0.2.0 to 0.3.0 (#13025)
  * chore(deps): Bump github.com/tinylib/msgp from 1.1.6 to 1.1.8 (#13023)
  * chore(deps): Bump github.com/openconfig/gnmi from 0.0.0-20220920173703-480bf53a74d2 to 0.9.1 (#13024)
  * chore: Update README.md (#12989)
  * chore: Enable G401, G403, G501, G502, G503 and G505 rules for gosec (#13021)
  * Update changelog for v1.26.1
  * feat(serializer.prometheusremote): Improve performance (#12971)
  * chore: Enable G101 rule for gosec (#13009)
  * chore: Enable G107 rule for gosec (#13010)
  * fix(inputs.procstat): Return tags of pids if lookup_error (#13015)
  * chore(deps): Bump github.com/shirou/gopsutil from 3.23.2 to 3.23.3 (#13017)
  * fix(inputs.netflow): Use correct name in the build tag (#13006)
  * fix(secrets): Minimize secret holding time (#13002)
  * chore: Enable G112 and G114 rules for gosec (#12986)
  * chore: Enable G202 rule for gosec (#12984)
  * chore(deps): Bump github.com/opencontainers/runc from 1.1.4 to 1.1.5 (#12981)
  * chore: Remove `revive:unhandled-error` - `errcheck` is more flexible (#13008)
  * fix(inputs.sqlserver): Converted THROW to RAISERROR for 2008 compatibility
  * fix(secretstores): Handle array of secrets correctly (#12919)
  * fix(secret): Add function to set a secret (#13012)
  * fix(secrets): Warn if OS limit for locked memory is too low (#12993)
  * feat(inputs.prometheus): Control which pod metadata is added as tags (#12851)
  * feat(inputs.internet_speed): Support multi-server test (#12797)
  * chore: run make docs
  * docs(outputs.http): add service to aws creds (#13003)
  * fix(systemd): Increase lock memory for service to 8192kb (#12990)
  * chore: Don't use all default exclude patterns for golangci-lint (#12969)
  * chore: Enable G102 rule for gosec (#12976)
  * chore(deps): Bump github.com/jhump/protoreflect from 1.8.3-0.20210616212123-6cc1efa697ca to 1.15.1 (#12967)
  * fix(inputs.upsd): Include ups.real_power (#12961)
  * fix(inputs.execd): Read from stdout using ReadLine instead of scanner.Scan to overcome 64kb buffer limit (#12935)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest/azure/auth (#12966)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.7.0 to 1.8.0 (#12968)
  * chore(deps): Bump github.com/golang-jwt/jwt/v4 from 4.4.2 to 4.5.0 (#12964)
  * fix(govulncheck): Downgrade govulncheck to fix github action (#12973)
  * docs(inputs.upsd): Add comment about ipv6 addresses (#12962)
  * chore: Fix linter findings for Darwin (#12958)
  * chore: Enable G106, G108, G109, G111, G201, G203 rules for gosec (#12956)
  * chore: Fix gosec G102 issues (#12923)
  * docs: Explain and note service inputs (#12870)
  * chore(deps): Bump govulncheck-action from 0.0.9 to 0.10.0 (#12927)
  * docs: Remove broken link to default config (#12925)
  * feat(inputs.kubernetes): Apply timeout for the whole HTTP request (#12918)
  * fix(outputs.graphite): Add custom regex to outputs (#12908)
  * fix(inputs.ethtool): Check for nil (#12867)
  * chore: go mod tidy (#12922)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.2.4 to 2.2.6 (#12913)
  * chore(deps): Bump golang.org/x/net from 0.7.0 to 0.8.0 (#12912)
  * chore(deps): Bump github.com/tidwall/gjson from 1.14.3 to 1.14.4 (#12911)
  * chore(deps): Bump modernc.org/sqlite from 1.19.2 to 1.21.0 (#12910)
  * chore(deps): Bump github.com/apache/thrift from 0.16.0 to 0.18.1 (#12909)
  * fix(inputs.prometheus): Use set over add for custom headers (#12907)
  * chore: Update circleci macos runners (#12887)
  * fix(config): Return error on order set as string (#12880)
  * docs: Fix various typos in comments (#12888)
  * feat(common.opcua): Add support for secret-store secrets (#12863)
  * docs: Add homekit plugin as external plugin (#12874)
  * docs(agent): resolve typo (#12884)
  * docs(typo): update wording (#12885)
  * chore: Update default folder locations to match packaging (#12865)
  * fix(inputs.prometheus): Correctly set timeout param (#12864)
  * docs: Update minimum documented go version (#12869)
  * chore: Ensure go generate runs on all platforms (#12871)
  * fix(inputs.internet_speed): Rename host tag to source (#12877)
  * docs(typo): output.go (#12873)
  * docs: update change log format (#12872)
  * chore(deps): Bump github.com/Azure/azure-event-hubs-go/v3 from 3.3.20 to 3.4.0 (#12856)
  * chore(deps): Bump github.com/antchfx/xpath from 1.2.3 to 1.2.4 (#12857)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.19.0 to 1.24.0 (#12855)
  * chore(deps): Bump github.com/sensu/sensu-go/api/core/v2 from 2.15.0 to 2.16.0 (#12854)
  * chore(deps): Bump github.com/Shopify/sarama from 1.37.2 to 1.38.1 (#12853)
  * fix(serializers.graphite): Allow for specifying regex to sanitize (#12835)
  * Update changelog for v1.26.0
  * Update build version to 1.27.0
* Mon May 22 2023 mrueckert@suse.de
- Update to version 1.26.3:
  * Telegraf v1.26.3
  * Update changelog for v1.26.3
  * Update build_version.txt for v1.26.3
  * fix(inputs.socket_listener): Fix race in tests (#13300)
  * chore(docs): Remove repetitive "the" (#13295)
  * chore: Enable deferInLoop, exitAfterDefer and unnecessaryDefer checkers for gocritic (#13280)
  * fix(inputs.vsphere): specify the correct option for disconnected_servers_behavior (#13286)
  * docs: Clarify watch config behavior (#13285)
  * fix(inputs.socket_listener): Fix loss of connection tracking (#13056)
  * chore(deps): Bump github.com/aerospike/aerospike-client-go/v5 from 5.10.0 to 5.11.0 (#13258)
  * chore(deps): Bump go.opentelemetry.io/collector/pdata from 1.0.0-rc7 to 1.0.0-rcv0011 (#13257)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.30.0 to 1.30.1 (#13256)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2 from 1.17.8 to 1.18.0 (#13255)
  * chore(deps): Bump github.com/benbjohnson/clock from 1.3.0 to 1.3.3 (#13254)
  * chore: Enable gocritic with initial set of rules (#13247)
  * chore(deps): Bump golang.org/x/net from 0.9.0 to 0.10.0 (#13276)
  * chore(deps): Bump github.com/docker/distribution from 2.8.1 to 2.8.2 (#13269)
  * chore(deps): Bump github.com/antchfx/xpath to latest master for string-join() (#13242)
  * chore(deps): bump signalfx/golib from 3.3.46 to 3.3.50 (#13230)
  * chore(deps): Bump google.golang.org/api from 0.106.0 to 0.120.0 (#13170)
  * fix(outputs.stackdriver): Allow for custom metric type prefix (#13168)
  * fix(outputs.graphite): Fix logic to reconnect with servers that were not up on agent startup (#13228) (#13239)
  * docs(common.kafka): Remove experimental notes (#13232)
  * chore: Update to go1.20.4 (#13226)
  * chore: Fix linter findings for Windows (part3) (#13143)
  * fix(outputs.stackdriver): Group batches by timestamp (#12994)
  * chore(deps): Bump prometheus from v1.8.2 to v2.42.0 (#13225)
  * chore(deps): Bump govulncheck-action from 0.10.0 to 0.10.1 (#13223)
  * chore: Finish gosec activities (#13222)
  * chore: Enable G404 rule for gosec (#13095)
  * deps(outputs.wavefront): Bump wavefront sdk from 0.12.0 to 0.13.0 (#13213)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest/adal from 0.9.22 to 0.9.23 (#13215)
  * chore(deps): Bump github.com/fatih/color from 1.13.0 to 1.15.0 (#13216)
  * chore(deps): Bump golang.org/x/oauth2 from 0.5.0 to 0.7.0 (#13217)
  * fix(outputs.prometheus_client): Fix export_timestamp for v1 metric type (#13169)
  * docs(inputs.vsphere): Resolve copy/paste typo with resource pools (#13162)
  * fix(processors.starlark): Ddo not reject tracking metrics twice (#13156)
  * fix(inputs.gnmi): Create selfstat to track connection state (#13149)
  * fix(inputs.intel_pmu): Fix handling of the json perfmon format (#13139)
  * chore(deps): Bump github.com/yuin/goldmark from 1.5.3 to 1.5.4 (#13138)
  * chore(deps): Bump golang.org/x/net from 0.8.0 to 0.9.0 (#13137)
  * chore: Bump golangci-lint from v1.51.2 to v1.52.2 (#13142)
  * fix: update release workflow (#13141)
  * chore: Fix linter findings for Windows (part1) (#13057)
  * docs(inputs.knx_listener): Add link to config generation project (#13128)
  * chore(deps): Bump github.com/netsampler/goflow2 from 1.1.1 to 1.3.3 (#13104)
  * chore: Fix linter findings for Windows (part2) (#13096)
  * fix(outputs.warp10): Support Infinity/-Infinity/NaN values (#13126)
* Mon Apr 24 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Use _service mode manual as better alias name than disabled
* Mon Apr 24 2023 mrueckert@suse.de
- Update to version 1.26.2:
  * Telegraf v1.26.2
  * Update changelog for v1.26.2
  * Update build_version.txt for v1.26.2
  * docs(inputs.mysql): remove duplicate settings from config (#13131)
  * docs: use single quotes for multi-line literal TOML (#13124)
  * chore: update license URLs (#13113)
  * chore: update golangci-lint (#13110)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.15.13 to 1.20.9 (#13107)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.13.15 to 1.13.20 (#13106)
  * chore(deps): Bump github.com/docker/docker from 23.0.0 to 23.0.4 (#13105)
  * fix(processors.lookup): Fix tracking metrics (#13092)
  * chore: Enable G110 rule for gosec (#13044)
  * test: Check correct build tags for each plugin registered (#13019)
  * fix(parsers.grok): Fix nil metric for multiline inputs (#13078)
  * fix(inputs.prometheus): Add namespace option in k8s informer factory (#13063)
  * chore: Enable G601 rule for gosec (#13042)
  * chore: Enable G103 rule for gosec (#13038)
  * fix: Correct spelling of "fingerprints" in circleci config (#13074)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatch from 1.21.6 to 1.25.9 (#13072)
  * chore(deps): Bump github.com/wavefronthq/wavefront-sdk-go from 0.11.0 to 0.12.0 (#13070)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts from 1.18.5 to 1.18.9 (#13069)
  * chore(deps): Bump github.com/vishvananda/netns from 0.0.2 to 0.0.4 (#13071)
  * fix(inputs.socket_listener): Fix tracking of unix sockets (#13059)
  * chore: Update to go1.20.3 (#13055)
  * feat: implement remote artifact signing (#13066)
  * chore: Update lxd images for testing (#13064)
  * chore: Enable G303 and G305 rules for gosec (#13039)
  * chore: Enable G301, G302 and G306 rules for gosec (#13022)
  * fix(agent): pass quiet flag earlier (#13020)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis (#13027)
  * chore(deps): Bump github.com/prometheus/common from 0.41.0 to 0.42.0 (#13026)
  * chore(deps): Bump github.com/safchain/ethtool from 0.2.0 to 0.3.0 (#13025)
  * chore(deps): Bump github.com/tinylib/msgp from 1.1.6 to 1.1.8 (#13023)
  * chore(deps): Bump github.com/openconfig/gnmi from 0.0.0-20220920173703-480bf53a74d2 to 0.9.1 (#13024)
  * chore: Update README.md (#12989)
  * chore: Enable G401, G403, G501, G502, G503 and G505 rules for gosec (#13021)
* Mon Apr  3 2023 mrueckert@suse.de
- Update to version 1.26.1:
  * Telegraf v1.26.1
  * Update changelog for v1.26.1
  * Update build_version.txt for v1.26.1
  * chore: Enable G101 rule for gosec (#13009)
  * chore: Enable G107 rule for gosec (#13010)
  * fix(inputs.procstat): Return tags of pids if lookup_error (#13015)
  * Make docs.
  * chore(deps): Bump github.com/shirou/gopsutil from 3.23.2 to 3.23.3 (#13017)
  * fix(inputs.netflow): Use correct name in the build tag (#13006)
  * fix(secrets): Minimize secret holding time (#13002)
  * chore: Enable G112 and G114 rules for gosec (#12986)
  * chore: Enable G202 rule for gosec (#12984)
  * chore(deps): Bump github.com/opencontainers/runc from 1.1.4 to 1.1.5 (#12981)
  * chore: Remove `revive:unhandled-error` - `errcheck` is more flexible (#13008)
  * fix(secretstores): Handle array of secrets correctly (#12919)
  * fix(secret): Add function to set a secret (#13012)
  * fix(secrets): Warn if OS limit for locked memory is too low (#12993)
  * docs(outputs.http): add service to aws creds (#13003)
  * fix(systemd): Increase lock memory for service to 8192kb (#12990)
  * chore: Don't use all default exclude patterns for golangci-lint (#12969)
  * chore: Enable G102 rule for gosec (#12976)
  * chore(deps): Bump github.com/jhump/protoreflect from 1.8.3-0.20210616212123-6cc1efa697ca to 1.15.1 (#12967)
  * fix(inputs.upsd): Include ups.real_power (#12961)
  * fix(inputs.execd): Read from stdout using ReadLine instead of scanner.Scan to overcome 64kb buffer limit (#12935)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest/azure/auth (#12966)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.7.0 to 1.8.0 (#12968)
  * chore(deps): Bump github.com/golang-jwt/jwt/v4 from 4.4.2 to 4.5.0 (#12964)
  * fix(govulncheck): Downgrade govulncheck to fix github action (#12973)
  * docs(inputs.upsd): Add comment about ipv6 addresses (#12962)
  * chore: Fix linter findings for Darwin (#12958)
  * chore: Enable G106, G108, G109, G111, G201, G203 rules for gosec (#12956)
  * chore: Fix gosec G102 issues (#12923)
  * docs: Explain and note service inputs (#12870)
  * chore(deps): Bump govulncheck-action from 0.0.9 to 0.10.0 (#12927)
  * docs: Remove broken link to default config (#12925)
  * feat(inputs.kubernetes): Apply timeout for the whole HTTP request (#12918)
  * fix(outputs.graphite): Add custom regex to outputs (#12908)
  * fix(inputs.ethtool): Check for nil (#12867)
  * chore: go mod tidy (#12922)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.2.4 to 2.2.6 (#12913)
  * chore(deps): Bump golang.org/x/net from 0.7.0 to 0.8.0 (#12912)
  * chore(deps): Bump github.com/tidwall/gjson from 1.14.3 to 1.14.4 (#12911)
  * chore(deps): Bump modernc.org/sqlite from 1.19.2 to 1.21.0 (#12910)
  * chore(deps): Bump github.com/apache/thrift from 0.16.0 to 0.18.1 (#12909)
  * fix(inputs.prometheus): Use set over add for custom headers (#12907)
  * chore: Update circleci macos runners (#12887)
  * fix(config): Return error on order set as string (#12880)
  * docs: Fix various typos in comments (#12888)
  * docs: Add homekit plugin as external plugin (#12874)
  * docs(agent): resolve typo (#12884)
  * docs(typo): update wording (#12885)
  * chore: Update default folder locations to match packaging (#12865)
  * fix(inputs.prometheus): Correctly set timeout param (#12864)
  * docs: Update minimum documented go version (#12869)
  * chore: Ensure go generate runs on all platforms (#12871)
  * fix(inputs.internet_speed): Rename host tag to source (#12877)
  * docs(typo): output.go (#12873)
  * docs: update change log format (#12872)
  * chore(deps): Bump github.com/Azure/azure-event-hubs-go/v3 from 3.3.20 to 3.4.0 (#12856)
  * chore(deps): Bump github.com/antchfx/xpath from 1.2.3 to 1.2.4 (#12857)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.19.0 to 1.24.0 (#12855)
  * chore(deps): Bump github.com/sensu/sensu-go/api/core/v2 from 2.15.0 to 2.16.0 (#12854)
  * chore(deps): Bump github.com/Shopify/sarama from 1.37.2 to 1.38.1 (#12853)
  * fix(serializers.graphite): Allow for specifying regex to sanitize (#12835)
* Tue Mar 14 2023 Marcus Rueckert <mrueckert@suse.de>
- Add memory constraint with 6G
* Mon Mar 13 2023 mrueckert@suse.de
- Update to version 1.26.0:
  * Telegraf v1.26.0
  * Update changelog for v1.26.0
  * chore(deps): Bump github.com/opencontainers/runc from 1.1.3 to 1.1.4 (#12852)
  * fix(makefile): Re-add build tags flag to go build (#12847)
  * chore(deps): Update OpenTelemetry from 0.3.1 to 0.3.3 (#12840)
  * feat(inputs.vsphere): Flag for more lenient behavior when connect fails on startup (#12828)
  * feat(inputs.modbus): Allow to convert coil and discrete registers to boolean (#12825)
  * feat(common.oauth): Add audience parameter (#12821)
  * feat(parsers.xpath): Add timezone handling (#12820)
  * chore: add service input stub to Windows event log, not windows (#12837)
  * feat(agent): Print loaded configs (#12827)
  * chore: Update to go1.20.2 (#12824)
  * chore(deps): Bump github.com/shirou/gopsutil from v3.22.12 to v3.23.2 (#12822)
  * docs(outputs.postgresql): Improve TimescaleDB config examples (#12829)
  * feat(processors.converter): Convert tag or field as metric timestamp (#12767)
  * feat(inputs.radius): Add plugin for simple radius auth response time monitoring (#12736)
  * docs(inputs.vsphere): Update inventory docs & removed unnecessary if-statement (#12819)
  * fix(inputs.amqp_consumer): Avoid deprecations when handling defaults (#12818)
  * fix(inputs.amqp_consumer): Fix panic on Stop() if not connected successfully (#12817)
  * fix(inputs.ethtool): Close namespace (#12815)
  * feat(inputs.ethtool): Add support for link speed, duplex, autoneg and… (#12814)
  * feat(agent): Add command-line option to specify password (#12812)
  * feat(processors): Add lookup processor (#12809)
  * feat(inputs.win_eventlog): Add state-persistence capabilities (#12790)
  * chore(deps): Bump github.com/opensearch-project/opensearch-go/v2 from 2.1.0 to 2.2.0 (#12806)
  * feat(inputs.modbus): Add RS485 specific config options (#12786)
  * chore(deps): Bump cloud.google.com/go/storage from 1.28.1 to 1.29.0 (#12805)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest/adal (#12804)
  * chore(deps): Bump github.com/stretchr/testify from 1.8.1 to 1.8.2 (#12807)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials (#12808)
  * docs: Use already existing link to fix markdownlint issue. (#12810)
  * feat(inputs.cgroup): Added support for cpu.stat (#12798)
  * chore(deps): Downgrade github.com/karrick/godirwalk from v1.17.0 to v1.16.2 (#12801)
  * docs: Clean up make docs on windows (#12796)
  * chore(secretstores.os): Unify config (#12791)
  * chore: Unify sample configs across OSes (#12789)
  * feat(inputs.prometheus): Use namespace annotations to filter pods to be scraped (#12777)
  * chore: run make docs (#12802)
  * feat(inputs.docker_log): Add state-persistence capabilities (#12775)
  * chore: Fix linter findings for errorlint (part8) (#12785)
  * docs: Add optional tls parameters to the documentation (#12788)
  * chore: Specify distro support (part 3) (#12792)
  * docs: Update the FAQ (#12793)
  * chore: Use type on powershell/command prompt only (#12794)
  * chore: Remove usages of github.com/pkg/errors dependency (archived) (#12787)
  * fix(inputs.statsd): On close, verify listener is not nil (#12778)
  * chore: Fix linter findings for errorlint (part7) (#12772)
  * chore: Bump golangci-lint from v1.51.0 to v1.51.2 (#12782)
  * chore: only run govulncehck on master
  * chore(CI): Add govulncheck Github action (#12783)
  * feat(parsers.avro): Add Apache Avro parser (#11816)
  * fix(agent): Allow gracefull shutdown on interrupt (e.g. Ctrl-C) (#12781)
  * feat: Plugin state-persistence (#12166)
  * chore: Generate config at build time (#12766)
  * chore: Document linux only plugins (part 2) (#12765)
  * chore: Document linux only plugins (part 1) (#12764)
  * chore: Fix linter findings for errorlint (part6) (#12733)
  * chore: Fix linter findings for errorlint (part5) (#12731)
  * fix(agent): Only rotate log on SIGHUP if needed (#12740)
  * chore: Remove windows specific config (#12763)
  * docs(aggregators.derivative): Add explanation of calculations (#12758)
  * chore: Enable printing Windows sample configs on non-Windows (#12741)
  * chore: Stop generating the nightly config (#12742)
  * feat(outputs.mqtt): Add option to specify topic layouts (#12697)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.62.77 to 1.62.193 (#12757)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/timestreamwrite from 1.14.5 to 1.16.0 (#12756)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.5.0 to 1.7.0 (#12755)
  * chore(deps): Bump github.com/coocood/freecache from 1.2.2 to 1.2.3 (#12754)
  * chore(deps): Bump github.com/openzipkin-contrib/zipkin-go-opentracing from 0.4.5 to 0.5.0 (#12753)
  * docs: rename playfabtotelegraf external plugin (#12759)
  * Update changelog for v1.25.3
  * feat(common.tls): add enable flag (#12727)
  * feat(inputs.jti_openconfig_telemetry): Set timestamp from data (#12730)
  * fix(serializers.json): allow stateful transformations (#12735)
  * fix(inputs.lvm): add options to specify path to binaries (#12725)
  * feat(inputs.wireguard): Add allowed_peer_cidr field (#12729)
  * chore: eliminate unnecessary use of quoted strings in printf (#12722)
  * fix(parsers.xpath): Fix panic for JSON name expansion (#12724)
  * feat(inputs.internet_speed): Add the best server selection via latency and jitter field (#12707)
  * chore: Fix linter findings for errorlint (part4) (#12723)
  * feat(inputs.win_wmi): add Windows Management Instrumentation (WMI) input plugin (#11250)
  * fix(agent): Reload config on config update (#12721)
  * feat(inputs.disk): Add label as tag (#12696)
  * test(inputs.x509_cert): fix missing tag (#12720)
  * feat(inputs.x509_cert): Add tag for certificate type-classification (#12656)
  * chore: Fix linter findings for errorlint (part3) (#12704)
  * chore: Fix linter findings for errorlint (part1) (#12701)
  * chore(deps): Bump github.com/go-logfmt/logfmt from 0.5.1 to 0.6.0 (#12715)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.27.1 to 1.28.0 (#12714)
  * chore(deps): Bump google.golang.org/grpc from 1.52.3 to 1.53.0 (#12713)
  * chore(deps): Bump github.com/gophercloud/gophercloud from 1.0.0 to 1.2.0 (#12712)
  * chore: Fix linter findings for errorlint (part2) (#12702)
  * chore(deps): Bump golang.org/x/net from 0.5.0 to 0.7.0 (#12699)
  * chore(inputs.net_response): Use Init to check configuration issues (#12690)
  * docs(readme): add PlayFab Insights external plugin (#12708)
  * docs(parsers.json_v2): fix spelling typo (#12711)
  * feat(inputs.statsd): add pending messages stat and allow to configure number of threads (#12318)
  * chore: mention make lint in PR template and contributing doc (#12703)
  * chore(mqtt): unify input and output plugin's MQTT client (#12683)
  * feat(inputs.haproxy): Add support for tcp endpoints in haproxy plugin (#12680)
  * chore(deps): Bump testcontainers from 0.14.0 to 0.18.0 (#12698)
  * chore(deps): Bump github.com/containerd/containerd from 1.6.8 to 1.6.18 (#12693)
  * feat(inputs.x509_cert): Add OCSP stapling information for leaf certificates (#10550) (#12444)
  * docs(outputs.postgresql): Update URL for sql template (#12691)
  * feat(config): Accept durations given in days (e.g. "7d") (#12579)
  * feat(outputs.mqtt): add support for MQTT 5 publish properties (#12678)
  * chore: Update to go1.20.1 (#12679)
  * chore(deps): Bump github.com/gofrs/uuid from 4.3.1+incompatible to 5.0.0 (#12668)
  * fix(inputs.bond): Reset slave stats for each interface (#12462)
  * fix(inputs.cloudwatch): Verify endpoint is not nil (#12677)
  * feat(processors.unpivot): Add mode to create new metrics (#12659)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.1.5 to 2.2.4 (#12667)
  * chore(deps): Bump k8s.io/apimachinery from 0.25.3 to 0.25.6 (#12669)
  * chore(deps): Bump golang.org/x/sys from 0.4.0 to 0.5.0 (#12670)
  * Update changelog for v1.25.2
  * chore(deps): Bump github.com/antchfx/xmlquery from 1.3.12 to 1.3.15 (#12634)
  * docs: Tracking metrics (#12663)
  * fix(inputs.x509_cert): Fix Windows path handling (#12629)
  * fix(inputs.cloudwatch): enable custom endpoint support (#12657)
  * test: Use `t.Setenv` to set env vars (#12621)
  * fix: Rename the Prometheus Input Plugin Timeout variable (#12626)
  * docs: remove trailing whitespace (#12660)
  * docs: fix remaining markdownlinter issues (#12658)
  * docs: remove whitespace (#12655)
  * chore: Prevent RPM from changing permissions on telegraf.d (#12643)
  * chore(deps): Bump github.com/antchfx/xpath from 1.2.2 to 1.2.3 (#12633)
  * chore(deps): Bump github.com/moby/ipvs from 1.0.2 to 1.1.0 (#12632)
  * chore(deps): Bump google.golang.org/grpc from 1.52.0 to 1.52.3 (#12631)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.44.0 to 1.45.0 (#12630)
  * docs: Update all readme to pass linter (#12615)
  * feat(inputs.http_listener_v2): Add custom server http headers (#12645)
  * fix(inputs.gnmi): Handle both new-style `tag_subscription` and old-style `tag_only` (#12512)
  * fix(inputs.cisco_telemetry_mdt): check subfield sizes to avoid panics (#12637)
  * fix(inputs.tail): fix typo in the README (#12648)
  * docs(inputs.syslog): add BSD syslog to readme intro (#12647)
  * fix(secretstores): check store id format and presence (#12644)
  * feat(inputs.internet_speed): server ID include and exclude filter (#12617)
  * docs(inputs.procstat): add ppid field (#12641)
  * docs(inputs.snmp): Explain different snmp backends (#12627)
  * chore: Update OpenTelemetry (#12638)
  * chore: Fix linter findings for tenv (#12622)
  * chore: Fix linter findings for nolintlint (part3) (#12613)
  * chore: Show file names and line numbers for found issues in github action logs (#12618)
  * feat(agent): Add /etc/telegraf/telegraf.d to default config locations (#12608)
  * fix(inputs.conntrack): Resolve segfault when setting collect field (#12603)
  * feat(inputs.p4runtime): Implementation of P4Runtime input plugin (#12473)
  * docs: Show TOML inline table syntax for tags/tagpass/tagdrop (#12636)
  * feat(inputs.processes): Add `use_sudo` option for BSD (#12628)
  * docs(inputs.prometheus): fix incorrect headers option (#12625)
  * fix(agent): Only read the config once (#12607)
  * chore: bump go to 1.20 for golangci-lint-action (#12614)
  * chore: Bump golangci-lint from v1.50.1 to v1.51.0 (#12605)
  * fix(inputs.mongodb): SIGSEGV when restarting MongoDB node (#12604)
  * feat: Always disable cgo support (static builds) (#12600)
  * chore: Update to go1.20 (#12593)
  * fix(inputs.mongodb): Improve error logging (#12599)
  * docs: indicate secret-store support in plugin READMEs (#12592)
  * feat(inputs.opensearch_query): add opensearch_query input plugin (#12393)
  * chore: Lint whole codebase both in PR and master branch (#12590)
  * docs(inputs.postgresql): Provide socket connection details (#12584)
  * feat(inputs.example): Add secret-store sample code (#12550)
  * feat(inputs.mysql): add secret-store support (#12591)
  * chore: clean up import shadowing issues (#12588)
  * chore(internal.gzip): cleanup CompressWithGzip (#12587)
  * chore(inputs.opentelemetry): Update OpenTelemetry input plugin (#12561)
  * fix(docs): fix link to license for Google flatbuffers (#12586)
  * chore(deps): google.golang.org/grpc v1.51.0 to v1.52.0 (#12583)
  * chore(deps): update golang/x dependencies (#12582)
  * chore(deps): update github.com/prometheus/client_golang from 1.13.1 to 1.14.0 (#12581)
  * chore(deps): update gopsutil dependency from 3.22.9 to 3.22.12 (#12580)
  * chore(inputs.x509_cert): fix linter warning (#12577)
  * fix(inputs.mysql): avoid side-effects for TLS between plugin instances (#12576)
  * fix(inputs.upsd): Add additional fields (#12543)
  * fix(outputs.prometheus_client): Expire with ticker, not add/collect (#12560)
  * chore(deps): Bump github.com/multiplay/go-ts3 from 1.0.1 to 1.1.0 (#12572)
  * chore(deps): Bump github.com/coreos/go-semver from 0.3.0 to 0.3.1 (#12571)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.11.0 to 1.11.1 (#12570)
  * chore(deps): Bump github.com/99designs/keyring from 1.2.1 to 1.2.2 (#12568)
  * Update changelog for v1.25.1
  * fix(inputs.opcua): fix opcua and opcua-listener for servers using password-based auth (#12529)
  * fix(inputs.prometheus): Set the timeout for slow running API endpoints correctly (#12559)
  * feat(inputs.win_perf_counters): add remote system support (#12556)
  * feat(inputs.gnmi): Set max gRPC message size (#12495)
  * fix(inputs.exec): restore pre-v1.21 behavior for CSV data_format (#12533)
  * chore(deps): Bump github.com/kardianos/service from 1.2.1 to 1.2.2 (#12418)
  * Revert "chore: update windows signing script (#12524)" (#12555)
  * fix(inputs.sqlserver): Suppress error on secondary replicas (#12528)
  * chore: Fix linter findings for nolintlint (part2) (#12430)
  * feat(inputs.icinga2): Support collecting hosts,services and endpoint metrics (#12506)
  * fix(inputs.upsd): Always convert to float (#12516)
  * chore: Update package repo GPG key (#12546)
  * chore: Update package repo GPG key (#12544)
  * chore: fix linter findings for nolintlint part 1 (#12427)
  * docs(outputs.elasticsearch): detail overriding timezone (#12551)
  * docs(outputs.mqtt): update readme to match sample config (#12552)
  * feat(secretstores): convert many output plugins (#12497)
  * feat(inputs.cisco_telemetry_mdt): include delete field (#12345)
  * docs(outputs.mqtt): fix incorrect use of brackets (#12539)
  * fix(agent): catch non-existing commands and error out (#12549)
  * chore: update package testing from f35 to f37 (#12548)
  * chore(deps): Bump github.com/karrick/godirwalk from 1.16.1 to 1.17.0 (#12417)
  * chore(deps): bump github.com/antchfx/jsonquery from 1.3.0 to 1.3.1 (#12511)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 (#12538)
  * fix(inputs.logstash): Collect opensearch specific stats (#12536)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2 from 1.17.1 to 1.17.3 (#12420)
  * fix(inputs.prometheus): correctly track deleted pods (#12522)
  * feat(inputs.dns_query): Add IP field(s) (#12519)
  * chore: update windows signing script (#12524)
  * feat(intel_powerstat): Add CPU base frequency metric and add support for new platforms (#12452)
  * chore: Run make docs with various GOOS (#12503)
  * fix(common.cookie): Allow any 2xx status code (#12515)
  * feat(inputs.redfish): Add power control metric (#12496)
  * feat(inputs.openweathermap): Add snow parameter (#12466)
  * feat(outputs.mqtt): enhance routing capabilities (#12224)
  * test(inputs.snmp): Use random port (#12464)
  * feat(tools/readme_linter): Check for global configuration section (#12426)
  * fix(inputs.upsd): Ensure firmware is always a string (#12486)
  * docs(inputs.influxdb): Collect v2 with prometheus plugin (#12492)
  * feat(inputs.influxdb): Collect uptime statistics (#12493)
  * fix(inputs.cisco_telemetry_mdt): add operation-metric and class-policy prefix (#12240)
  * fix(json_v2): In case of invalid json, log messsage to debug log (#12440)
  * chore(deps): update github.com/denisenkom/go-mssqldb from 0.12.0 to 0.12.3 (#12476)
  * docs(secretstores): document systemd-nspawn requirement (#12494)
  * chore: update to go1.19.5 (#12498)
  * fix(secretstores): fix handling of TOML strings (#12490)
  * fix(agent): handle float time with fractions of seconds correctly (#12491)
  * fix(agent): Only set default snmp after reading all configs (#12457)
  * docs(inputs.example): correctly set syntax highlighting and section name (#12471)
  * docs(inputs.socketstat): fix wrong TOML option name. (#12482)
  * fix(inputs.win_eventlog): Handle remote events more robustly. (#12375)
  * fix(inputs.sqlserver): add more precise version check (#12384)
  * chore(stackdriver): Fix deprecated monitoringpb (#12424)
  * feat(inputs.modbus): add workaround to enforce reads from zero for coil registers (#12408)
  * fix(inputs.gnmi): update configuration documentation (#12415)
  * feat(secretstores): add support for additional input plugins (#12067)
  * feat(inputs.sqlserver): get database pages performance counter  (#12400)
  * fix(secretstores): Fix handling of 'id' and print failing secret-store (#12468)
  * feat(kafka): Add keep-alive period setting for input and output. (#12459)
  * fix(agent): Correctly reload configuration files (#12453)
  * docs: add tado input (#12411)
  * chore: update influxdb-observability to fix statsd bug (#12429)
  * docs(inputs.postgresql): update readme and samples to note timeout behavior (#12446)
  * chore: Fix linter findings for makezero (part4) (#12410)
  * fix(inputs.mysql): Revert slice declarations with non-zero initial length (#12409)
  * fix: Added own SPID filter to sqlserverqueries.go (#12387)
  * fix(inputs.sqlserver): SqlRequests include sleeping sessions with open transactions (#12386)
  * chore(linter): disable linter warning for freeze() in starlark (#12406)
  * fix(outputs.loki): return response body on error (#12399)
  * chore: Do not start service on deb install (#12405)
  * fix(inputs.x509_cert): fix off-by-one when adding intermediate certificates (#12404)
  * test: Always create test config for package testing (#12390)
  * fix(secretstores): cleanup duplicate printing (#12401)
  * docs: add bacnet to external plugins list (#12394)
  * test(parsers.json): add fuzz test (#12368)
  * chore(deps): Bump cloud.google.com/go/storage from 1.23.0 to 1.28.1 (#12385)
  * chore(deps): bump github.com/nats-io/nats-server/v2 from 2.9.4 to 2.9.9 (#12379)
  * chore(deps): bump github.com/eclipse/paho.mqtt.golang (#12378)
  * feat(inputs.stackdriver): Allow filtering by resource metadata labels (#12377)
  * chore(deps): bump github.com/hashicorp/consul/api from 1.15.2 to 1.18.0 (#12381)
  * chore(changelog): add missing blank line
  * Update changelog for v1.25.0
  * Update build version to 1.26.0
* Tue Feb 28 2023 mrueckert@suse.de
- Update to version 1.25.3:
  * Telegraf v1.25.3
  * Update changelog for v1.25.3
  * Update build_version.txt for v1.25.3
  * Update go.mod
  * fix(serializers.json): allow stateful transformations (#12735)
  * fix(inputs.lvm): add options to specify path to binaries (#12725)
  * chore: eliminate unnecessary use of quoted strings in printf (#12722)
  * fix(parsers.xpath): Fix panic for JSON name expansion (#12724)
  * chore: Fix linter findings for errorlint (part4) (#12723)
  * fix(agent): Reload config on config update (#12721)
  * chore: Fix linter findings for errorlint (part3) (#12704)
  * chore: Fix linter findings for errorlint (part1) (#12701)
  * chore(deps): Bump github.com/go-logfmt/logfmt from 0.5.1 to 0.6.0 (#12715)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.27.1 to 1.28.0 (#12714)
  * chore(deps): Bump google.golang.org/grpc from 1.52.3 to 1.53.0 (#12713)
  * chore(deps): Bump github.com/gophercloud/gophercloud from 1.0.0 to 1.2.0 (#12712)
  * chore: Fix linter findings for errorlint (part2) (#12702)
  * chore(deps): Bump golang.org/x/net from 0.5.0 to 0.7.0 (#12699)
  * chore(inputs.net_response): Use Init to check configuration issues (#12690)
  * docs(readme): add PlayFab Insights external plugin (#12708)
  * docs(parsers.json_v2): fix spelling typo (#12711)
  * chore: mention make lint in PR template and contributing doc (#12703)
  * chore(deps): Bump testcontainers from 0.14.0 to 0.18.0 (#12698)
  * chore(deps): Bump github.com/containerd/containerd from 1.6.8 to 1.6.18 (#12693)
  * docs(outputs.postgresql): Update URL for sql template (#12691)
  * chore: Update to go1.20.1 (#12679)
  * chore(deps): Bump github.com/gofrs/uuid from 4.3.1+incompatible to 5.0.0 (#12668)
  * fix(inputs.bond): Reset slave stats for each interface (#12462)
  * fix(inputs.cloudwatch): Verify endpoint is not nil (#12677)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.1.5 to 2.2.4 (#12667)
  * chore(deps): Bump k8s.io/apimachinery from 0.25.3 to 0.25.6 (#12669)
  * chore(deps): Bump golang.org/x/sys from 0.4.0 to 0.5.0 (#12670)
  * use original signing script
* Wed Feb 15 2023 mrueckert@suse.de
- Update to version 1.25.2:
  * Telegraf v1.25.2
  * Update changelog for v1.25.2
  * Update build_version.txt for v1.25.2
  * chore(deps): Bump github.com/antchfx/xmlquery from 1.3.12 to 1.3.15 (#12634)
  * docs: Tracking metrics (#12663)
  * fix(inputs.x509_cert): Fix Windows path handling (#12629)
  * fix(inputs.cloudwatch): enable custom endpoint support (#12657)
  * test: Use `t.Setenv` to set env vars (#12621)
  * fix: Rename the Prometheus Input Plugin Timeout variable (#12626)
  * docs(inputs.cisco_telemetry_mdt): remove new feature
  * docs: remove trailing whitespace (#12660)
  * docs: fix remaining markdownlinter issues (#12658)
  * docs: remove whitespace (#12655)
  * chore: Prevent RPM from changing permissions on telegraf.d (#12643)
  * chore(deps): Bump github.com/antchfx/xpath from 1.2.2 to 1.2.3 (#12633)
  * chore(deps): Bump github.com/moby/ipvs from 1.0.2 to 1.1.0 (#12632)
  * chore(deps): Bump google.golang.org/grpc from 1.52.0 to 1.52.3 (#12631)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.44.0 to 1.45.0 (#12630)
  * docs: Update all readme to pass linter (#12615)
  * fix(inputs.gnmi): Handle both new-style `tag_subscription` and old-style `tag_only` (#12512)
  * fix(inputs.cisco_telemetry_mdt): check subfield sizes to avoid panics (#12637)
  * fix(inputs.tail): fix typo in the README (#12648)
  * docs(inputs.syslog): add BSD syslog to readme intro (#12647)
  * fix(secretstores): check store id format and presence (#12644)
  * docs(inputs.procstat): add ppid field (#12641)
  * docs(inputs.snmp): Explain different snmp backends (#12627)
  * chore: Update OpenTelemetry (#12638)
  * chore: Fix linter findings for tenv (#12622)
  * chore: Fix linter findings for nolintlint (part3) (#12613)
  * chore: Show file names and line numbers for found issues in github action logs (#12618)
  * fix(inputs.conntrack): Resolve segfault when setting collect field (#12603)
  * docs: Show TOML inline table syntax for tags/tagpass/tagdrop (#12636)
  * docs(inputs.prometheus): fix incorrect headers option (#12625)
  * fix(agent): Only read the config once (#12607)
  * chore: bump go to 1.20 for golangci-lint-action (#12614)
  * chore: Bump golangci-lint from v1.50.1 to v1.51.0 (#12605)
  * fix(inputs.mongodb): SIGSEGV when restarting MongoDB node (#12604)
  * chore: Update to go1.20 (#12593)
  * fix(inputs.mongodb): Improve error logging (#12599)
  * chore: Lint whole codebase both in PR and master branch (#12590)
  * docs(inputs.postgresql): Provide socket connection details (#12584)
  * chore: clean up import shadowing issues (#12588)
  * chore(internal.gzip): cleanup CompressWithGzip (#12587)
  * chore(inputs.opentelemetry): Update OpenTelemetry input plugin (#12561)
  * fix(docs): fix link to license for Google flatbuffers (#12586)
  * chore(deps): google.golang.org/grpc v1.51.0 to v1.52.0 (#12583)
  * chore(deps): update golang/x dependencies (#12582)
  * chore(deps): update github.com/prometheus/client_golang from 1.13.1 to 1.14.0 (#12581)
  * chore(deps): update gopsutil dependency from 3.22.9 to 3.22.12 (#12580)
  * chore(inputs.x509_cert): fix linter warning (#12577)
  * fix(inputs.mysql): avoid side-effects for TLS between plugin instances (#12576)
  * fix(inputs.upsd): Add additional fields (#12543)
  * fix(outputs.prometheus_client): Expire with ticker, not add/collect (#12560)
  * chore(deps): Bump github.com/multiplay/go-ts3 from 1.0.1 to 1.1.0 (#12572)
  * chore(deps): Bump github.com/coreos/go-semver from 0.3.0 to 0.3.1 (#12571)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.11.0 to 1.11.1 (#12570)
  * chore(deps): Bump github.com/99designs/keyring from 1.2.1 to 1.2.2 (#12568)
* Mon Jan 30 2023 mrueckert@suse.de
- Update to version 1.25.1:
  * Telegraf v1.25.1
  * Update changelog for v1.25.1
  * Update build_version.txt for v1.25.1
  * fix(inputs.opcua): fix opcua and opcua-listener for servers using password-based auth (#12529)
  * fix(inputs.prometheus): Set the timeout for slow running API endpoints correctly (#12559)
  * fix(inputs.exec): restore pre-v1.21 behavior for CSV data_format (#12533)
  * chore(deps): Bump github.com/kardianos/service from 1.2.1 to 1.2.2 (#12418)
  * fix(inputs.sqlserver): Suppress error on secondary replicas (#12528)
  * chore: Fix linter findings for nolintlint (part2) (#12430)
  * fix(inputs.upsd): Always convert to float (#12516)
  * chore: Update package repo GPG key (#12546)
  * chore: Update package repo GPG key (#12544)
  * chore: fix linter findings for nolintlint part 1 (#12427)
  * docs(outputs.elasticsearch): detail overriding timezone (#12551)
  * docs(outputs.mqtt): update readme to match sample config (#12552)
  * docs(outputs.mqtt): fix incorrect use of brackets (#12539)
  * fix(agent): catch non-existing commands and error out (#12549)
  * chore: update package testing from f35 to f37 (#12548)
  * chore(deps): Bump github.com/karrick/godirwalk from 1.16.1 to 1.17.0 (#12417)
  * chore(deps): bump github.com/antchfx/jsonquery from 1.3.0 to 1.3.1 (#12511)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 (#12538)
  * fix(inputs.logstash): Collect opensearch specific stats (#12536)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2 from 1.17.1 to 1.17.3 (#12420)
  * fix(inputs.prometheus): correctly track deleted pods (#12522)
  * chore: update windows signing script (#12524)
  * chore: Run make docs with various GOOS (#12503)
  * fix(common.cookie): Allow any 2xx status code (#12515)
  * test(inputs.snmp): Use random port (#12464)
  * fix(inputs.upsd): Ensure firmware is always a string (#12486)
  * docs(inputs.influxdb): Collect v2 with prometheus plugin (#12492)
  * fix(inputs.cisco_telemetry_mdt): add operation-metric and class-policy prefix (#12240)
  * fix(json_v2): In case of invalid json, log messsage to debug log (#12440)
  * chore(deps): update github.com/denisenkom/go-mssqldb from 0.12.0 to 0.12.3 (#12476)
  * docs(secretstores): document systemd-nspawn requirement (#12494)
  * chore: update to go1.19.5 (#12498)
  * fix(secretstores): fix handling of TOML strings (#12490)
  * fix(agent): handle float time with fractions of seconds correctly (#12491)
  * fix(agent): Only set default snmp after reading all configs (#12457)
  * docs(inputs.example): correctly set syntax highlighting and section name (#12471)
  * docs(inputs.socketstat): fix wrong TOML option name. (#12482)
  * fix(inputs.win_eventlog): Handle remote events more robustly. (#12375)
  * fix(inputs.sqlserver): add more precise version check (#12384)
  * chore(stackdriver): Fix deprecated monitoringpb (#12424)
  * fix(inputs.gnmi): update configuration documentation (#12415)
  * fix(secretstores): Fix handling of 'id' and print failing secret-store (#12468)
  * feat(kafka): Add keep-alive period setting for input and output. (#12459)
  * fix(agent): Correctly reload configuration files (#12453)
  * chore: update influxdb-observability to fix statsd bug (#12429)
  * docs(inputs.postgresql): update readme and samples to note timeout behavior (#12446)
  * chore: Fix linter findings for makezero (part4) (#12410)
  * fix(inputs.mysql): Revert slice declarations with non-zero initial length (#12409)
  * fix: Added own SPID filter to sqlserverqueries.go (#12387)
  * fix(inputs.sqlserver): SqlRequests include sleeping sessions with open transactions (#12386)
  * chore(linter): disable linter warning for freeze() in starlark (#12406)
  * fix(outputs.loki): return response body on error (#12399)
  * chore: Do not start service on deb install (#12405)
  * fix(inputs.x509_cert): fix off-by-one when adding intermediate certificates (#12404)
  * test: Always create test config for package testing (#12390)
  * fix(secretstores): cleanup duplicate printing (#12401)
  * chore(deps): Bump cloud.google.com/go/storage from 1.23.0 to 1.28.1 (#12385)
  * chore(deps): bump github.com/nats-io/nats-server/v2 from 2.9.4 to 2.9.9 (#12379)
  * chore(deps): bump github.com/eclipse/paho.mqtt.golang (#12378)
  * chore(deps): bump github.com/hashicorp/consul/api from 1.15.2 to 1.18.0 (#12381)
* Tue Dec 20 2022 mrueckert@suse.de
- Update to version 1.25.0:
  * Telegraf v1.25.0
  * Update changelog for v1.25.0
  * feat(inputs.powerdns_recursor): Support for new PowerDNS recursor control protocol (#9633)
  * feat(parsers.csv): suport null delimiters (#12247)
  * fix(common.opcua): parse full range of status codes with uint32 (#12376)
  * chore: fix linter findings for makezero (part3) (#12371)
  * chore: update OpenTelemetry from v0.2.30 to v0.2.33 (#12372)
  * test(inputs.statsd): increase sleep + expiration on test (#12354)
  * feat(inputs.netflow): add netflow plugin (#12108)
  * feat(inputs.sqlserver): add @@SERVICENAME and SERVERPROPERTY(''IsClustered'') in measurement sqlserver_server_properties  (#12351)
  * fix(inputs.modbus): fix default value of transmission mode (#12367)
  * fix(inputs.kube_inventory): Change default token path, use in-cluster config by default (#12284)
  * feat(inputs.kubernetes): Allow fetching kublet metrics remotely (#12301)
  * feat(inputs.smart): Add additional SMART metrics that indicate/predict device failure (#12329)
  * fix(inputs.mongodb): Fix connection leak triggered by config reload (#12330)
  * chore: Fix linter findings for makezero (part2) (#12362)
  * fix(inputs.filecount): Revert library version (#12295)
  * chore: Move host-endianness definition to `internal` (#12360)
  * feat: secret-store implementation (#11232)
  * fix(inputs.sql): cast measurement_column to string (#12323)
  * fix(processors.parser): handle empty metric names correctly (#12357)
  * chore(deps): bump github.com/aliyun/alibaba-cloud-sdk-go (#12334) from 1.61.1836 to 1.62.77
  * feat(agent): Deprecate active usage of netsnmp translator (#12358)
  * chore(deps): Bump github.com/gosnmp/gosnmp from 1.34.0 to 1.35.0 (#12355)
  * feat(parsers.grok): add option to allow multiline messages (#12320)
  * chore: update github.com/wavefrontHQ/wavefront-sdk-go from v0.10.4 to v0.11.0 (#12309)
  * chore: update to go1.19.4 (#12347)
  * docs: add document on debugging with delve (#12346)
  * chore(outputs.wavefront): Reduce code duplication (#12332)
  * fix(inputs.vsphere): Eliminated duplicate samples (#12259)
  * feat(inputs.cgroups): do not abort on first error, print message once (#12342)
  * feat(inputs.modbus): add support for half-precision float (float16) (#12340)
  * feat(tls): allow setting renegotiation method (#12302)
  * fix(inputs.modbus): Fix Windows COM-port path (#12339)
  * feat(inputs.sqlserver): introduce timeout for query execution (#12319)
  * fix(inputs.zfs): Unbreak datasets stats gathering in case listsnaps is enabled on a zfs pool (#12307)
  * feat(inputs.kafka_consumer): Add sarama debug logs (#12304)
  * feat(inputs.http_response): Add User-Agent header (#12324)
  * feat(inputs.sqlserver): add metric available_physical_memory_kb in sqlserver_server_properties (#12292)
  * docs: specify the time for nightly builds (#12312)
  * feat(inputs.modbus): optimize grouped requests (#11106)
  * chore: improve processor ordering (#12308)
  * fix(readme): update bigbluebutton-telegraf-plugin url (#12310)
  * feat(parsers.csv): add option for overwrite tags (#12008)
  * chore(inputs.gnmi): Degrade empty-name error to a warning and add instructions. (#12305)
  * Update changelog for v1.24.4
  * fix(inputs.directory_monitor): Close input file before removal (#12294)
  * fix(inputs.gnmi): Do not provide empty prefix for subscription request. (#12275)
  * fix(outputs.azure_data_explorer): update test call to NewSerializer (#12291)
  * chore(deps): bump go.mongodb.org/mongo-driver from 1.10.2 to 1.11.0 (#12266)
  * fix(inputs.prometheus): correctly default to 9102 port (#12282)
  * feat(inputs.tail): add option to preserve newlines for multiline data (#12281)
  * docs(inputs.kube_inventory): update k3s integration guide (#12285)
  * feat: add method to inform of deprecated plugin option values (#11987)
  * refactor(outputs.azure_data_explorer): removed deprecated code (#11951)
  * chore(deps): bump cloud.google.com/go/pubsub from 1.25.1 to 1.26.0 (#12267)
  * chore(deps): bump github.com/yuin/goldmark from 1.5.2 to 1.5.3 (#12268)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/credentials from 1.12.21 to 1.13.2 (#12269)
  * fix(inputs.promethes): respect selectors when scraping pods (#12278)
  * fix(inputs.socket_listener): ensure closed connection (#12280)
  * feat(inputs.snmp): convert enum values (#11872)
  * chore(inputs.gnmi): Bump github.com/google/gnxi to latest master to allow Sonic-style paths. (#12272)
  * feat(inputs.prometheus): Allow explicit scrape configuration without annotations (#11962)
  * feat(inputs.prometheus): Add support for custom header (#12050)
  * fix(output.datadog): log response in case of non 2XX response from API (#12201)
  * chore: Fix linter findings for prealloc (part3) (#12246)
  * chore: Fix linter findings for errname (#12253)
  * chore: Fix linter findings for makezero (part1) (#12254)
  * fix(inputs.gnmi): Fix empty name for Sonic device (#12258)
  * feat(parsers.xpath): Allow to specify byte-array fields to encode in HEX (#11999)
  * chore(deps): Bump github.com/showwin/speedtest-go from 1.1.5 to 1.2.1 (#12248)
  * test(outputs.sql): print out what we get, bump time required (#12262)
  * feat(inputs.modbus): Add 8-bit integer types (#12255)
  * chore(inputs.x509_cert): Cleanup code (#12250)
  * chore: update readme linter changed files version (#12251)
  * test(outputs.sql): do not write to file during testing (#12203)
  * fix(input.modbus): Add workaround to read field in separate requests (#12235)
  * feat(serializers.json): Support serializing JSON nested in string fields (#12260)
  * feat(outputs.graylog): implement optional connection retries (#11950)
  * feat(inputs.socket_ listener): Allow to specify message separator for streams (#12187)
  * feat: Add Azure Monitor input plugin (#10103)
  * fix(input.redis_sentinel): fix sentinel and replica stats gathering (#12229)
  * feat(parsers.binary): handle hex-encoded inputs (#12232)
  * feat(inputs.sqlserver): add data and log used space metrics for Azure SQL DB (#12126)
  * docs(inputs.x509_cert): Add documentation for 'exclude_root_certs' option. (#12249)
  * feat(inputs.tail): Allow handling of quoted strings spanning multiple lines (#11762)
  * chore: Fix linter findings for prealloc (part1) (#12228)
  * fix: Cleanup and add sample.conf embedding (#12244)
  * feat(inputs.ethtool): Gather statistics from namespaces (#11895)
  * chore(deps): bump github.com/Azure/azure-event-hubs-go/v3 from 3.3.18 to 3.3.20 (#12239)
  * chore(deps): bump github.com/urfave/cli/v2 from 2.16.3 to 2.23.5 (#12238)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/sts from 1.16.19 to 1.17.2 (#12237)
  * chore(deps): bump github.com/gofrs/uuid from v4.3.0 to v4.3.1 (#12236)
  * test(inputs.mongodb): update integration test logic (#12241)
  * chore: Fix linter findings for prealloc (part2) (#12242)
  * chore(package_lxd_test): create valid config, additional debug output (#12225)
  * feat(inputs.modbus): Optimize requests (#11273)
  * docs:  add telegraf Homebrew formula link (#12233)
  * chore: enable lll linter (#12226)
  * docs(inputs.modbus): delete sample.conf (#12223)
  * chore: wrap long lines in other locations (#12219)
  * chore: wrap long lines in plugins/inputs/[l-s]* (#12217)
  * chore: wrap long lines in plugins/inputs/[t-z]* (#12218)
  * chore: enable interfacebloat linter (#12174)
  * docs: add Contributor Covenant Code of Conduct (#12215)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#12205)
  * docs(outputs.postgresql): fix example template queries that manage a view (#12190)
  * docs(outputs.kafka): specify broker behavior (#12161)
  * fix: Run processors in config order (#12113)
  * feat: add arm64 Windows builds (#12130)
  * chore: Wrap long lines in plugins/inputs/[i-k]* (#12199)
  * chore: Wrap long lines in plugins/inputs/[e-h]* (#12186)
  * chore: fix linter findings for unparam and revive.unused-parameter (#12150)
  * chore: Wrap long lines in plugins/parsers (#12180)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#12194)
  * chore: Wrap long lines in plugins/aggregators (#12183)
  * chore: Wrap long lines in plugins/inputs/[a-d]* (#12185)
  * chore: Wrap long lines in plugins/common (#12182)
  * chore: Wrap long lines in plugins/processors (#12181)
  * chore: log errors when adding to quantile aggregator (#12191)
  * chore: Wrap long lines in plugins/outputs (#12179)
  * fix(inputs.ping): Avoid -x/-X on FreeBSD 13 and newer with ping6 (#12171)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds (#12198)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/timestreamwrite (#12196)
  * chore(deps): bump github.com/prometheus/client_golang (#12197)
  * test(inputs.opcua_listener): harden tests (#12193)
  * fix(agent): watch for changes in configuration files in config directories (#12127)
  * chore: update golang.org/x/text from v0.3.7 to v0.3.8 (#12195)
  * fix: Add support for opcua datetime values (#12101)
  * chore(deps): bump github.com/aliyun/alibaba-cloud-sdk-go from 1.61.1818 to 1.61.1836 (#12132)
  * fix(outputs.prometheus): expire during add (#12160)
  * chore: Move influxdb_v2 to be first in sample config (#12163)
  * feat!: Disable [[outputs.influxdb]] in sample config (#12158)
  * test(outputs.sql): simplify clickhouse test (#12189)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#12188)
  * fix(inputs.cloudwatch): Fix multiple namespaces issue (#12177)
  * fix(outputs.yandex_cloud_monitoring): catch int64 values (#12156)
  * feat(inputs.tomcat): add source tag (#12170)
  * chore: Use depguard instead of revive.imports-blacklist (#12153)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#12157)
  * chore: Enable asciicheck, asasalint, bidichk and exportloopref linters (#12169)
  * chore: Enable tparallel linter (#12175)
  * docs(inputs.syslog): mention usage of tcp4/6 (#12168)
  * docs: update commands and flags page (#12162)
  * chore: Cleanup printer.go (#12164)
  * chore: Ignore usages of deprecated fields from gnmi lib (#12154)
  * feat: Add exponential backoff when connecting or reconnecting and allow plugin to start without making initial connection (#12111)
  * fix: inputs.gnmi add support for decimal_val as per gnmi v0.8.0  (#12140)
  * test(outputs.sql): wait for db dump file to exist (#12149)
  * feat(inputs.system): collect unique user count logged in (#12147)
  * Update changelog for v1.24.3
  * chore: update to go v1.19.3 (#12142)
  * fix(inputs.directory_monitor): allow cross filesystem directories (#12124)
  * fix(serializers.splunkmetric): provide option to remove event metric tag (#12024)
  * chore(inputs.socket_listener): Reorganize plugin code (#12031)
  * chore: Fix linter findings introduced in last PRs (#12131)
  * chore(deps): bump github.com/nats-io/nats-server/v2 from 2.8.4 to 2.9.4 (#12134)
  * chore(deps): bump cloud.google.com/go/monitoring from 1.5.0 to 1.7.0 (#12135)
  * chore(parsers.xpath): Add correct deprecation tags (#11986)
  * feat(parsers): Add binary parser (#11552)
  * chore: update OpenTelemetry v0.2.30 / v0.63.0 (#12119)
  * docs: ran make docs (#12120)
  * docs(aggregators.derivative): Remove incorrect comment (#12026)
  * docs(serializers.json): specify version of jsonata used (#12117)
  * fix(processors.parser): Keep name of original metric if parser doesn't return one (#12116)
  * docs: add global configuration header (#12107)
  * fix(inputs.modbus): Handle field-measurement definitions correctly on duplicate field check (#12109)
  * test(outputs.graylog): skip tcp/udp tests on windows & darwin (#12110)
  * chore(common.shim): check err of s.writeProcessedMetrics for the linter (#12103)
  * chore: Increase golangci-lint timeout (#12106)
  * chore: shut down plugins gracefully to prevent race (#12102)
  * chore: Review of //nolint comments (#12088)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#12059)
  * chore: skip integration test with race (#12100)
  * feat(inputs.opcua_listener): OPC UA Event subscriptions (#11786)
  * chore: add kafka round trip integration test using inputs.kafka_consumer and outputs.kafka (#12058)
  * feat(ethtool): Possibility to skip gathering metrics for downed interfaces (#12087)
  * chore(deps): bump github.com/prometheus/client_model from 0.2.0 to 0.3.0 (#12097)
  * chore(deps): bump github.com/gopcua/opcua from 0.3.3 to 0.3.7 (#12095)
  * chore(deps): bump google.golang.org/api from 0.95.0 to 0.100.0 (#12096)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#12098)
  * feat(tools): Allow to markdown includes for sections (#12075)
  * fix(config): set default parser (#12076)
  * fix(processors): Correctly setup processors (#12081)
  * fix: update systemd unit description (#12093)
  * chore(deps): update modernc.org/libc from v1.20.3 to v1.21.2 (#12090)
  * feat(inputs.apcupsd): Added new fields to apcupsd (#12014)
  * test(outputs.sql): further wait for clickhouse writes (#12086)
  * test: update integration test occurrences (#12085)
  * fix(agent): panic as tickers slice was off-by-one in size (#12077)
  * test(inputs.mcrouter): add eventually to pause for metrics (#12074)
  * fix: Restore warning on unused config option(s) (#12063)
  * fix(inputs.kafka): switch to sarama's new consumer group rebalance strategy setting (#12064)
  * docs(inputs.http): add use system proxy config option (#12069)
  * fix(inputs.modbus): add slave id to failing connection (#12038)
  * docs(aggregators.starlark): corrected typo mentioning wrong func name (#12066)
  * fix(inputs.conntrack): Skip gather tests if conntrack kernel module is not loaded. (#12062)
  * chore: Resolve deprecated linter issues (#12051)
  * fix(inputs.zookeeper): add the ability to parse floats as floats (#12023)
  * test: add additional checks, waits in integration tests (#12056)
  * Revert "feat: run govulncheck nightly on master branch (#11977)" (#12054)
  * chore: Update golangci-lint Go version (#12055)
  * docs(inputs.mongodb): update supported versions (#12048)
  * fix(inputs.mongodb): ServerStatus int64 to float(#12049)
  * feat(inputs.modbus): add config option to pause after connect (#11983)
  * chore(deps): bump testcontainers-go from 0.13.0 to 0.14.0 and address breaking change (#12039)
  * chore(deps): bump github.com/Shopify/sarama from 1.36.0 to 1.37.2 (#11980)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#12032)
  * chore(deps): bump github.com/aliyun/alibaba-cloud-sdk-go (#12036)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/kinesis (#12037)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.40.0 to 1.42.0 (#11937)
  * chore(deps): bump github.com/yuin/goldmark from 1.4.13 to 1.5.2 (#12035)
  * chore(deps): bump github.com/signalfx/golib/v3 from 3.3.45 to 3.3.46 (#12034)
  * feat: run govulncheck nightly on master branch (#11977)
  * feat: New Intel DLB input plugin (#11824)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#12005)
  * chore(deps): bump modernc.org/sqlite from 1.17.3 to 1.19.2 (#12030)
  * chore(deps): bump k8s.io/api from 0.25.2 to 0.25.3 (#12029)
  * chore(deps): bump k8s.io/api from 0.25.0 to 0.25.2 (#12001)
  * docs(inputs.tomcat): clean up fields (#12018)
  * fix(regression): Fixes problem with metrics not exposed by plugins. (#12016)
  * refactor: Prevent import from going the wrong way (#12004)
  * feat: New input plugin for libvirt (#11814)
  * test: add dovecot integration test (#11996)
  * chore: Fix installgo_mac.sh using correct hash (#12002)
  * chore(deps): bump k8s.io/apimachinery from 0.25.1 to 0.25.2 (#11938)
  * chore: resolve linter issues for unhandled-error (#11969)
  * chore: Tool to update Telegraf to use new Go version (#11968)
  * test: add integration test for recovering after invalid data (#11994)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11998)
  * fix(inputs.syslog): print error when no error or message given (#11997)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11992)
  * chore: resolve linter issues for confusing-naming and confusing-results (#11956)
  * feat(inputs.conntrack): Parse conntrack stats (#8958)
  * fix(parsers.json_v2): Remove BOM before parsing (#11926)
  * chore: Resolve linter issues for ineffassign, nilerr, gosimple... (#11966)
  * fix(inputs.opcua): Add metric tags to node (#11993)
  * feat(outputs.event_hubs): Expose max message size batch option (#11991)
  * chore(inputs.powerdns): Don't run  flaky test on Windows (#11982)
  * chore(inputs.cloud_pubsub_push): Don't run flaky test on Windows (#11984)
  * chore(ci): Migrate to scheduled pipeline (#11981)
  * chore: Resolve linter issues for plugins/common package (#11964)
  * feat(parsers.xpath): Add option to skip (header) bytes (#11933)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/config (#11979)
  * chore(inputs.socket_listener): Reorganize test to be table-based. (#11970)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/cloudwatch (#11972)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11965)
  * chore: Bump golangci-lint to 1.50.0 (#11957)
  * chore: update OpenTelemetry plugins to latest release (#11943)
  * fix: Setting `enable_tls` has incorrect default value (#11941)
  * chore: update to go1.19.2 (#11940)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/credentials from 1.12.5 to 1.12.21 (#11936)
  * chore(deps): Update github.com/hashicorp/consul/api from 1.14.0 to 1.15.2 (#11894)
  * chore(deps): update github.com/gofrs/uuid from 4.2.0+incompatible to 4.3.0+incompatible (#11935)
  * fix(inputs.modbus): Improve duplicate field checks (#11912)
  * chore(deps): update github.com/sensu/sensu-go/api/core/v2 from 2.14.0 to 2.15.0 (#11928)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11915)
  * chore: Resolve linter issues in config.go and config_test.go (#11929)
  * docs: add libvirt plugin to external input plugins list (#11828)
  * build(rpm): Allow building RPMs cross-OS (#11904)
  * chore(deps): Bump github.com/snowflakedb/gosnowflake from 1.6.2 to 1.6.13 (#11886)
  * Update changelog for 1.24.2 release
  * feat(outputs.azure_data_explorer): Added support for streaming ingestion for ADX output plugin (#11874)
  * fix(parser.xpath): Handle floating-point times correctly (#11875)
  * fix(cli): Support old style of filtering sample configs (#11896)
  * chore: update github.com/shirou/gopsutil from v3.22.8 to v3.22.9 (#11923)
  * fix(inputs.influxdb_listener): error on invalid precision (#11866)
  * docs: Ran `make docs` (#11914)
  * docs(inputs.opcua): fix typo (#11897)
  * chore(lint): Removed deprecated varcheck linter (#11910)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11900)
  * feat(inputs.diskio): Allow selecting devices by ID (#11703)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11885)
  * chore(deps): github.com/docker/distribution from v2.7.1 ti v2.8.1 (#11893)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.4.0 to 1.5.0 (#11891)
  * chore(inputs.opcua): rename regular reads to unregistered reads (#11892)
  * chore(deps): Bump github.com/aws/smithy-go from 1.13.2 to 1.13.3 (#11890)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.10.1 to 1.10.2 (#11887)
  * chore(processors): Convert processors to `ParserPlugin`s (#11600)
  * feat(inputs.amqp_consumer): Determine content encoding automatically (#11860)
  * chore(deps): Replace go-ping by pro-bing (#11836)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.16.0 to 1.17.0 (#11839)
  * fix(common.kafka): Enable TLS in Kafka plugins without custom config (#11519)
  * docs(inputs.cpu): explain macos cpu support requires cgo (#11883)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11884)
  * feat(inputs.opcua): add use regular reads workaround (#11630)
  * fix(inputs.mqtt_consumer): rework connection and message tracking (#10696)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11881)
  * fix(inputs.internet_speed): rename enable_file_download to match upstream intent (#11877)
  * build: github Workflows security hardening (#11843)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11859)
  * fix: Update dependencies for OpenBSD support (#11861)
  * chore: Remove deprecated build tags (#11867)
  * fix(inputs.mongodb): actually start plugin correctly (#11849)
  * fix: re-allow specifying the influx parser type (#11806)
  * chore: update github.com/jackc/pgx/v4 from v4.17.0 to v4.17.1 (#11858)
  * chore: update github.com/lxc/lxd to latest (#11848)
  * chore(deps): Bump github.com/aerospike/aerospike-client-go/v5 from 5.9.0 to 5.10.0 (#11844)
  * chore: remove deprecated io/ioutils (#11678)
  * fix(internal.ethtool): avoid internal name conflict with aws (#11696)
  * docs(inputs.nvidia_smi): Example of how to enable nvidia-smi via docker compose (#11833)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11842)
  * chore(deps): Bump k8s.io/apimachinery from 0.25.0 to 0.25.1 (#11840)
  * feat(outputs.timestream): Support ingesting multi-measures (#11385)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11838)
  * feat(inputs.gcs): Google Cloud Storage Input Plugin (#8413)
  * Update changelog for v1.24.1
  * fix(parsers.csv): Remove direct checks for the parser type (#11825)
  * fix(inputs.ntpq): Handle pools with "-" when (#11827)
  * docs: update customization docs (#11822)
  * fix(parsers): Unwrap parser and remove some special handling (#11826)
  * fix: Enable global confirmation for installing mingw (#11835)
  * fix(parsers): Memory leak for plugins using ParserFunc. (#11815)
  * fix(inputs.modbus): Do not fail if a single slave reports errors (#11785)
  * fix(parsers.xpath): Add array index when expanding names. (#11781)
  * fix(inputs.ceph): Modernize Ceph input plugin metrics (#10797)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11800)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.33.0 to 1.40.0 (#11796)
  * feat(inputs.knx_listener): support TCP as transport protocol (#11783)
  * chore(deps): Bump github.com/wavefronthq/wavefront-sdk-go (#11799)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11798)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 (#11789)
  * feat(inputs.prometheus): use system wide proxy settings (#11729)
  * docs: Remove warning not to remove go:embed (#11797)
  * fix: Clear error message when provided config is not a text file (#11787)
  * chore(deps): Bump github.com/urfave/cli/v2 from 2.14.1 to 2.16.3 (#11794)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.24.0 to 1.25.1 (#11788)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11792)
  * chore: Run amd64 package on master so config is generated (#11790)
  * feat(processors.parser): Add option to parse tags (#11228)
  * Update changelog for v1.24.0
  * Update build version to 1.25.0
* Thu Nov  3 2022 jkowalczyk@suse.com
- Update to version 1.24.3:
  * Revert "feat: run govulncheck nightly on master branch (#11977)" (#12054)
  * Update build_version.txt for v1.24.3
  * Resolve conflict caused by earlier cherry pick error
  * chore: update to go v1.19.3 (#12142)
  * fix(inputs.directory_monitor): allow cross filesystem directories (#12124)
  * fix(serializers.splunkmetric): provide option to remove event metric tag (#12024)
  * chore(inputs.socket_listener): Reorganize plugin code (#12031)
  * chore: Fix linter findings introduced in last PRs (#12131)
  * chore(deps): bump github.com/nats-io/nats-server/v2 from 2.8.4 to 2.9.4 (#12134)
  * chore(deps): bump cloud.google.com/go/monitoring from 1.5.0 to 1.7.0 (#12135)
  * chore(parsers.xpath): Add correct deprecation tags (#11986)
  * chore: update OpenTelemetry v0.2.30 / v0.63.0 (#12119)
  * docs: ran make docs (#12120)
  * docs(aggregators.derivative): Remove incorrect comment (#12026)
  * docs(serializers.json): specify version of jsonata used (#12117)
  * fix(processors.parser): Keep name of original metric if parser doesn't return one (#12116)
  * docs: add global configuration header (#12107)
  * fix(inputs.modbus): Handle field-measurement definitions correctly on duplicate field check (#12109)
  * test(outputs.graylog): skip tcp/udp tests on windows & darwin (#12110)
  * chore(common.shim): check err of s.writeProcessedMetrics for the linter (#12103)
  * chore: Increase golangci-lint timeout (#12106)
  * chore: shut down plugins gracefully to prevent race (#12102)
  * chore: skip integration test with race (#12100)
  * chore: add kafka round trip integration test using inputs.kafka_consumer and outputs.kafka (#12058)
  * chore(deps): bump github.com/prometheus/client_model from 0.2.0 to 0.3.0 (#12097)
  * chore(deps): bump github.com/gopcua/opcua from 0.3.3 to 0.3.7 (#12095)
  * chore(deps): bump google.golang.org/api from 0.95.0 to 0.100.0 (#12096)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#12098)
  * feat(tools): Allow to markdown includes for sections (#12075)
  * fix(config): set default parser (#12076)
  * fix(processors): Correctly setup processors (#12081)
  * fix: update systemd unit description (#12093)
  * chore(deps): update modernc.org/libc from v1.20.3 to v1.21.2 (#12090)
  * test(outputs.sql): further wait for clickhouse writes (#12086)
  * test: update integration test occurrences (#12085)
  * fix(agent): panic as tickers slice was off-by-one in size (#12077)
  * test(inputs.mcrouter): add eventually to pause for metrics (#12074)
  * fix: Restore warning on unused config option(s) (#12063)
  * fix(inputs.kafka): switch to sarama's new consumer group rebalance strategy setting (#12064)
  * docs(inputs.http): add use system proxy config option (#12069)
  * fix(inputs.modbus): add slave id to failing connection (#12038)
  * docs(aggregators.starlark): corrected typo mentioning wrong func name (#12066)
  * chore: Resolve deprecated linter issues (#12051)
  * fix(inputs.zookeeper): add the ability to parse floats as floats (#12023)
  * test: add additional checks, waits in integration tests (#12056)
  * chore: Update golangci-lint Go version (#12055)
  * docs(inputs.mongodb): update supported versions (#12048)
  * chore(deps): bump testcontainers-go from 0.13.0 to 0.14.0 and address breaking change (#12039)
  * chore(deps): bump github.com/Shopify/sarama from 1.36.0 to 1.37.2 (#11980)
  * chore(deps): bump github.com/aliyun/alibaba-cloud-sdk-go (#12036)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/kinesis (#12037)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.40.0 to 1.42.0 (#11937)
  * chore(deps): bump github.com/yuin/goldmark from 1.4.13 to 1.5.2 (#12035)
  * chore(deps): bump github.com/signalfx/golib/v3 from 3.3.45 to 3.3.46 (#12034)
  * feat: run govulncheck nightly on master branch (#11977)
  * chore(deps): bump modernc.org/sqlite from 1.17.3 to 1.19.2 (#12030)
  * chore(deps): bump k8s.io/api from 0.25.2 to 0.25.3 (#12029)
  * chore(deps): bump k8s.io/api from 0.25.0 to 0.25.2 (#12001)
  * docs(inputs.tomcat): clean up fields (#12018)
  * fix(regression): Fixes problem with metrics not exposed by plugins. (#12016)
  * refactor: Prevent import from going the wrong way (#12004)
  * test: add dovecot integration test (#11996)
  * chore: Fix installgo_mac.sh using correct hash (#12002)
  * chore(deps): bump k8s.io/apimachinery from 0.25.1 to 0.25.2 (#11938)
  * chore: resolve linter issues for unhandled-error (#11969)
  * chore: Tool to update Telegraf to use new Go version (#11968)
  * test: add integration test for recovering after invalid data (#11994)
  * fix(inputs.syslog): print error when no error or message given (#11997)
  * chore: resolve linter issues for confusing-naming and confusing-results (#11956)
  * fix(parsers.json_v2): Remove BOM before parsing (#11926)
  * chore: Resolve linter issues for ineffassign, nilerr, gosimple... (#11966)
  * fix(inputs.opcua): Add metric tags to node (#11993)
  * chore(inputs.powerdns): Don't run  flaky test on Windows (#11982)
  * chore(inputs.cloud_pubsub_push): Don't run flaky test on Windows (#11984)
  * chore(ci): Migrate to scheduled pipeline (#11981)
  * chore: Resolve linter issues for plugins/common package (#11964)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/config (#11979)
  * chore(inputs.socket_listener): Reorganize test to be table-based. (#11970)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/cloudwatch (#11972)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11965)
  * chore: Bump golangci-lint to 1.50.0 (#11957)
  * chore: update OpenTelemetry plugins to latest release (#11943)
  * fix: Setting `enable_tls` has incorrect default value (#11941)
  * chore: update to go1.19.2 (#11940)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/credentials from 1.12.5 to 1.12.21 (#11936)
  * chore(deps): Update github.com/hashicorp/consul/api from 1.14.0 to 1.15.2 (#11894)
  * chore(deps): update github.com/gofrs/uuid from 4.2.0+incompatible to 4.3.0+incompatible (#11935)
  * fix(inputs.modbus): Improve duplicate field checks (#11912)
  * chore(deps): update github.com/sensu/sensu-go/api/core/v2 from 2.14.0 to 2.15.0 (#11928)
  * chore: Resolve linter issues in config.go and config_test.go (#11929)
  * docs: add libvirt plugin to external input plugins list (#11828)
  * build(rpm): Allow building RPMs cross-OS (#11904)
  * chore(deps): Bump github.com/snowflakedb/gosnowflake from 1.6.2 to 1.6.13 (#11886)
* Tue Oct  4 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Add _constraints minimum disk 4G to avoid build failures
* Tue Oct  4 2022 jkowalczyk@suse.com
- Update to version 1.24.2:
  * fix(parser.xpath): Handle floating-point times correctly (#11875)
  * fix(cli): Support old style of filtering sample configs (#11896)
  * chore: update github.com/shirou/gopsutil from v3.22.8 to v3.22.9 (#11923)
  * fix(inputs.influxdb_listener): error on invalid precision (#11866)
  * docs: Ran `make docs` (#11914)
  * docs(inputs.opcua): fix typo (#11897)
  * chore(lint): Removed deprecated varcheck linter (#11910)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11885)
  * chore(deps): github.com/docker/distribution from v2.7.1 ti v2.8.1 (#11893)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.4.0 to 1.5.0 (#11891)
  * chore(deps): Bump github.com/aws/smithy-go from 1.13.2 to 1.13.3 (#11890)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.10.1 to 1.10.2 (#11887)
  * chore(processors): Convert processors to `ParserPlugin`s (#11600)
  * chore(deps): Replace go-ping by pro-bing (#11836)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.16.0 to 1.17.0 (#11839)
  * fix(common.kafka): Enable TLS in Kafka plugins without custom config (#11519)
  * docs(inputs.cpu): explain macos cpu support requires cgo (#11883)
  * fix(inputs.mqtt_consumer): rework connection and message tracking (#10696)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11881)
  * fix(inputs.internet_speed): rename enable_file_download to match upstream intent (#11877)
  * build: github Workflows security hardening (#11843)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11859)
  * fix: Update dependencies for OpenBSD support (#11861)
  * chore: Remove deprecated build tags (#11867)
  * fix(inputs.mongodb): actually start plugin correctly (#11849)
  * fix: re-allow specifying the influx parser type (#11806)
  * chore: update github.com/jackc/pgx/v4 from v4.17.0 to v4.17.1 (#11858)
  * chore: update github.com/lxc/lxd to latest (#11848)
  * chore(deps): Bump github.com/aerospike/aerospike-client-go/v5 from 5.9.0 to 5.10.0 (#11844)
  * chore: remove deprecated io/ioutils (#11678)
  * fix(internal.ethtool): avoid internal name conflict with aws (#11696)
  * docs(inputs.nvidia_smi): Example of how to enable nvidia-smi via docker compose (#11833)
  * chore(deps): Bump k8s.io/apimachinery from 0.25.0 to 0.25.1 (#11840)
* Tue Oct  4 2022 jkowalczyk@suse.com
- Update to version 1.24.1:
  * fix(parsers.csv): Remove direct checks for the parser type (#11825)
  * fix(inputs.ntpq): Handle pools with "-" when (#11827)
  * docs: update customization docs (#11822)
  * fix(parsers): Unwrap parser and remove some special handling (#11826)
  * fix: Enable global confirmation for installing mingw (#11835)
  * fix(parsers): Memory leak for plugins using ParserFunc. (#11815)
  * fix(inputs.modbus): Do not fail if a single slave reports errors (#11785)
  * fix(parsers.xpath): Add array index when expanding names. (#11781)
  * fix(inputs.ceph): Modernize Ceph input plugin metrics (#10797)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11800)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.33.0 to 1.40.0 (#11796)
  * chore(deps): Bump github.com/wavefronthq/wavefront-sdk-go (#11799)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11798)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 (#11789)
  * docs: Remove warning not to remove go:embed (#11797)
  * fix: Clear error message when provided config is not a text file (#11787)
  * chore(deps): Bump github.com/urfave/cli/v2 from 2.14.1 to 2.16.3 (#11794)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.24.0 to 1.25.1 (#11788)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11792)
  * chore: Run amd64 package on master so config is generated (#11790)
  * feat(processors.parser): Add option to parse tags (#11228)
* Tue Oct  4 2022 jkowalczyk@suse.com
- Update to version 1.24.0:
  * feat(inputs.directory_monitor): Support paths for files_to_ignore and files_to_monitor (#11784)
  * chore(inputs.jolokia2): Move agent and proxy one level up (#11637)
  * fix(outputs.execd): Fixing the execd behavior to not throw error when partially unserializable metrics are written. (#11767)
  * fix: add missing entry json_transformation to missingTomlField (#11779)
  * fix: Do not error out for parsing errors in datadog mode. (#11777)
  * chore: update to go1.19.1 (#11776)
  * fix(inputs.mongodb): add an option to bypass connection errors on start (#11629)
  * feat(inputs.directory_monitor): Traverse sub-directories (#11773)
  * fix(inputs.jolokia2): add optional origin header (#11692)
  * chore(deps): Bump google.golang.org/grpc from 1.48.0 to 1.49.0 (#11746)
  * docs: Add go report badge (#11774)
  * feat(inputs.sqlserver): Improved filtering for active requests (#11709)
  * chore(deps): Bump github.com/Azure/azure-kusto-go from 0.7.0 to 0.8.0 (#11770)
  * docs(external): add hwinfo external plugin (#11757)
  * chore(deps): Bump gonum.org/v1/gonum from 0.11.0 to 0.12.0 (#11764)
  * chore(deps): Bump github.com/urfave/cli/v2 from 2.11.2 to 2.14.1 (#11763)
  * fix: sort labels in prometheusremotewrite serializer (#11755)
  * fix(inputs.opcua): Assign node id correctly (#11723)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds (#11747)
  * chore: Rename Telegraf receiver argument from a to t (#11742)
  * chore(deps): Bump k8s.io/client-go from 0.24.3 to 0.25.0 (#11745)
  * chore(deps): Bump github.com/gophercloud/gophercloud (#11744)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#11743)
  * chore: update github.com/Shopify/sarama from v1.35 to v1.36 (#11713)
  * chore(deps): Bump github.com/rabbitmq/amqp091-go from 1.3.4 to 1.4.0 (#11699)
  * feat(outputs.postgresql): add Postgresql output (#11672)
  * chore(deps): Bump github.com/tidwall/gjson from 1.14.1 to 1.14.3 (#11721)
  * feat: Migrate to urfave/cli (#11700)
  * chore(deps): Bump github.com/hashicorp/consul/api from 1.13.1 to 1.14.0 (#11717)
  * feat(inputs.linux_cpu): Add plugin to collect CPU metrics on Linux (#8988)
  * chore(deps): Bump github.com/aerospike/aerospike-client-go/v5 (#11716)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/sts (#11711)
  * chore(deps): Bump github.com/wavefronthq/wavefront-sdk-go (#11710)
  * fix(inputs.sqlserver): fixing wrong filtering for sqlAzureMIRequests and sqlAzureDBRequests (#11701)
  * fix: use os-agnositc systemd detection, remove sysv in RPM packaging (#10570)
  * feat(inputs.mqtt_consumer): Add incoming mqtt message size calculation (#11426)
  * feat: tool to build custom Telegraf builds (#11524)
  * chore: Update golangci-lint (#11705)
  * docs: update ms sql dsn example (#11704)
  * feat(serializers.prometheus): Provide option to reduce payload size by removing HELP from payload (#11690)
  * feat(inputs.sqlserver): Add db name to io stats for MI (#11688)
  * fix: refactor telegraf version (#11656)
  * fix(agent): add flushBatch method (#11615)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.9.1 to 1.10.1 (#11676)
  * chore(deps): Bump github.com/aliyun/alibaba-cloud-sdk-go from 1.61.1695 to 1.61.1727 (#11695)
  * fix(inputs.prometheus): plugin run outside k8s cluster error (#11673)
  * chore: only lint changed READMEs (#11677)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/timestreamwrite (#11679)
  * fix: remove bare url in changelog that failed lint
  * chore: Move aws credentials to plugins/common. (#11681)
  * chore: Use build tags to select plugins (#11654)
  * chore(deps): Bump github.com/urfave/cli/v2 from 2.3.0 to 2.11.2 (#11675)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/ec2 (#11670)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest (#11669)
  * chore(deps): Bump github.com/jackc/pgx/v4 from 4.16.1 to 4.17.0 (#11671)
  * fix: Sync sql output and input build constraints to handle loong64 in go1.19. (#11664)
  * docs: explain PowerShell 5 encoding (#11662)
  * chore: update circle-ci orbs (#11618)
  * docs(inputs.zookeeper): document use of prometheus plugin (#11658)
  * feat(outputs.iotdb): Add new output plugin to support Apache IoTDB (#11557)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs (#11653)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds (#11652)
  * feat(outputs.amqp): Add proxy support (#11649)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/ec2 (#11651)
  * chore: Markdown fixes for inputs/[a-m]* (#11606)
  * chore(deps): bump github.com/antchfx/xmlquery from 1.3.9 to 1.3.12 (#11644)
  * fix: Bump github.com/lxc/lxd to latest git to fix https://github.com/lxc/lxd/issues/10738. (#11647)
  * chore(deps): bump google.golang.org/api from 0.85.0 to 0.91.0 (#11643)
  * chore(deps): Bump github.com/prometheus/client_golang from 1.12.2 to 1.13.0 (#11640)
  * feat(common.tls): Implement minimum TLS version for clients (#11493)
  * chore(deps): bump github.com/hashicorp/consul/api from 1.12.0 to 1.13.1 (#11641)
  * chore(deps): Bump github.com/emicklei/go-restful from v2.9.5+incompatible to v3.8.0 (#11636)
  * feat: Supervisord input plugin (#9015)
  * chore(parsers.json_v2): Cleanup test by reusing testutil function (#11627)
  * fix(inputs.mongodb): update version check for newer versions (#11635)
  * feat: add coralogix dialect to opentelemetry (#11622)
  * fix(inputs.x509): Multiple sources with non-overlapping DNS entries. (#11613)
  * fix(parsers): Linter issues (#11607)
  * feat (inputs/prometheus): add setting to set custom namespace label name to avoid conflicts (#11538)
  * chore: workaround for failing "go list -m all" (#11624)
  * feat(processors.starlark): Add starlark benchmark for tag-concatenation (#11306)
  * chore(deps): bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0 (#11616)
  * chore: Update to go1.18.5 (#11621)
  * chore: Using Windows, add exe extension to tools (#11608)
  * docs: Add source tag best practices to the metric schema docs (#11620)
  * feat(external): Add nsdp external plugin (#11619)
  * chore: Fix support issue template (#11617)
  * fix(inputs.kubernetes): refresh token from file at each read (#11578)
  * feat(inputs.ntpq): Allow to specify `reach` output format (#11594)
  * chore(deps): Update github.com/Shopify/sarama from 1.34.1 to 1.35.0 (#11603)
  * chore(deps): update k8s.io/apimachinery from 0.24.2 to 0.24.3 (#11602)
  * chore(deps): Update cloud.google.com/go/pubsub from 1.23.0 to 1.24.0 (#11604)
  * chore(deps): Update github.com/BurntSushi/toml from 0.4.1 to 1.2.0 (#11605)
  * chore: Migrate all issue templates to yaml (#11612)
  * docs(inputs.exec): clarify parsing for ints (#11597)
  * fix(outputs): Linter issues (#11595)
  * fix(inputs.kube_inventory): send file location to enable token auto-refresh (#11577)
  * feat(inputs.ntpq): Add possibility to query remote servers (#11592)
  * feat(inputs.openstack): Add "allow_reauth" config option for openstack client (#11572)
  * feat(inputs.ntpq): Add option to specify command flags (#11593)
  * chore: update github.com/harlow/kinesis-consumer (#11599)
  * chore(deps): Bump github.com/signalfx/golib/v3 from 3.3.43 to 3.3.45 (#11598)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#11584)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis (#11585)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatch (#11586)
  * chore(deps): Bump github.com/Azure/azure-event-hubs-go/v3 (#11590)
  * test: fix openetelemtry test (#11573)
  * fix(inputs): Linter issues (#11576)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.0.13 to 2.1.5 (#11581)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest/adal (#11583)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs (#11582)
  * chore(deps): Bump github.com/shirou/gopsutil/v3 from 3.22.4 to 3.22.7 (#11580)
  * fix(outputs.wavefront): update wavefront sdk and use non-deprecated APIs (#11560)
  * chore(inputs.ntpq): Cleanup existing plugin (#11575)
  * fix(inputs.cloudwatch): customizable batch size when querying (#10851)
  * chore(deps): Bump github.com/eclipse/paho.mqtt.golang from 1.3.5 to 1.4.1 (#11347)
  * chore(deps): Bump github.com/vmware/govmomi from 0.28.0 to 0.29.0 (#11568)
  * chore(deps): Bump github.com/karrick/godirwalk from 1.16.1 to 1.17.0 (#11574)
  * chore(deps): Bump github.com/go-ldap/ldap/v3 from 3.4.1 to 3.4.4 (#11569)
  * chore(deps): Update all go.opentelemetry.io dependencies (#11494)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.46.0 to 1.51.0 (#11567)
  * chore(deps): Bump github.com/apache/thrift from 0.15.0 to 0.16.0 (#11565)
  * chore(deps): Bump github.com/testcontainers/testcontainers-go from 0.12.0 to 0.13.0 (#11412)
  * feat(outputs.sql): Add settings for go sql.DB settings (#11551)
  * fix: Updating credentials file to not use endpoint_url parameter (#10841)
  * fix: Remove shell execution for license-checker. (#11563)
  * chore: More parser cleanup (#11532)
  * feat: Add license checking tool (#11398)
  * feat(parsers.xpath): Add support for returning underlying data-types (#11558)
  * fix(inputs.opcua): return an error with mismatched types (#11539)
  * feat(output.mqtt): Add support for MQTT protocol version 5 (#11284)
  * fix(inputs.stackdriver): Handle when no buckets available (#11556)
  * docs(inputs.mysql): Add link to docs on how to enable mysql's performance schema (#11555)
  * chore: add missing section to kafka_consumer's sample.conf (#11553)
  * docs: add timeout section (#11550)
  * fix(inputs.sqlserver): set lower deadlock priority (#11548)
  * feat(inputs.kafka_consumer): Option to set default fetch message bytes (#11220)
  * docs(inputs.modbus): README changes regarding request.tags (#11541)
  * feat(outputs.graphite): Retry connecting to servers with failed send attempts (#11439)
  * feat(inputs.statsd): add median timing calculation to statsd input plugin (#11518)
  * fix(inputs.snmp_trap): nil map panic when use snmp_trap with netsnmp translator (#11534)
  * feat(parsers.json): Allow JSONata based transformations in JSON serializer (#11251)
  * fix: Add version number to MacOS packages (#11512)
  * feat(inputs.syslog): log remote host as source tag (#9440)
  * feat(outputs.groundwork): Improve metric parsing to extend output (#11443)
  * feat: added metrics for member and replica-set avg health of MongoDB  (#11516)
  * feat(outputs.redistimeseries): Add integration test (#11529)
  * chore: update to go1.18.4 (#11526)
  * fix(inputs.mqtt_consumer):  topic parsing error  when topic having prefix(/) (#11527)
  * fix(inputs.sqlserver): set lower deadlock priority (#11522)
  * fix: make docs + go.mod cleanup post-redis merge (#11521)
  * feat: Add RedisTimeSeries plugin (#11054)
  * docs: run make-docs (#11514)
  * feat(inputs.cisco_telemetry_mdt): Add GRPC Keepalive/timeout config options (#11458)
  * fix: use reader over readcloser, regen cookie-jar (#11482)
  * fix: correct init volume gatherer in openstack (#11481)
  * feat: Nats Jetstream consumer add simple support for jetstream subjects (#11373)
  * Revert "fix: add version number to Mac packages (#11506)" (#11510)
  * fix: add version number to Mac packages (#11506)
  * fix(parsers.prometheus): histogram infinity bucket must be allways present (#11490) (#11486)
  * feat(inputs.modbus): Error out on requests with no fields defined. (#11469)
  * test: do not have leadership election during kafka test (#11404)
  * docs: Add example output section to HTTP plugin (#11497)
  * chore: cleanup go.mod and dependency licences (#11503)
  * feat: add Stomp (Active MQ) output plugin (#7995)
  * chore: Update CRLF line endings in agent.conf to LF (#11501)
  * feat: add proxy support for outputs/cloudwatch (#11399)
  * docs: explain proxmox user/token and node_name (#11487)
  * chore: Check for readme changes in each PR (#11495)
  * chore: Skip building artifacts on master branch (#11465)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11496)
  * fix: Backport sync sample.conf and README.md files (#11489)
  * feat(inputs.smart): Collect SSD endurance information where available in smartctl (#11391)
  * chore(deps): Bump github.com/antchfx/jsonquery from 1.1.5 to 1.2.0 (#11461)
  * feat(inputs.logstash): Record number of failures (#9185)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11483)
  * fix: allow 201 for cookies, update header docs (#11472)
  * fix(inputs.snmp): snmp UseUnconnectedUDPSocket when using udp (#10331)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11480)
  * fix(inputs.upsd): Move to new sample.conf style (#11471)
  * feat(rabbitmq): add support for head_message_timestamp metric (#11475)
  * fix: Update prometheusremotewrite parser to be a new style parser plugin (#11456)
  * chore(gnmi): Add Metrics heading to README.md (#11476)
  * fix(gnmi): refactor tag-only subs for complex keys (#11011)
  * chore: sign nightly artifacts to detect issues before release (#11464)
  * feat(inputs.nginx_plus_api): Gather limit_reqs metrics (#10874)
  * test: ignore return code on check-update (#11445)
  * fix: use bigint for backupsize in sqlserver (#11448)
  * feat: Migrate influx and influx_upstream parsers to new style (#11432)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11463)
  * chore(inputs.socket_listener): Remove parser from init (#11462)
  * feat(input): add upsd implementation (#9890)
  * fix: Deprecation warnings for non-deprecated packages (#11460)
  * chore(deps): Bump github.com/docker/docker (#11438)
  * fix: Update prometheus parser to be a new style parser plugin (#11440)
  * docs(inputs.mqtt_consumer): add pivot example to readme (#11195)
  * test: Update wait statement for postgresql_extensible (#11447)
  * docs: add firehose to EXTERNAL_PLUGINS.md (#11450)
  * chore(deps): Bump github.com/prometheus/client_golang (#11437)
  * chore(deps): Bump k8s.io/api from 0.24.1 to 0.24.2 (#11434)
  * feat: Migrate nagios parser to new style (#11402)
  * fix: add reset-mode flag for CSV parser (#11288)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11431)
  * feat: adding aws metric streams input plugin (#11233)
  * test: run check-update on dnf/yum (#11430)
  * chore(deps): Bump github.com/influxdata/influxdb-observability/otel2influx from 0.2.21 to 0.2.22 (#11416)
  * feat: migrate grok to new parser style (#11408)
  * feat: Migrate dropwizard parser to new style (#11371)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.15.4 to 1.15.8 (#11415)
  * test: exchange confused parameters (expected vs actual) (#11422)
  * feat: Migrate logfmt parser to new style (#11366)
  * fix: Bring back old xpath section names (#11335)
  * feat: Migrate graphite parser to new style (#11405)
  * feat: migrate value parser to new style (#11407)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11419)
  * feat(outputs/wavefront): make maximum http batch size configurable (#11201)
  * feat: migrate form_urlencoded parser to new style (#11381)
  * chore: move printing of sample config file out of config.go (#11409)
  * chore(deps): Bump github.com/vmware/govmomi from 0.27.3 to 0.28.0 (#11396)
  * chore(deps): Bump github.com/golang-jwt/jwt/v4 from 4.4.1 to 4.4.2 (#11395)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11414)
  * fix: Sync back sample.confs for inputs.couchbase and outputs.groundwork. (#11413)
  * fix: resolve jolokia2 panic on null response (#11397)
  * test: add nightly package testing to amd64/linux (#11377)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.1.0 to 1.46.0 (#11382)
  * chore: Remove 'github.com/cisco-ie/nx-telemetry-proto' replacement (#11401)
  * chore: Remove 'github.com/satori/go.uuid' replacement (#11240)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis (#11380)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.22.2 to 1.23.0 (#11394)
  * feat: Migrate collectd parser to new style (#11367)
  * feat: allow collecting node-level metrics for Couchbase buckets (#9717)
  * feat: migrate wavefront parser to new style (#11374)
  * chore(deps): Bump github.com/Azure/azure-kusto-go from 0.6.0 to 0.7.0 (#11378)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.8.0 to 1.33.0 (#11379)
  * chore(deps): Bump github.com/jackc/pgx/v4 from 4.15.0 to 4.16.1 (#11346)
  * chore(deps): Bump go.opentelemetry.io/collector/pdata from 0.52.0 to 0.54.0 (#11369)
  * docs: swap bytes sent/recv descriptions in nfsclient (#11376)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.18.0 to 1.22.2 (#11349)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.15.0 to 1.16.0 (#11339)
  * chore(deps): Bump github.com/dynatrace-oss/dynatrace-metric-utils-go from 0.3.0 to 0.5.0 (#11342)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11365)
  * feat: Migrate json_v2 parser to new style (#11343)
  * fix: Restore sample configurations broken during initial migration (#11276)
  * feat: Add CSV serializer (#11307)
  * fix: don't require listeners to be present in overview (#9315)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11351)
  * feat: Migrate json parser to new style (#11226)
  * chore: move agent config into seperate file (#11337)
  * docs: Sync sample.conf for recent features (#11348)
  * chore(deps): Bump github.com/Shopify/sarama from 1.32.0 to 1.34.1 (#11319)
  * feat(x509_cert): add proxy support (#9319)
  * feat(redis): add Redis 6 ACL auth support (#9333)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11344)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/timestreamwrite from 1.3.2 to 1.13.6 (#11322)
  * fix: filter out views in mongodb lookup (#11280)
  * chore(deps): Bump github.com/fatih/color from 1.10.0 to 1.13.0 (#11340)
  * chore: fix typo (recieve -> receive) (#11341)
  * chore(deps): Bump google.golang.org/api from 0.74.0 to 0.84.0 (#11338)
  * chore(deps): Bump github.com/gophercloud/gophercloud from 0.24.0 to 0.25.0 (#11321)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.9.0 to 1.9.1 (#11320)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#11328)
  * test: add coveralls coverage to master (#11256)
  * chore: make apt-get instructions consistent and add GPG fingerprint (#11326)
  * chore(deps): Bump github.com/go-logfmt/logfmt from 0.5.0 to 0.5.1 (#11299)
  * chore(deps): Bump k8s.io/client-go from 0.23.3 to 0.24.1 (#11223)
  * chore(deps): Bump google.golang.org/grpc from 1.46.2 to 1.47.0 (#11318)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.12.2 to 1.12.5 (#11297)
  * test: mark integration tests correctly (#11317)
  * test: update wait for statement for postgres (#11309)
  * chore: Remove prefix to use the default `chore(deps)` (#11315)
  * docs: explain directly connecting to mongo node (#11314)
  * fix: Prevent concurrent map writes to c.UnusedFields (#11311)
  * feat: Make the command "config" a subcommand (#11282)
  * feat: add default appType as config option to groundwork output (#11300)
  * fix(parsers/xpath): Reduce debug messages when empty selection is allowed (#11302)
  * feat(inputs.x509_cert): add smtp protocol (#11271)
  * fix: bump cloud.google.com/go/monitoring from 1.2.0 to 1.5.0 (#11295)
  * fix: Remove all rebase logic from CI (#11293)
  * fix: Don't rebase on master when building packages (#11291)
* Tue Aug 16 2022 jkowalczyk@suse.com
- Update to version 1.23.4:
  * fix: remove bare url in changelog that failed lint
  * fix: update license of dependencies
  * fix: update github.com/mdlayher/netlink to 1.6.0 to fix the build
  * fix: Sync sql output and input build constraints to handle loong64 in go1.19. (#11664)
  * docs: explain PowerShell 5 encoding (#11662)
  * chore: update circle-ci orbs (#11618)
  * docs(inputs.zookeeper): document use of prometheus plugin (#11658)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs (#11653)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds (#11652)
  * chore(deps): bump github.com/aws/aws-sdk-go-v2/service/ec2 (#11651)
  * chore(deps): bump github.com/antchfx/xmlquery from 1.3.9 to 1.3.12 (#11644)
  * fix: Bump github.com/lxc/lxd to latest git to fix https://github.com/lxc/lxd/issues/10738. (#11647)
  * chore(deps): bump google.golang.org/api from 0.85.0 to 0.91.0 (#11643)
  * chore(deps): Bump github.com/prometheus/client_golang from 1.12.2 to 1.13.0 (#11640)
  * chore(deps): bump github.com/hashicorp/consul/api from 1.12.0 to 1.13.1 (#11641)
  * chore(deps): Bump github.com/emicklei/go-restful from v2.9.5+incompatible to v3.8.0 (#11636)
  * fix(inputs.mongodb): update version check for newer versions (#11635)
  * feat: add coralogix dialect to opentelemetry (#11622)
  * fix(parsers): Linter issues (#11607)
  * chore: workaround for failing "go list -m all" (#11624)
  * chore(deps): bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0 (#11616)
  * chore: Update to go1.18.5 (#11621)
  * docs: Add source tag best practices to the metric schema docs (#11620)
  * chore: Fix support issue template (#11617)
  * fix(inputs.kubernetes): refresh token from file at each read (#11578)
  * chore(deps): Update github.com/Shopify/sarama from 1.34.1 to 1.35.0 (#11603)
  * chore(deps): update k8s.io/apimachinery from 0.24.2 to 0.24.3 (#11602)
  * chore(deps): Update cloud.google.com/go/pubsub from 1.23.0 to 1.24.0 (#11604)
  * chore(deps): Update github.com/BurntSushi/toml from 0.4.1 to 1.2.0 (#11605)
  * chore: Migrate all issue templates to yaml (#11612)
  * docs(inputs.exec): clarify parsing for ints (#11597)
  * fix(outputs): Linter issues (#11595)
  * fix(inputs.kube_inventory): send file location to enable token auto-refresh (#11577)
  * chore: update github.com/harlow/kinesis-consumer (#11599)
  * chore(deps): Bump github.com/signalfx/golib/v3 from 3.3.43 to 3.3.45 (#11598)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#11584)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis (#11585)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatch (#11586)
  * chore(deps): Bump github.com/Azure/azure-event-hubs-go/v3 (#11590)
  * test: fix openetelemtry test (#11573)
  * fix(inputs): Linter issues (#11576)
  * chore(deps): Bump github.com/pion/dtls/v2 from 2.0.13 to 2.1.5 (#11581)
  * chore(deps): Bump github.com/Azure/go-autorest/autorest/adal (#11583)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs (#11582)
  * chore(deps): Bump github.com/shirou/gopsutil/v3 from 3.22.4 to 3.22.7 (#11580)
  * fix(inputs.cloudwatch): customizable batch size when querying (#10851)
  * chore(deps): Bump github.com/eclipse/paho.mqtt.golang from 1.3.5 to 1.4.1 (#11347)
  * chore(deps): Bump github.com/vmware/govmomi from 0.28.0 to 0.29.0 (#11568)
  * chore(deps): Bump github.com/karrick/godirwalk from 1.16.1 to 1.17.0 (#11574)
  * chore(deps): Bump github.com/go-ldap/ldap/v3 from 3.4.1 to 3.4.4 (#11569)
  * chore(deps): Update all go.opentelemetry.io dependencies (#11494)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.46.0 to 1.51.0 (#11567)
  * chore(deps): Bump github.com/apache/thrift from 0.15.0 to 0.16.0 (#11565)
  * chore(deps): Bump github.com/testcontainers/testcontainers-go from 0.12.0 to 0.13.0 (#11412)
  * fix: Updating credentials file to not use endpoint_url parameter (#10841)
  * fix(inputs.opcua): return an error with mismatched types (#11539)
  * fix(inputs.stackdriver): Handle when no buckets available (#11556)
  * docs(inputs.mysql): Add link to docs on how to enable mysql's performance schema (#11555)
  * chore: add missing section to kafka_consumer's sample.conf (#11553)
  * docs: add timeout section (#11550)
  * fix(inputs.sqlserver): set lower deadlock priority (#11548)
  * docs(inputs.modbus): README changes regarding request.tags (#11541)
  * docs: run make-docs (#11514)
  * test: do not have leadership election during kafka test (#11404)
  * chore: Update CRLF line endings in agent.conf to LF (#11501)
* Mon Jul 25 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Refresh harden_telegraf.service.patch
* Mon Jul 25 2022 jkowalczyk@suse.com
- Update to version 1.23.3:
  * Update changelog for v1.23.3
  * Update build_version.txt for v1.23.3
  * fix(inputs.snmp_trap): nil map panic when use snmp_trap with netsnmp translator (#11534)
  * fix: add version number to MacOS packages
  * chore: update to go1.18.4 (#11526)
  * fix(inputs.mqtt_consumer):  topic parsing error  when topic having prefix(/) (#11527)
  * fix(inputs.sqlserver): set lower deadlock priority (#11522)
  * fix: use reader over readcloser, regen cookie-jar (#11482)
  * fix: correct init volume gatherer in openstack (#11481)
  * fix: add version number to Mac packages (#11506)
  * fix(parsers.prometheus): histogram infinity bucket must be allways present (#11490) (#11486)
  * docs: Add example output section to HTTP plugin (#11497)
  * docs: explain proxmox user/token and node_name (#11487)
  * chore(deps): Bump github.com/antchfx/jsonquery from 1.1.5 to 1.2.0 (#11461)
* Tue Jul 12 2022 jkowalczyk@suse.com
- Update to version 1.23.2:
  * Update changelog for v1.23.2
  * Update build_version.txt for v1.23.2
  * Sync sample.conf and README.md files.
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11483)
  * fix: allow 201 for cookies, update header docs (#11472)
  * fix(inputs.snmp): snmp UseUnconnectedUDPSocket when using udp (#10331)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11480)
  * chore(gnmi): Add Metrics heading to README.md (#11476)
  * fix(gnmi): refactor tag-only subs for complex keys (#11011)
  * fix: use bigint for backupsize in sqlserver (#11448)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11463)
  * chore(inputs.socket_listener): Remove parser from init (#11462)
  * fix: Deprecation warnings for non-deprecated packages (#11460)
  * chore(deps): Bump github.com/docker/docker (#11438)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11431)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11419)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11414)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11365)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11351)
  * docs: Update etc/telegraf.conf and etc/telegraf_windows.conf (#11344)
  * chore: Remove prefix to use the default `chore(deps)` (#11315)
* Wed Jul  6 2022 jkowalczyk@suse.com
- Update to version 1.23.1:
  * Update changelog for v1.23.1
  * Update build_version.txt for v1.23.1
  * Sync sample.conf into READMEs.
  * Fix xpath config location.
  * docs(inputs.mqtt_consumer): add pivot example to readme (#11195)
  * test: Update wait statement for postgresql_extensible (#11447)
  * docs: add firehose to EXTERNAL_PLUGINS.md (#11450)
  * chore(deps): Bump github.com/prometheus/client_golang (#11437)
  * chore(deps): Bump k8s.io/api from 0.24.1 to 0.24.2 (#11434)
  * chore(deps): Bump github.com/influxdata/influxdb-observability/otel2influx from 0.2.21 to 0.2.22 (#11416)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.15.4 to 1.15.8 (#11415)
  * test: exchange confused parameters (expected vs actual) (#11422)
  * fix: Bring back old xpath section names (#11335)
  * chore(deps): Bump github.com/vmware/govmomi from 0.27.3 to 0.28.0 (#11396)
  * chore(deps): Bump github.com/golang-jwt/jwt/v4 from 4.4.1 to 4.4.2 (#11395)
  * fix: Sync back sample.confs for inputs.couchbase and outputs.groundwork. (#11413)
  * fix: resolve jolokia2 panic on null response (#11397)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/ec2 from 1.1.0 to 1.46.0 (#11382)
  * chore: Remove 'github.com/cisco-ie/nx-telemetry-proto' replacement (#11401)
  * chore: Remove 'github.com/satori/go.uuid' replacement (#11240)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/kinesis (#11380)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.22.2 to 1.23.0 (#11394)
  * chore(deps): Bump github.com/Azure/azure-kusto-go from 0.6.0 to 0.7.0 (#11378)
  * chore(deps): Bump cloud.google.com/go/bigquery from 1.8.0 to 1.33.0 (#11379)
  * chore(deps): Bump github.com/jackc/pgx/v4 from 4.15.0 to 4.16.1 (#11346)
  * chore(deps): Bump go.opentelemetry.io/collector/pdata from 0.52.0 to 0.54.0 (#11369)
  * docs: swap bytes sent/recv descriptions in nfsclient (#11376)
  * chore(deps): Bump cloud.google.com/go/pubsub from 1.18.0 to 1.22.2 (#11349)
  * chore(deps): Bump github.com/nats-io/nats.go from 1.15.0 to 1.16.0 (#11339)
  * chore(deps): Bump github.com/dynatrace-oss/dynatrace-metric-utils-go from 0.3.0 to 0.5.0 (#11342)
  * fix: Restore sample configurations broken during initial migration (#11276)
  * fix: don't require listeners to be present in overview (#9315)
  * chore: move agent config into seperate file (#11337)
  * docs: Sync sample.conf for recent features (#11348)
  * chore(deps): Bump github.com/Shopify/sarama from 1.32.0 to 1.34.1 (#11319)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/timestreamwrite from 1.3.2 to 1.13.6 (#11322)
  * fix: filter out views in mongodb lookup (#11280)
  * chore(deps): Bump github.com/fatih/color from 1.10.0 to 1.13.0 (#11340)
  * chore: fix typo (recieve -> receive) (#11341)
  * chore(deps): Bump google.golang.org/api from 0.74.0 to 0.84.0 (#11338)
  * chore(deps): Bump github.com/gophercloud/gophercloud from 0.24.0 to 0.25.0 (#11321)
  * chore(deps): Bump go.mongodb.org/mongo-driver from 1.9.0 to 1.9.1 (#11320)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#11328)
  * test: add coveralls coverage to master (#11256)
  * chore: make apt-get instructions consistent and add GPG fingerprint (#11326)
  * chore(deps): Bump github.com/go-logfmt/logfmt from 0.5.0 to 0.5.1 (#11299)
  * chore(deps): Bump k8s.io/client-go from 0.23.3 to 0.24.1 (#11223)
  * chore(deps): Bump google.golang.org/grpc from 1.46.2 to 1.47.0 (#11318)
  * chore(deps): Bump github.com/aws/aws-sdk-go-v2/credentials from 1.12.2 to 1.12.5 (#11297)
  * test: mark integration tests correctly (#11317)
  * test: update wait for statement for postgres (#11309)
  * docs: explain directly connecting to mongo node (#11314)
  * fix: Prevent concurrent map writes to c.UnusedFields (#11311)
  * fix: bump cloud.google.com/go/monitoring from 1.2.0 to 1.5.0 (#11295)
* Mon Jun 13 2022 jkowalczyk@suse.com
- Update to version 1.23.0:
  * fix: Remove all rebase logic from CI (#11293)
  * fix: Don't rebase on master when building packages (#11291)
  * Update changelog for v1.23.0
  * test: add install go for linux, use in integration tests (#11281)
  * fix(inputs/directory_monitor): Add support for multiline file parsing (#11234)
  * chore: Fix readme linter errors for input plugins M-Z (#11274)
  * fix: Always build README-embedder for host-architecture (#11253)
  * feat: Migrate xpath parser to new style (#11218)
  * fix: add missing build constraints for sqlite (#11272)
  * fix: remove full access permissions (#11261)
  * chore: Fix readme linter errors for input plugins E-L (#11214)
  * chore: Fix readme linter errors for input plugins A-D (#10964)
  * fix: update github.com/containerd/containerd from v1.5.11 to v1.5.13 (#11266)
  * fix: bump github.com/tidwall/gjson from 1.10.2 to 1.14.1 (#11264)
  * chore: Fix readme linter errors for processor, aggregator, and parser plugins (#10960)
  * fix: update modernc.org/sqlite from v1.10.8 to v1.17.3 (#11260)
  * docs: add missing word <3 (#11262)
  * feat(intel_powerstat): add uncore frequency metrics (#11254)
  * test: remove restore integration test cache (#11255)
  * test: add circle ci integration testing on PRs (#11246)
  * test: harden running of testcontainer integration tests (#11245)
  * chore: update go from v1.18.1 to v1.18.3 (#11248)
  * chore: rename circleci executor (#11247)
  * chore: upgrade windows circleci size (#11249)
  * fix: re-add event to splunk serializer (#11237)
  * docs: update test-container docs (#11244)
  * test: remove docker-compose.yml test file (#11243)
  * fix: update moby/ipvs dependency from v1.0.1 to v1.0.2 (#11242)
  * feat(inputs.sqlserver): Update query store and latch performance counters (#11216)
  * test: migrate elasticsearch to testcontainers (#11207)
  * chore: Bump apcupds and remove the replacement as issue is fixed upstream. (#11239)
  * test: migrate postgres to testcontainers (#11209)
  * test: migrate mcrouter to test-containers (#11208)
  * test: migrate kafka to testcontainers (#11206)
  * docs: Initial update of integration test docs (#11210)
  * chore: Bump riemann-go-client and remove replacement (#11236)
  * fix: Upgrade xpath and fix code (#11241)
  * feat(inputs.nginx_plus_api): Gather slab metrics (#10448)
  * fix(inputs/modbus): #11105 fix requests starting with an omitted field (#11202)
  * fix: (outputs/sql) table existence cache (#10812)
  * fix: Update sample.conf for prometheus (#11217)
  * fix: bump github.com/nats-io/nats-server/v2 from 2.7.4 to 2.8.4 (#11221)
  * test: enable logging with testcontainers (#11211)
  * chore: update github.com/opencontainers/runc from v1.0.2 to v1.1.2 (#11212)
  * chore: update gopkg.in/yaml.v3 from v3.0.0 to v3.0.1 (#11213)
  * fix(inputs/snmp): switch new Reconnect method to be a value receiver (#11197)
  * test: refactor testcontainer port lookup (#11198)
  * test: actually skip flaky snmp test (#11199)
  * chore: correctly spell embed (#11200)
  * fix: bump go.opentelemetry.io/otel/metric from 0.28.0 to 0.30.0 (#11088)
  * chore: update OpenTelmetry plugins (#11194)
  * docs: remove recommendation for prometheus metric_version=2 (#11158)
  * fix: bump github.com/sensu/sensu-go/api/core/v2 from 2.13.0 to 2.14.0 (#11021)
  * test: migrate zookeeper to test-containers (#11185)
  * fix(plugins/amqp): move from `streadway/amqp` to `rabbitmq/amqp091-go` (#11192)
  * feat: Add constant 'algorithm' to the mock plugin (#11188)
  * fix: redis plugin goroutine leak triggered by auto reload config mechanism (#11143)
  * fix: update golangci-lint from v1.45.2 to v1.46.2 (#11191)
  * fix(inputs/snmp): Reconnect TCP agents if needed (#11163)
  * test: migrate pgbouncer to test-containers (#11186)
  * test: remove rabbitmq container not used (#11175)
  * chore: Embed sample configurations into README for aggregators (#11190)
  * chore: Embed sample configurations into README for processors (#11189)
  * chore: embed sample configurations into README for outputs (#11182)
  * feat: Google API Auth (#11084)
  * test: migrate openldap tests to test-containers (#11169)
  * test: migrate nsq to test containers (#11173)
  * test: migrate opcua to test-containers (#11171)
  * feat: add field key option to set event partition key (#11076)
  * test: migrate aerospike to test-containers (#11177)
  * fix: Convert slab plugin to new sample.conf. (#11181)
  * test: migrate memcached to test-containers (#11176)
  * test: migrate redis to test-containers (#11174)
  * test: migrate mqtt to test containers (#11172)
  * test: migrate nats to test-containers (#11170)
  * test: migrate crate to test-containers code (#11165)
  * chore: Embed sample configurations into README for inputs (#11136)
  * fix: search services file in /etc/services and fall back to /usr/etc/services (#11179)
  * fix: Remove any content type from prometheus accept header (#11082)
  * feat(inputs.cpu): Add tags with core id or physical id to cpus (#11141)
  * chore: add readme linter to CI (#11020)
  * feat(intel_powerstat): add Max Turbo Frequency and introduce improvements (#11035)
  * test: avoid data race in tcp-listener test (#11144)
  * fix: bump github.com/aws/aws-sdk-go-v2/config from 1.15.3 to 1.15.7 (#11166)
  * test: add generic test-container code for re-use, migrate mysql (#11157)
  * feat: add external huebridge input plugin (#11159)
  * fix: Improve slab testing without sudo. (#11151)
  * docs: update review docs (#11147)
  * test: force elasticsearch to index batch data (#11153)
  * test: update mongodb output to use test containers (#11137)
  * test: switch internet speed to enable file download (#11146)
  * fix: doc interval setting for internet speed plugin (#11150)
  * fix(inputs.burrow): Move Dialer to variable and run `make fmt` (#11149)
  * fix: avoid calling sadc with invalid 0 interval (#11140)
  * feat: [inputs/burrow] fill more http transport parameters (#6948)
  * feat: do not error if no nodes found for current config with xpath parser (#11102)
  * feat: add slab metrics input plugin (#11075)
  * fix: use readers over closers in http input (#11083) Refs boo#1203914
  * chore(inputs_a-l): migrate sample configs into separate files (#11132)
  * chore(inputs_m-z): migrate sample configs into separate files (#11133)
  * chore(outputs): migrate sample configs into separate files (#11131)
  * chore(aggregators): migrate sample configs into separate files (#11130)
  * chore(processors): migrate sample configs into separate files (#11125)
  * test: use supported version of elasticsearch (#11111)
  * test: remove unecessary flag in sql input (#11115)
  * fix: elasticsearch output float handling test (#11120)
  * test: remove unused riemann from docker-compose (#11118)
  * fix(parsers/nagios): metrics will always return a supported status co… (#11062)
  * feat: allow other fluentd metrics apart from retry_count, buffer_queu… (#11056)
  * feat(parsers/logfmt): Add tag support (#11060)
  * fix: log instance name in skip warnings (#10995)
  * fix: bump github.com/wavefronthq/wavefront-sdk-go from 0.9.10 to 0.9.11 (#10970)
  * fix: Update gopsutil from v3.22.3 to v3.22.4 to allow for HOST_PROC_MOUNTINFO. (#11107)
  * chore(inputs/file): More clear error messages (#11104)
  * test: add test for mysql gatherGlobalVariables using sql-mock (#10987)
  * feat: Artifactory Webhook Receiver (#10918)
  * docs: fix socket_writer output format link (#11101)
  * fix: check net.Listen() error in tests (#11093)
  * fix: Output erroneous namespace and continue instead of error out (#11069)
  * Update changelog
  * feat: add mount option filtering to disk plugin (#11039)
  * feat(inputs.vsphere): Collect resource pools metrics and add resource pool tag in VM metrics (#10574)
  * docs: note about listsnapshots cause zfs parse failures (#11091)
  * fix: bump github.com/showwin/speedtest-go from 1.1.4 to 1.1.5 (#10722)
  * fix(outputs.Wavefront): If no "host" tag is provided, do not add "telegraf.host" tag (#11078)
  * chore: update opentelemetry plugins (#11085)
  * docs: correct copy-and-paste of udp to tcp (#11080)
  * refactor: replace strings.Replace with strings.ReplaceAll (#11079)
  * feat(exec, execd): add an option to pass a custom environment to their child process (#11049)
  * fix(inputs.couchbase): Don't assume metrics will all be of the same length (#11045)
  * fix: deprecate useless database config option (#11044)
  * fix: do not error when closing statsd network connection (#11043)
  * fix: re-init azure monitor http client on context deadline error (#11030)
  * feat: add influx semantic commits checker, checks only last commit. (#11037)
  * fix: have telegraf service wait for network up (#11042)
  * chore(inputs/disk): add deprecation notice to legacy mountpoints setting (#10948)
  * style: align plugin renaming (#10868)
  * Update changelog
  * fix: datadog count metrics (#10979)
  * feat(outputs.http): Support configuration of `MaxIdleConns` and `MaxIdleConnsPerHost` (#10954)
  * chore: enable linting of shell scripts (#11031)
  * chore: increase timeout for darwin packaging (#11041)
  * fix: reduce log level in disk plugin (#10925)
  * feat: create and push nightly docker images to quay.io (#11000)
  * chore: remove influxdata/validate-semantic-github-messages github workflow (#11036)
  * chore: Adding influx's semantic commit and PR message checker, so we … (#11009)
  * fix: use external xpath parser for gnmi (#11024)
  * fix: remove duplicate influxdb listener writes (#10976)
  * Update changelog
  * fix: bump github.com/aws/aws-sdk-go-v2/config from 1.13.1 to 1.15.3 (#10998)
  * fix: add mutex to gnmi lookup map (#11008)
  * fix(cmd): Also allow 0 outputs when using test-wait parameter (#11013)
  * fix: allow Makefile to work on Windows (#11015)
  * chore: Fix readme linter errors for output plugins (#10951)
  * fix: use sprint to cast to strings in gnmi (#11010)
  * docs: add openstack metadata external plugin (#10999)
  * fix: use correct auth token with consul_agent (#11001)
  * docs: correct influx parser type setting in README (#11004)
  * fix: add mariadb_dialect to address the MariaDB differences in INNODB_METRICS (#10486)
  * fix: correctly parse various numeric forms (#10923)
  * chore: add readme linter (#10916)
  * chore: update pull request with master when running CI (#10993)
  * docs: add missing slash in mongodb readme (#10994)
  * fix: update go.opentelemetry.io/collector/pdata from v0.48.0 to v0.49.0 (#10984)
  * docs: regex processor only works on strings (#10982)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs (#10997)
  * fix: bump github.com/aws/aws-sdk-go-v2/credentials from 1.8.0 to 1.11.2 (#10975)
  * test: use `T.TempDir` to create temporary test directory (#10988)
  * feat(processor/regex): Add ability to check every tag for regex replace (#10927)
  * chore: go mod tidy (#10983)
  * chore: Update Go to 1.18.1 (#10961)
  * feat(inputs/teamspeak): allow to configure nickname (#10934)
  * fix: update github.com/containerd/containerd from v1.5.9 to v1.5.11 (#10981)
  * feat(inputs/sqlserver): add RecentBackups query (#10567)
  * fix: bump github.com/miekg/dns from 1.1.46 to 1.1.48 (#10973)
  * fix: ensure aliyuncms metrics accept array, fix discovery (#10850)
  * fix(inputs/aerospike): Statistics query bug (#10930)
  * fix: update github.com/Azure/azure-kusto-go from 0.5.0 to 0.60 (#10966)
  * chore: add logging to graylog tests (#10896)
  * chore: remove go generate from CI tests (#10977)
  * fix: update github.com/gopcua/opcua from v0.3.1 to v0.3.3 (#10974)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#10972)
  * fix: bump github.com/xdg/scram from 1.0.3 to 1.0.5 (#10773)
  * fix: bump go.mongodb.org/mongo-driver from 1.8.3 to 1.9.0 (#10971)
  * fix: align the default value for msg size (#10947)
  * fix: update opentelemetry from v0.2.10 to v0.2.17 (#10963)
  * docs: update sql readme for creating login in windows (#10967)
  * fix: remove overly verbose info message from cisco mdt (#10959)
  * fix: update starlark 7a1108eaa012->d1966c6b9fcd (#10940)
  * docs: update csv parser metadata descriptions (#10750)
  * style: Add deprecation notice to renamed plugins (#10867)
  * chore(inputs): add descriptions to config in README.md (#10962)
  * feat: migrate input plugins to new sample config format (M-Z) (#10926)
  * fix: update influxdb_v2 error message (#10958)
  * fix(inputs.prometheus): moved from watcher to informer (#10932)
  * feat: migrate input plugins to new sample config format (A-L) (#10924)
  * feat: migrate output plugins to new sample config format (#10910)
  * feat: migrate processor plugins to new sample config format (#10913)
  * feat: migrate aggregator plugins to new sample config format (#10912)
  * Update changelog
  * feat: generate the plugins sample config (#10886)
  * feat(inputs.mongodb): Add metrics about files currently open and currently active data handles (#7896)
  * fix: bump gonum.org/v1/gonum from 0.9.3 to 0.11.0 (#10937)
  * fix: bump github.com/golang-jwt/jwt/v4 from 4.2.0 to 4.4.1 (#10906)
  * chore: add actions/setup-go@v2 to linter config (#10935)
  * docs(external.psi): add psi plugin (#10462)
  * fix: Update gopsutil and associated dependencies for improved OpenBSD supp… (#10931)
  * docs: update rpm/deb instructions with stable URLs (#10905)
  * fix: inconsistencies in sql*Requests queries (#10553)
  * feat: add ANSI color filter for tail input plugin (#10880)
  * feat: (outputs.elasticsearch) Add healthcheck timeout (#10853)
  * feat: In Lustre input plugin, support collecting per-client stats. (#10607)
  * fix: default value for logfile rotation interval (#10883)
  * fix: redundant zfs pool tag (#10871)
  * docs: update license of dependencies (#10914)
  * fix: update vsphere info message to debug (#10903)
  * docs: fix contribute button link (#10904)
  * feat: add fritzbox as external plugin (#10818)
  * docs: improve documentation around contribution (#10825)
  * chore: set telegraf log as text block in bug reports (#10895)
  * fix: include body in error message (#10866)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10885)
  * docs: clarify the k and fields topk params (#10830)
  * chore: remove slow process test (#10856)
  * chore: update slow file rotation tests (#10857)
  * chore: switch HTTP 100 test case values (#10858)
  * chore: fix slow running intel-pmu test (#10859)
  * chore: skip longer/integration tests on -short mode (#10860)
  * chore: remove CircleCI parallelism (#10862)
  * chore: reduce timeouts and sleeps (#10861)
  * Update CHANGELOG.md
  * Update build version to 1.23.0
  * Update changelog
  * Update CHANGELOG.md
* Mon May 16 2022 jkowalczyk@suse.com
- Update to version 1.22.4:
  * Update changelog
  * update build version
  * fix: bump github.com/showwin/speedtest-go from 1.1.4 to 1.1.5 (#10722)
  * fix(outputs.Wavefront): If no "host" tag is provided, do not add "telegraf.host" tag (#11078)
  * chore: update opentelemetry plugins (#11085)
  * fix(inputs.couchbase): Don't assume metrics will all be of the same length (#11045)
  * fix: do not error when closing statsd network connection (#11043)
  * fix: re-init azure monitor http client on context deadline error (#11030)
  * fix: have telegraf service wait for network up (#11042)
* Thu Apr 28 2022 jkowalczyk@suse.com
- Update to version 1.22.3:
  * go mod tidy
  * Update changelog
  * update build version
  * chore: increase timeout for darwin packaging (#11041)
  * fix: reduce log level in disk plugin (#10925)
  * fix: use external xpath parser for gnmi (#11024)
  * fix: remove duplicate influxdb listener writes (#10976)
  * chore: go mod tidy (#10983)
  * chore: Update Go to 1.18.1 (#10961)
* Tue Apr 26 2022 jkowalczyk@suse.com
- Update to version 1.22.2:
  * Update changelog
  * update build version
  * update build version
  * fix: bump github.com/aws/aws-sdk-go-v2/config from 1.13.1 to 1.15.3 (#10998)
  * fix: add mutex to gnmi lookup map (#11008)
  * fix(cmd): Also allow 0 outputs when using test-wait parameter (#11013)
  * fix: allow Makefile to work on Windows (#11015)
  * fix: use sprint to cast to strings in gnmi (#11010)
  * fix: use correct auth token with consul_agent (#11001)
  * fix: add mariadb_dialect to address the MariaDB differences in INNODB_METRICS (#10486)
  * fix: correctly parse various numeric forms (#10923)
  * fix: update go.opentelemetry.io/collector/pdata from v0.48.0 to v0.49.0 (#10984)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs (#10997)
  * fix: bump github.com/aws/aws-sdk-go-v2/credentials from 1.8.0 to 1.11.2 (#10975)
  * fix: update github.com/containerd/containerd from v1.5.9 to v1.5.11 (#10981)
  * fix: bump github.com/miekg/dns from 1.1.46 to 1.1.48 (#10973)
  * fix: ensure aliyuncms metrics accept array, fix discovery (#10850)
  * fix(inputs/aerospike): Statistics query bug (#10930)
  * fix: update github.com/Azure/azure-kusto-go from 0.5.0 to 0.60 (#10966)
  * fix: update github.com/gopcua/opcua from v0.3.1 to v0.3.3 (#10974)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#10972)
  * fix: bump github.com/xdg/scram from 1.0.3 to 1.0.5 (#10773)
  * fix: bump go.mongodb.org/mongo-driver from 1.8.3 to 1.9.0 (#10971)
  * fix: align the default value for msg size (#10947)
  * fix: update opentelemetry from v0.2.10 to v0.2.17 (#10963)
  * fix: remove overly verbose info message from cisco mdt (#10959)
  * fix: update starlark 7a1108eaa012->d1966c6b9fcd (#10940)
  * fix: update influxdb_v2 error message (#10958)
  * fix(inputs.prometheus): moved from watcher to informer (#10932)
* Mon Apr 25 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Refresh harden_telegraf.service.patch
* Mon Apr 25 2022 jkowalczyk@suse.com
- Update to version 1.22.1:
  * fix: bump gonum.org/v1/gonum from 0.9.3 to 0.11.0 (#10937)
  * fix: bump github.com/golang-jwt/jwt/v4 from 4.2.0 to 4.4.1 (#10906)
  * chore: add actions/setup-go@v2 to linter config (#10935)
  * docs(external.psi): add psi plugin (#10462)
  * fix: Update gopsutil and associated dependencies for improved OpenBSD supp… (#10931)
  * docs: update rpm/deb instructions with stable URLs (#10905)
  * fix: inconsistencies in sql*Requests queries (#10553)
  * fix: default value for logfile rotation interval (#10883)
  * fix: redundant zfs pool tag (#10871)
  * docs: update license of dependencies (#10914)
  * fix: update vsphere info message to debug (#10903)
  * docs: fix contribute button link (#10904)
  * docs: improve documentation around contribution (#10825)
  * chore: set telegraf log as text block in bug reports (#10895)
  * fix: include body in error message (#10866)
  * docs: clarify the k and fields topk params (#10830)
  * chore: remove slow process test (#10856)
  * chore: update slow file rotation tests (#10857)
  * chore: switch HTTP 100 test case values (#10858)
  * chore: fix slow running intel-pmu test (#10859)
  * chore: skip longer/integration tests on -short mode (#10860)
  * chore: remove CircleCI parallelism (#10862)
  * chore: reduce timeouts and sleeps (#10861)
* Mon Apr 25 2022 jkowalczyk@suse.com
- Update to version 1.22.0:
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10843)
  * fix: fix handling of imports in protocol-buffer definitions (#10798)
  * fix: change name of snmp translator setting (#10872)
  * fix: rename consul_metrics -> consul_agent (#10876)
  * fix: consul_metrics input plugin docs (#10873)
  * tests: remove redundant newlines that go 1.18 treats as errors (#10847)
  * fix: Add option to select translator (#10802)
  * feat: new input Hugepages plugin (#10763)
  * fix: update the precision parameter default value (#10814)
  * fix: bump github.com/nats-io/nats-server/v2 from 2.7.3 to 2.7.4 (#10807)
  * feat: add new rtt per op field to nfsclient (#10787)
  * fix(parsers.json_v2): Check if gpath exists and support optional in fields/tags (#10799)
  * fix(inputs.snmp):  use the correct path when evaluating symlink (#10748)
  * fix: bump github.com/Shopify/sarama from 1.29.1 to 1.32.0 (#10772)
  * fix: update parsing logic of config.Duration (#10803)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10805)
  * feat(parsers.influx): New influx line protocol via feature flag (#10749)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10804)
  * docs: Improve language related to the New Relic license key. (#10796)
  * fix: correctly read ntpq long poll output (#10790)
  * fix(inputs.docker): keep field type of tasks_desired the same (#10711)
  * fix(json_v2): allow multiple optional objects (#10777)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10789)
  * docs: update wavefront docs for clearer proxy server use (#10774)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10779)
  * feat: HTTP basic auth for webhooks (#9332)
  * docs: update uri scheme for default RavenDB configuration (#10764)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10769)
  * fix: sql unsigned settings (#10673)
  * docs: better specify agent precision is integer + unit (#10746)
  * fix: bump github.com/shirou/gopsutil/v3 from 3.21.12 to 3.22.2 (#10758)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10760)
  * style: Add deprecation notices to plugin options (#10616)
  * fix: sanitize stasd names (#10466)
  * fix: bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds (#10759)
  * fix: bump github.com/miekg/dns from 1.1.43 to 1.1.46 (#10757)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#10751)
  * fix: bump github.com/nats-io/nats-server/v2 from 2.7.2 to 2.7.3 (#10752)
  * docs: add value_field_name to value processor (#10740)
  * fix: log err when loading mibs (#10735)
  * docs: add info on Graylog GELF spec (#10745)
  * fix: typo metadata support in csv parser (#10742)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10737)
  * feat: Add tag batch-processing to XPath parser (#10585)
  * fix: add push only updated values flag to histogram aggregator (#10515)
  * feat(parsers/csv): Add metadata support to CSV parser plugin (#10083)
  * fix: Revert "fix: error msg for missing env variables in config (#10681)" (#10727)
  * fix: bump github.com/aws/aws-sdk-go-v2/config from 1.8.3 to 1.13.1 (#10720)
  * fix: bump github.com/testcontainers/testcontainers-go (#10728)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs (#10719)
  * fix: bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds (#10721)
  * fix: bump github.com/wavefronthq/wavefront-sdk-go from 0.9.9 to 0.9.10 (#10718)
  * fix: bump github.com/ClickHouse/clickhouse-go from 1.5.1 to 1.5.4 (#10717)
  * fix: Linter fixes for config/config.go (#10710)
  * fix: bump k8s.io/api from 0.23.3 to 0.23.4 (#10713)
  * fix: bump cloud.google.com/go/pubsub from 1.17.1 to 1.18.0 (#10714)
  * fix: bump github.com/newrelic/newrelic-telemetry-sdk-go (#10715)
  * fix: mdstat when sync is less than 10%% (#10701)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10708)
  * fix: Remove verbose logging from disk input plugin (#10527)
  * feat: Bump github.com/aerospike/aerospike-client-go from 1.27.0 to 5.7.0 (#10604)
  * feat(inputs/memcached): Support client TLS origination to memcached (#10642)
  * feat: socks5 proxy support for websocket (#10672)
  * fix: error msg for missing env variables in config (#10681)
  * fix: include influxdb bucket name in error messages (#10706)
  * fix: openweathermap add feels_like field (#10705)
  * fix: Set NextCheckTime to LastCheckTime to avoid GroundWork to invent a value (#10623)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/dynamodb from 1.5.0 to 1.13.0 (#10692)
  * fix: bump github.com/sensu/sensu-go/api/core/v2 from 2.12.0 to 2.13.0 (#10704)
  * fix: bump github.com/gophercloud/gophercloud from 0.16.0 to 0.24.0 (#10693)
  * fix: bump github.com/jackc/pgx/v4 from 4.14.1 to 4.15.0 (#10702)
  * fix(dedup): Modifying slice while iterating is dangerous (#10684)
  * fix: linter fixes for "import-shadowing: The name '...' shadows an import name" (#10689)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/sts from 1.7.2 to 1.14.0 (#10602)
  * fix: update gosmi from v0.4.3 to v0.4.4 (#10686)
  * feat: update configs (#10676)
  * feat[elastic output]: add elastic pipeline flags (#10505)
  * fix: ensure folders do not get loaded more than once (#10551)
  * docs: update VMWare doc links (#10663)
  * fix: prometheusremotewrite wrong timestamp unit (#10547)
  * feat: update configs (#10662)
  * fix: add graylog toml tags (#10660)
  * feat: add socks5 proxy support for kafka output plugin (#8192)
  * docs: override reported OpenSearch version (#10586)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10659)
  * fix: bump all go.opentelemetry.io dependencies (#10647)
  * feat: collection offset implementation (#10545)
  * chore: update go to 1.17.7 (#10658)
  * fix: check for nil client before closing in amqp (#10635)
  * fix: timestamp change during execution of json_v2 parser. (#10657)
  * fix: bump github.com/signalfx/golib/v3 from 3.3.38 to 3.3.43 (#10652)
  * fix: bump github.com/aliyun/alibaba-cloud-sdk-go (#10653)
  * fix: incorrect handling of json_v2 timestamp_path (#10618)
  * feat: gather additional stats from memcached (#10641)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10649)
  * fix: Revert deprecation of http_listener_v2 (#10648)
  * fix: bump github.com/denisenkom/go-mssqldb from 0.10.0 to 0.12.0 (#10503)
  * fix: bump github.com/gopcua/opcua from 0.2.3 to 0.3.1 (#10626)
  * fix: use current time as ecs timestamp (#10636)
  * fix: bump github.com/nats-io/nats-server/v2 from 2.6.5 to 2.7.2 (#10638)
  * chore: add -race flag to go tests (#10629)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10631)
  * fix: license doc outdated causing CI failure (#10630)
  * fix: bump k8s.io/client-go from 0.22.2 to 0.23.3 (#10589)
  * feat: Implemented support for reading raw values, added tests and doc (#6501)
  * fix: Improve parser tests by using go-cmp/cmp (#10497)
  * feat(mongodb): add FsTotalSize and FsUsedSize informations (#10625)
  * docs: update quay docs for auth (#10612)
  * chore: allow downgrade of go version in windows script (#10614)
  * chore: update CI go to 1.17.6 (#10611)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10600)
  * fix(inputs.opcua): add more data to error log (#10465)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.6.0 to 1.13.0 (#10601)
  * refactor: use early return pattern (#10591)
  * fix: bump github.com/benbjohnson/clock from 1.1.0 to 1.3.0 (#10588)
  * feat: add dynamic tagging to gnmi plugin (#7484)
  * fix: bump github.com/Azure/azure-kusto-go from 0.5.0 to 0.5.2 (#10598)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10584)
  * fix(parsers.json_v2): allow optional paths and handle wrong paths correctly (#10468)
  * docs: add expriation_interval to readme (#10583)
  * feat: aggregator histogram add expiration (#10520)
  * fix[elasticsearch output]: add scheme to fix error in sniffing option (#10513)
  * chore: fix typo in bug report template (#10582)
  * style: Add deprecated warning and version to win_perf_counters option (#10579)
  * feat: Add autorestart and restartdelay flags to Windows service (#10559)
  * fix: Statefull parser handling (#10575)
  * fix: bump github.com/vmware/govmomi from 0.27.2 to 0.27.3 (#10571)
  * fix: bump github.com/prometheus/client_golang from 1.11.0 to 1.12.1 (#10572)
  * fix: remove signed macOS dotfile artifacts (#10560)
  * fix: bump go.mongodb.org/mongo-driver from 1.7.3 to 1.8.3 (#10564)
  * fix: bump github.com/google/go-cmp from 0.5.6 to 0.5.7 (#10563)
  * fix: bump go.opentelemetry.io/collector/model from 0.39.0 to 0.43.2 (#10562)
  * fix: bump github.com/multiplay/go-ts3 from 1.0.0 to 1.0.1 (#10538)
  * fix: bump cloud.google.com/go/monitoring from 0.2.0 to 1.2.0 (#10454)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10561)
  * docs: updates readme to add service SID auth and cleans up AAD auth dupe info (#10541)
  * feat: Add caching to internet_speed (#10530)
  * feat: Xtremio input (#9697)
  * feat(inputs.win_perf_counter): allow errors to be ignored (#10535)
  * fix(outputs/azure_data_explorer): Added azureBlob controls to lower RAM usage (#10179)
  * fix: bump github.com/vmware/govmomi from 0.26.0 to 0.27.2 (#10536)
  * docs: add apt and knot to EXTERNAL_PLUGINS.md (#10552)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10546)
  * fix: move "Starting Telegraf" log (#10528)
  * fix: update docker memory usage calculation (#10491)
  * feat: Add ClickHouse driver to sql inputs/outputs plugins (#9671)
  * fix: collapsed fields by calling more indepth function (#10430)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10533)
  * feat: process group tag for groundwork output plugin (#10499)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10532)
  * docs: Update deprecation readme (#10529)
  * feat: add FileVersion and icon to Win exe (#10487)
  * chore: update grpc to v1.44.0 (#10525)
  * fix: bump google.golang.org/api from 0.54.0 to 0.65.0 (#10434)
  * fix: typo in docs (#10441)
  * fix: bump github.com/antchfx/xmlquery from 1.3.6 to 1.3.9 (#10507)
  * fix: bump github.com/nsqio/go-nsq from 1.0.8 to 1.1.0 (#10521)
  * fix: bump github.com/prometheus/common from 0.31.1 to 0.32.1 (#10506)
  * fix: ipset crash when command not found (#10474)
  * fix: bump cloud.google.com/go/pubsub from 1.17.0 to 1.17.1 (#10504)
  * fix: bump github.com/influxdata/influxdb-observability/influx2otel from 0.2.8 to 0.2.10 (#10432)
  * fix: Update modbus readme (#10501)
  * Fix: Update README.md (#10500)
  * docs: Fixes for input/sql readme (#10498)
  * feat: update configs (#10490)
  * fix: graylog readme to use graylog 3 URLs (#10481)
  * fix: add RFC3164 to RFC5424 translation to docs (#10480)
  * fix: add comment to logparser (#10479)
  * chore: Add `openConnections` to enterprise cluster metrics Readme (#10483)
  * fix: remove duplicate addition of fields (#10478)
  * fix(parsers.nagios): nagios parser now uses real error for logging #10472 (#10473)
  * fix: add newline in execd for prometheus parsing (#10463)
  * fix: bump github.com/shirou/gopsutil/v3 from 3.21.10 to 3.21.12 (#10451)
  * fix: do not save cache on i386 builds (#10464)
  * chore: readme escape rpm variables
  * fix: address flaky tests in cookie_test.go and graylog_test.go (#10326)
  * feat: check TLSConfig early to catch missing certificates (#10341)
  * fix: ensure CI tests runs against i386 (#10457)
  * fix: bump github.com/jackc/pgx/v4 from 4.6.0 to 4.14.1 (#10453)
  * fix: bump github.com/Azure/azure-event-hubs-go/v3 from 3.3.13 to 3.3.17 (#10449)
  * fix: bump github.com/gosnmp/gosnmp from 1.33.0 to 1.34.0 (#10450)
  * fix: wavefront_disable_prefix_conversion case missing from missingTomlField func (#10442)
  * fix: bump github.com/hashicorp/consul/api from 1.9.1 to 1.12.0 (#10435)
  * feat: Parser plugin restructuring (#8791)
  * fix: bump github.com/antchfx/jsonquery from 1.1.4 to 1.1.5 (#10433)
  * fix: bump github.com/prometheus/procfs from 0.6.0 to 0.7.3 (#10414)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10429)
  * feat: Add noise plugin (#10057)
  * feat: update configs (#10425)
  * fix: Accept non-standard OPC UA OK status by implementing a configurable workaround (#10384)
  * feat: support headers for http plugin with cookie auth (#10404)
  * fix: snmp input plugin errors if mibs folder doesn't exist (#10346) (#10354)
  * fix: correctly set ASCII trailer for syslog output (#10393)
  * feat: update configs (#10424)
  * chore: go mod tidy (#10423)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.5.2 to 1.12.0 (#10415)
  * fix: bump github.com/kardianos/service from 1.0.0 to 1.2.1 (#10416)
  * fix: ensure http body is empty (#10396)
  * feat: add bearer token support to elasticsearch output (#10399)
  * fix: bump github.com/couchbase/go-couchbase from 0.1.0 to 0.1.1 (#10417)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10411)
  * fix(json_v2): use raw values for timestamps (#10413)
  * fix: bump github.com/pion/dtls/v2 from 2.0.9 to 2.0.13 (#10418)
  * chore: update mqtt documentation (#10394)
  * feat: deprecate unused snmp_trap timeout configuration option (#10339)
  * fix: update containerd to 1.5.9 (#10402)
  * feat: update configs (#10400)
  * feat:  add compression to Datadog Output (#9963)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10395)
  * fix: re-enable OpenBSD modbus support (#10385)
  * fix: Fix batching logic with write records, introduce concurrent requests (#8947)
  * feat: Add additional stats to bond collector (#10137)
  * fix(outputs/amqp): Close the last connection when writing error to avoid connection leaks (#10360)
  * feat: update docker client API version (#10382)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10381)
  * fix: fix missing storage in container with disk plugin (#10318)
  * feat: add systemd notify support (#10340)
  * chore: typos across source code comments (#10361)
  * chore: sql readme with more details on data types (#10378)
  * fix: empty import tzdata for Windows binaries (#10377)
  * feat: update configs (#10374)
  * chore: document deprecation of timeout (#10373)
  * feat: update configs (#10345)
  * feat: add mock input plugin (#9782)
  * chore: use 4 cores on linux systems (#10342)
  * fix: update go-ldap to v3.4.1 (#10343)
  * chore: remove "i386" test job (#10344)
  * fix: update GroundWork SDK and improve logging (#10255)
  * feat: add more functionality to template processor (#10316)
  * chore: run release signing jobs at the same time (#10333)
  * feat: update configs (#10336)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10335)
  * feat: add builds for riscv64 (#10262)
  * feat: add consul metrics input plugin (#10258)
  * fix: snmp marshal error (#10322)
  * feat: add exclude_root_certs option to x509_cert plugin (#9822)
  * feat: add option to disable prepared statements for PostgreSQL (#9710)
  * fix: cumulative interval start times for stackdriver output (#10097)
  * feat: add option to skip errors during CSV parsing (#10267)
  * feat: update configs (#10334)
  * feat: socketstat input plugin (#3649)
  * fix: update djherbis/times and fix dependabot (#10332)
  * fix: warning output when running with --test (#10329)
  * feat: update configs (#10325)
  * docs: add note about dpdk and socket availability (#10324)
  * feat: reworked varnish_cache plugin (#9432)
  * chore:  release packaging run in parallel (#10314)
  * fix: update bug template
  * chore: add logs section for bug reports (#10323)
  * fix: do not require networking during tests (#10321)
  * chore: update mac signing job to use latest xcode (#10311)
  * chore: update Go version to 1.17.5 (#10310)
  * feat: update configs (#10319)
  * chore: cleanup go.mod (#10313)
  * feat: add timeout-setting to Graylog-plugin (#10220)
  * feat: Improve error logging on plugin initialization (#10307)
  * fix: Fix panic in logparser due to missing Log. (#10296)
  * fix: panic due to no module (#10303)
  * fix: grab table columns more accurately (#10295)
  * fix: check index before assignment (#10299)
  * feat: adds optional list of non retryable http statuscodes to http output plugin (#10186)
  * fix: panic is no mibs folder is found (#10301)
  * fix: mac signing issue with arm64 (#10293)
  * fix: Update go-sensu to v2.12.0 (#10247)
  * fix: typo in openstack neutron input plugin (newtron) (#10284)
  * fix: Fix panic in parsers due to missing Log for all plugins using SetParserFunc. (#10288)
  * fix: mark TestGatherUDPCert as an integration test (#10279)
  * feat: support darwin arm64 (#10239)
  * feat: update configs (#10275)
  * fix: run gofmt (#10274)
  * fix: run go mod tidy (#10273)
  * fix: inputs.snmp to respect number of retries configured (#10268)
  * feat: add Redis Sentinel input plugin (#10042)
  * fix: flush wavefront output sender on error to clean up broken connections (#10225)
  * feat: Add option to disable Wavefront prefix conversion (#10252)
  * feat: add heap_size_limit field for input.kibana (#10243)
  * fix: use sha256 for RPM digest (#10272)
  * feat: Update underlying KNX library to support new types. (#10263)
  * chore: restart service if it is already running and upgraded via RPM (#9970)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10237)
  * fix: Handle duplicate registration of protocol-buffer files gracefully. (#10188)
  * fix(http_listener_v2): fix panic on close (#10132)
  * feat: add Vault input plugin (#10198)
  * feat: support aws managed service for prometheus (#10202)
  * fix: Make telegraf compile on Windows with golang 1.16.2 (#10246)
  * feat: Modbus add per-request tags (#10231)
  * fix: Implement NaN and inf handling for elasticsearch output (#10196)
  * feat: add nomad input plugin (#10106)
  * fix: Print loaded plugins and deprecations for once and test (#10205)
  * fix: eliminate MIB dependency for ifname processor (#10214)
  * feat: Optimize locking for SNMP MIBs loading. (#10206)
  * feat: Add SMART plugin concurrency configuration option, nvme-cli v1.14+ support and lint fixes. (#10150)
  * feat: update configs (#10236)
  * fix(inputs/kube_inventory): set TLS server name config properly (#9975)
  * fix: Sudden close of Telegraf caused by OPC UA input plugin (#10230)
  * fix: bump github.com/eclipse/paho.mqtt.golang from 1.3.0 to 1.3.5 (#9913)
  * fix: json_v2 parser timestamp setting (#10221)
  * fix: ensure graylog spec fields not prefixed with '_' (#10209)
  * docs: remove duplicate links in CONTRIBUTING.md (#10218)
  * fix: pool detection and metrics gathering for ZFS >= 2.1.x (#10099)
  * fix: parallelism fix for ifname processor (#10007)
  * chore: Forbids "log" package only for aggregators, inputs, outputs, parsers and processors (#10191)
  * docs: address documentation gap when running telegraf in k8s (#10215)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10211)
  * fix: mqtt topic extracting no longer requires all three fields (#10208)
  * fix: windows service - graceful shutdown of telegraf (#9616)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10201)
  * feat: Modbus support multiple slaves (gateway feature) (#9279)
  * fix: Revert unintented corruption of the Makefile from #10200. (#10203)
  * chore: remove triggering update-config bot in CI (#10195)
* Mon Apr 25 2022 jkowalczyk@suse.com
- Update to version 1.21.4:
  * fix: ensure folders do not get loaded more than once (#10551)
  * docs: update VMWare doc links (#10663)
  * fix: prometheusremotewrite wrong timestamp unit (#10547)
  * docs: override reported OpenSearch version (#10586)
  * fix: bump all go.opentelemetry.io dependencies (#10647)
  * chore: update go to 1.17.7 (#10658)
  * fix: check for nil client before closing in amqp (#10635)
  * fix: timestamp change during execution of json_v2 parser. (#10657)
  * fix: bump github.com/signalfx/golib/v3 from 3.3.38 to 3.3.43 (#10652)
  * fix: bump github.com/aliyun/alibaba-cloud-sdk-go (#10653)
  * fix: incorrect handling of json_v2 timestamp_path (#10618)
  * fix: Revert deprecation of http_listener_v2 (#10648)
  * fix: bump github.com/denisenkom/go-mssqldb from 0.10.0 to 0.12.0 (#10503)
  * fix: bump github.com/gopcua/opcua from 0.2.3 to 0.3.1 (#10626)
  * fix: update go.mod
  * fix: use current time as ecs timestamp (#10636)
  * fix(outputs/azure_data_explorer): Added azureBlob controls to lower RAM usage (#10179)
  * fix: bump github.com/nats-io/nats-server/v2 from 2.6.5 to 2.7.2 (#10638)
  * chore: add -race flag to go tests (#10629)
  * fix: license doc outdated causing CI failure (#10630)
  * fix: bump k8s.io/client-go from 0.22.2 to 0.23.3 (#10589)
  * docs: update quay docs for auth (#10612)
  * chore: allow downgrade of go version in windows script (#10614)
  * chore: update CI go to 1.17.6 (#10611)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.6.0 to 1.13.0 (#10601)
  * refactor: use early return pattern (#10591)
  * fix: bump github.com/benbjohnson/clock from 1.1.0 to 1.3.0 (#10588)
  * fix: bump github.com/Azure/azure-kusto-go from 0.5.0 to 0.5.2 (#10598)
  * fix(parsers.json_v2): allow optional paths and handle wrong paths correctly (#10468)
  * fix[elasticsearch output]: add scheme to fix error in sniffing option (#10513)
  * chore: fix typo in bug report template (#10582)
  * style: Add deprecated warning and version to win_perf_counters option (#10579)
  * fix: bump github.com/vmware/govmomi from 0.27.2 to 0.27.3 (#10571)
  * fix: bump github.com/prometheus/client_golang from 1.11.0 to 1.12.1 (#10572)
  * fix: remove signed macOS dotfile artifacts (#10560)
  * fix: bump go.mongodb.org/mongo-driver from 1.7.3 to 1.8.3 (#10564)
  * fix: bump github.com/google/go-cmp from 0.5.6 to 0.5.7 (#10563)
  * fix: bump go.opentelemetry.io/collector/model from 0.39.0 to 0.43.2 (#10562)
  * fix: bump github.com/multiplay/go-ts3 from 1.0.0 to 1.0.1 (#10538)
  * fix: bump cloud.google.com/go/monitoring from 0.2.0 to 1.2.0 (#10454)
  * fix: bump github.com/vmware/govmomi from 0.26.0 to 0.27.2 (#10536)
  * docs: add apt and knot to EXTERNAL_PLUGINS.md (#10552)
  * fix: update docker memory usage calculation (#10491)
* Mon Apr 25 2022 jkowalczyk@suse.com
- Update to version 1.21.3:
  * Update license of dependencies file
  * fix: collapsed fields by calling more indepth function (#10430)
  * docs: Update deprecation readme (#10529)
  * chore: update grpc to v1.44.0 (#10525)
  * fix: bump google.golang.org/api from 0.54.0 to 0.65.0 (#10434)
  * fix: typo in docs (#10441)
  * fix: bump github.com/antchfx/xmlquery from 1.3.6 to 1.3.9 (#10507)
  * fix: bump github.com/nsqio/go-nsq from 1.0.8 to 1.1.0 (#10521)
  * fix: bump github.com/prometheus/common from 0.31.1 to 0.32.1 (#10506)
  * fix: ipset crash when command not found (#10474)
  * fix: bump cloud.google.com/go/pubsub from 1.17.0 to 1.17.1 (#10504)
  * fix: bump github.com/influxdata/influxdb-observability/influx2otel from 0.2.8 to 0.2.10 (#10432)
  * fix: Update modbus readme (#10501)
  * Fix: Update README.md (#10500)
  * docs: Fixes for input/sql readme (#10498)
  * fix: graylog readme to use graylog 3 URLs (#10481)
  * fix: add RFC3164 to RFC5424 translation to docs (#10480)
  * fix: add comment to logparser (#10479)
  * chore: Add `openConnections` to enterprise cluster metrics Readme (#10483)
  * fix: remove duplicate addition of fields (#10478)
  * fix(parsers.nagios): nagios parser now uses real error for logging #10472 (#10473)
  * fix: add newline in execd for prometheus parsing (#10463)
  * fix: bump github.com/shirou/gopsutil/v3 from 3.21.10 to 3.21.12 (#10451)
  * fix: do not save cache on i386 builds (#10464)
  * chore: readme escape rpm variables
  * fix: address flaky tests in cookie_test.go and graylog_test.go (#10326)
  * fix: ensure CI tests runs against i386 (#10457)
  * fix: bump github.com/jackc/pgx/v4 from 4.6.0 to 4.14.1 (#10453)
  * fix: bump github.com/Azure/azure-event-hubs-go/v3 from 3.3.13 to 3.3.17 (#10449)
  * fix: bump github.com/gosnmp/gosnmp from 1.33.0 to 1.34.0 (#10450)
  * fix: wavefront_disable_prefix_conversion case missing from missingTomlField func (#10442)
  * fix: bump github.com/hashicorp/consul/api from 1.9.1 to 1.12.0 (#10435)
  * fix: bump github.com/antchfx/jsonquery from 1.1.4 to 1.1.5 (#10433)
  * fix: bump github.com/prometheus/procfs from 0.6.0 to 0.7.3 (#10414)
  * fix: snmp input plugin errors if mibs folder doesn't exist (#10346) (#10354)
  * fix: correctly set ASCII trailer for syslog output (#10393)
  * chore: go mod tidy (#10423)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.5.2 to 1.12.0 (#10415)
  * fix: bump github.com/kardianos/service from 1.0.0 to 1.2.1 (#10416)
  * fix: ensure http body is empty (#10396)
  * fix: bump github.com/couchbase/go-couchbase from 0.1.0 to 0.1.1 (#10417)
  * fix(json_v2): use raw values for timestamps (#10413)
  * fix: bump github.com/pion/dtls/v2 from 2.0.9 to 2.0.13 (#10418)
  * chore: update mqtt documentation (#10394)
  * fix: update containerd to 1.5.9 (#10402)
  * fix: Fix batching logic with write records, introduce concurrent requests (#8947)
  * fix(outputs/amqp): Close the last connection when writing error to avoid connection leaks (#10360)
  * fix: cumulative interval start times for stackdriver output (#10097)
  * fix: Make telegraf compile on Windows with golang 1.16.2 (#10246)
* Fri Jan 21 2022 Felix Niederwanger <felix.niederwanger@suse.com>
- Build-requirement increased to go > 1.17
* Wed Jan 12 2022 reichwald@b1-systems.de
- Update to version 1.21.2:
  * Add json_timestamp_layout configuration option
  * output.http add use_batch_format configuration option
  * Many bug fixes, see full list:
  https://github.com/influxdata/telegraf/releases/tag/v1.21.2
- Update to version 1.21.1:
  * inputs.smart Add SMART plugin concurrency configuration option, nvme-cli v1.14+ support
  * Some bug fixes, see full list:
  https://github.com/influxdata/telegraf/releases/tag/v1.21.1
- Update to version 1.21.0:
  * New Input Plugins
  * intel_pmu input plugin
  * Linux Volume Manager input plugin
  * Openstack input plugin
  * New Output Plugins
  * groundwork output plugin
  * mongodp output plugin
  * Azure Event Hubs output plugin
  * Many bug fixes, see full list:
  https://github.com/influxdata/telegraf/releases/tag/v1.21.0
* Tue Dec 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.20.4:
  * Update go version to 1.17.3
  * Update deprecated plugin READMEs to better indicate deprecation
  * Update dependencies
  * inputs.mongodb Update readme with correct connection URI
  * inputs.mysql Fix type conversion follow-up
  * inputs.proxmox Changed VM ID from string to int
  * inputs.modbus Do not build modbus on openbsd
  * inputs.cisco_telemetry_mdt Move to new protobuf library
  * outputs.loki Add metric name with label "__name"
  * inputs.nvidia_smi Set the default path correctly
  * inputs.sqlserver Add elastic pool in supported versions
    in sqlserver
  * inputs.influxdb Update influxdb input schema docs
  * inputs.intel_rdt Correct timezone handling
* Fri Nov 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.20.3:
  * New External Plugins
  * IBM DB2
  * Oracle Database
  * Many bug fixes, see full list:
  https://github.com/influxdata/telegraf/releases/tag/v1.20.3
- Update to version 1.20.2:
  * parsers.influx Fix memory leak in influx parser
  * Minor other bug fixes
* Thu Nov 25 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.20.1:
  * inputs.elasticsearch_query Add custom time/date format field
  * Some bug fixes, see list:
  https://github.com/influxdata/telegraf/releases/tag/v1.20.1
- Update to version 1.20.0:
  * New Input Plugins
  * Add rocm_smi input to monitor AMD GPUs
  * Add mdstat input to gather from /proc/mdstat collection
  * Add Elasticsearch query input
  * Add internet Speed Monitor Input Plugin
  * New Output Plugins
  * Add OpenTelemetry output
  * Add Azure Data Explorer(ADX) output
  * Features:
  * inputs.systemd_units feat(plugins/inputs/systemd_units): add
    pattern support
  * inputs.cloudwatch Pull metrics from multiple AWS CloudWatch
    namespaces
  * inputs.cloudwatch Support AWS Web Identity Provider
  * inputs.modbus Add support for RTU over TCP
  * Many other bug fixes and features, full list:
    https://github.com/influxdata/telegraf/releases/tag/v1.20.0
* Wed Nov 24 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_telegraf.service.patch
* Thu Jul  1 2021 rpm@fthiessen.de
- Update to version 1.19.0:
  * Update Go to 1.16.5
  * Many linter fixes
  * New Input Plugins
  * Alibaba CloudMonitor Service (Aliyun)
  * OpenTelemetry
  * Intel Data Plane Development Kit (DPDK)
  * KNX, SQL
  * New Output Plugins: Websocket, SQL, AWS Cloudwatch logs
  * New Parser Plugins: Prometheus Remote Write, JSON V2
  * Bugfixes
  * Fix reading config files starting with http
  * serializers.prometheusremotewrite Update dependency and remove
    tags with empty values
  * outputs.kafka Don't prevent telegraf from starting when
    there's a connection error
  * outputs.dynatrace Use dynatrace-metric-utils
  * parsers.json_v2 Update json_v2 parser to handle null types
  * inputs.sql Fix import of sqlite and ignore it on all platforms
    that require CGO.
  * inputs.kube_inventory Fix connecting to the wrong url
  * processors.parser Fix segfault
  * inputs.docker Close all idle connections
  * inputs.suricata Support new JSON format
  * outputs.influxdb Fix endless retries
  * Features
  * Add named timestamp formats
  * Allow multiple "--config" and "--config-directory" flags
  * Config file environment variable can be a URL
  * common.http Add OAuth2 to HTTP input
  * outputs.datadog Add HTTP proxy to datadog output
  * outputs.graphite Allow more characters in graphite tags
  * processors.strings Add UTF-8 sanitizer
  * processors.enum Support float64
  * processors.starlark Support nanosecond resolution timestamp
  * processors.starlark Add math module
  * processors.starlark Add an example showing how to obtain IOPS from
    diskio input
  * parsers.value Add custom field name config option
  * parsers.prometheusremotewrite Add starlark script for
    renaming metrics
  * inputs.vsphere Add config option for the historical interval
    duration
  * inputs.ping Add an option to specify packet size
  * inputs.sqlserver Added login_name
  * inputs.dovecot Add support for unix domain sockets
  * inputs.aliyuncms Add config option list of regions to query
  * inputs.sqlserver Enable Azure Active Directory (AAD)
    authentication support
  * inputs.cloudwatch Add wildcard support in dimensions configuration
  * inputs.mysql Gather all mysql channels
  * inputs.logstash Add support for version 7 queue stats
  * inputs.couchbase Add ~200 more Couchbase metrics via Buckets
    endpoint
  * inputs.sqlserver input/sqlserver: Add service and save connection pools
  * inputs.x509_cert Wildcard support for cert filenames
  * processors.starlark Add time module
  * inputs.kinesis_consumer Add content_encoding option with gzip
    and zlib support
  * inputs.sqlserver Add an optional health metric
  * inputs.http_listener_v2 Add support for snappy compression
  * inputs.cisco_telemetry_mdt Add support for events and class based query
  * inputs.mongodb Optionally collect top stats
* Tue May 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.18.2
  * processors.converter Add support for large hexadecimal strings
  * inputs.apcupsd Fix apcupsd 'ALARMDEL' bug via forked repo
  * parsers.json Make JSON format compatible with nulls
  * inputs.nfsclient Fix nfsclient ops map to allow collection of
    metrics other than read and write
  * inputs.snmp Log snmpv3 auth failures
  * common.shim Accept larger inputs from scanner
  * inputs.vsphere Add MetricLookback setting to handle reporting
    delays in vCenter 6.7 and later
  * outputs.sumologic Carbon2 serializer: sanitize metric name
  * inputs.opcua Fix error handling
* Wed Apr  7 2021 jkowalczyk@suse.com
- Update to version 1.18.1:
  * Add ability to handle 'binary logs' mySQL query with 3 columns, in case 3 columns are sent (MySQL 8 and greater) (#9082)
  * Add configurable option for the 'path' tag override in the Tail plugin. (#9069)
  * fix nfsclient merge to release-1.18 branch
  * inputs.nfsclient: use uint64, also update error handling (#9067)
  * Fix inputs.snmp init when no mibs installed (#9050)
  * inputs.ping: Always SetPrivileged(true) in native mode (#9072)
  * Don't walk the entire interface table to just retrieve one field (#9043)
  * readme fix (#9064)
  * use correct compute metadata url to get folder-id (#9056)
  * Handle error when initializing the auth object in Azure Monitor output plugin. (#9048)
  * update: inputs.sqlserver support version in readme (#9040)
  * SQLServer - Fixes sqlserver_process_cpu calculation (#8549)
  * Fix ipmi panic (#9035)
  * check for length of perusage for stat gathering and removed not used function (#9009)
  * update new plugins in changelog (#8991)
  * exec plugins should not truncate messages in debug mode (#8333)
  * Close running outputs when reloading (#8769)
* Wed Mar 17 2021 jkowalczyk@suse.com
- Update to version 1.18.0:
  * fix segfaults in sflow plugin by checking if protocol headers are set (#8995)
  * Teamspeak input plugin query clients (#8950)
  * Improve xml parser's handling of missing values (#8971)
  * chore: remove references to outdated InfluxDB settings. (#8754)
  * nats_output: use the configured credentials file (#8986)
  * Bigquery output Plugin (#8634)
  * feat: Adding Plex Webhooks external plugin (#8898)
  * accurate state documentation for Starlark
  * Filter data out from system databases for Azure SQL DB only (#8849)
  * Mac entry script: Add space before calling path so that zsh doesn't remove first character of path when prompting for update. (#8976)
  * Include DMG files when syncing release artifacts to AWS (#8972)
  * fix ping tests
  * add more logging to ping plugin
  * Writing unit tests for Kinesis output plugin Write method (#8930)
  * Fix output name to match directory name for sensu output plugin (#8960)
  * New plugins readme cleanup (#8956)
  * Reset the flush interval timer when flush is requested or batch is ready. (#8953)
  * Add Starlark parsing example of nested JSON (#8675)
  * NFS Client input plugin README cleanup (#8943)
  * Fix max open requests to one if idempotent writes is set to true (#8954)
  * Prometheus [Input] plugin - Optimizing for bigger kubernetes clusters (500+ pods) when scraping thru 'monitor_kubernetes_pods' (#8762)
  * Set $HOSTIP in default URL (#8721)
  * Correct Q+A about state (#8918)
  * Add field key length output by field type in schema_sizing Starlark script (#8934)
  * Mac Packaging / Notarization (#8878)
  * Nfsclient input: (Reopen of PR 1491 and 1684) (#4615)
  * chore: update docs link in influxdbv2listener (#8939)
  * fix: Beat readme title (#8938)
  * Get Tail tests to pass on windows (#8927)
  * chore: update csgo readme title (#8933)
  * Add XML parser using XPath queries (#8931)
  * Clearing LGTM alerts and warnings (#8923)
  * Input plugin for RavenDB (#8834)
  * Add Derivative Aggregator Plugin (#3762)
  * Add CSGO SRCDS input plugin (#8525)
  * [plugins/input/docker] Make perdevice affect also cpu and add class granularity through perdevice_include/total_include  (#7312)
  * Sensu Go Output Plugin for Telegraf (#8398)
  * Switching kinesis output plugin to use telegraf.Logger (#8929)
  * Add PPID field to procstat input plugin (#8887)
  * Adding a new directory monitor input plugin.  (#8751)
  * Add Starlark script for estimating Line Protocol cardinality (#8852)
  * Dynatrace Plugin: Make conversion to counters possible / Changed large bulk handling (#8397)
  * plugin: output loki (#8450)
  * SqlServer - fix for default server list (#8655)
  * Add MessagePack output data format (#8828)
  * Use consistent container name in docker input plugin (#8703)
  * Revive fixes - part 3 (#8872)
  * Fix max_repetitions signedness issues #8823 (#8902)
  * outputs.kinesis - log record error count (#8817)
  * Bug Fix - SQL Server HADR queries for SQL Versions (#8833)
  * add proxy (#8915)
  * Display error message on badly formatted config string array (eg. namepass) (#8910)
  * fix: reading multiple holding registers in modbus input plugin (#8628)
  * Non systemd support with unittest (#8785)
  * Fix statsd concurrency bug (#8885)
  * SignalFx Output (#6714)
  * Support more snmpv3 authentication protocols (#8850)
  * add SMCIPMITool input to external plugin list (#8897)
  * SQL Perfmon counters - synced queries from v2 to all db types (#8393)
  * Fix mutex locking around ifname cache  (#8873)
  * Run revive linter in CI (#8798)
  * Add quantile aggregator plugin (#8594)
  * plugins/filestat: Skip missing files (#7316)
  * added member_id as tag(as it is a unique value) for redfish plugin and added address of the server when the status is other than 200 for better debugging (#8813)
  * Revive fixes - part 2 (#8835)
  * Bump github.com/gopcua/opcua from 0.1.12 to 0.1.13 (#8744)
  * Support exclamation mark to create non-matching list in tail plugin (#8613)
  * Add support for datadog distributions metric (#8179)
  * outputs/warp10: url encode comma in tags value (#8657)
  * inputs.x509_cert: Fix timeout issue  (#8824)
  * update min Go version in Telegraf readme (#8846)
  * Add default retry for load config via url (#8803)
  * Code Signing for Windows (#8816)
  * Fix reconnection issues mqtt (#8821)
  * Validate the response from InfluxDB after writing/creating a database to avoid json parsing panics/errors (#8775)
  * Move windows tests to circle-ci, remove appveyor (#8844)
  * Expose v4/v6-only connection-schemes through GosnmpWrapper (#8804)
  * adds missing & to flush_jitter output ref (#8838)
  * Sort and timeout is deadline (#8839)
  * Revive fixes - part 1 (#8797)
  * Update README for inputs.ping with correct cmd for native ping on Linux (#8787)
  * Increase build verbosity with go mod download -x (#8496)
  * AWS EC2 metadata processor Using StreamingProcessor (#8707)
  * Update go-ping to latest version (#8771)
  * Allow to provide constants to a starlark script (#8772)
  * Add HTTP proxy setting to New Relic output plugin (#8749)
  * Set interface for native (#8770)
  * Resolve regression, re-add missing function (#8764)
  * [outputs.influxdb_v2] add exponential backoff, and respect client error responses (#8662)
  * add line about measurement being specified in docs (#8734)
  * Fix issue with elasticsearch output being really noisy about some errors (#8748)
  * Add geoip external project reference
  * improve mntr regex to match user specific keys. (#7533)
  * Fix crash in lustre2 input plugin, when field name and value (#7967)
  * Update grok-library to v1.0.1 with dots and dash-patterns fixed. (#8673)
  * Use go-ping for "native" execution in Ping plugin (#8679)
  * Integration test audit (#8725)
  * fix x509 cert timeout issue (#8741)
  * Add setting to enable caching in ipmitool (#8335)
  * Bump github.com/nsqio/go-nsq from 1.0.7 to 1.0.8 (#8714)
  * Bump github.com/Shopify/sarama from 1.27.1 to 1.27.2 (#8715)
  * fix: remove ambiguity on '\v' from line-protocol parser (#8720)
  * add kafka connect example to jolokia2 input (#8709)
  * Bump github.com/newrelic/newrelic-telemetry-sdk-go from 0.2.0 to 0.5.1 (#8712)
  * Create dependabot.yml (#8614)
  * Add Event Log support for Windows (#8616)
  * update readme: prometheus remote write (#8683)
  * Fix Redis output field type inconsistencies (#8678)
  * GNMI plugin should not take off the first character of field keys when no 'alias path' exists. (#8659)
  * Update template, remove CLA checkbox (#8680)
  * Use the 'measurement' json field from the particle webhook as the measurment name, or if it's blank, use the 'name' field of the event's json. (#8609)
  * Procstat input plugin should use the same timestamp in all metrics in the same Gather() cycle. (#8658)
  * update data formats output docs (#8674)
  * Add timestamp column support to postgresql_extensible (#8602)
  * Added ability to define skip values in csv parser (#8627)
  * Removing .lgtm.yml (#8664)
  * fix some annoying tests due to ports in use
  * Add Beat input plugin (#6653)
  * add todo note about wavefront dependencies
  * Optimize SeriesGrouper & aggregators.merge (#8391)
  * Using mime-type in prometheus parser to handle protocol-buffer responses (#8545)
  * Input SNMP plugin - upgrade gosnmp library to version 1.29.0 (#8588)
  * Provide test environment for kibana input plugin (#8629)
  * Upgrade circle-ci config to v2.1 (#8621)
  * remove redundant reference to docs in data formats docs (#8652)
  * alphabetize external plugins list (#8647)
  * Open Hardware Monitor (#8646)
  * outputs/http: add option to control idle connection timeout (#8055)
  * Lgtm config (#8625)
  * update influxdb_v2 config documentation in main (#8618)
  * update intel powerstat readme (#8600)
  * common/tls: Allow specifying SNI hostnames (#7897)
  * Fix spelling and clarify docs (#8164)
  * fixed formatting (+1 squashed commit) (#8541)
  * Provide method to include core count when reporting cpu_usage in procstat input (#6165)
  * Add support for an inclusive job list in Jenkins plugin (#8287)
  * improve the error log message for snmp trap (#8552)
  * [http_listener_v2] Stop() succeeds even if fails to start (#8502)
  * Unify comments style in the CPU input (#8605)
  * Fix readme link for line protocol in influx parser (#8610)
  * Add hex_key parameter for IPMI input plugin connection (#8524)
  * Add configurable number of 'most recent' date-stamped indices to gather in Elasticsearch input (#8543)
  * Add more verbose errors to influxdb output (#6061)
  * Allow globs (wildcards) in config for tags/fields in enum processor (#8598)
  * [ethtool] interface_up field added (#8590)
  * changed TestThreadStats acc to wait for 2 and added warning comment (#8592)
  * Add wildcard tags json parser support (#8579)
  * update inputs.influxdb readme (#8569)
  * Revert "Update grok package to support for field names containing '-' and '.' (#8276)"
  * Revert "disable flakey grok test for now"
  * fix potential issue with race condition (#8577)
  * fix issue with mqtt concurrent map write (#8562)
  * Added Glob pattern matching for "Windows Services" plugin (#8575)
  * Add prometheus remote write serializer (#8360)
  * Typo in INPUTS.md (#8573)
  * Remove duplicated field "revision" from ecs_task because it's already defined as a tag there (#8574)
  * fix crash when socket_listener receiving invalid data (#8551)
  * Graphite tags parser (#8564)
  * Update json parser readme (#8532)
  * Add per user metrics to mysql input (#6132)
  * Fix typo in CONTRIBUTING.md (#8528)
  * Fixing issue with missing metrics when pod has only pending containers (#8472)
  * fix edge case in aerospike plugin where an expected hex string was converted to integer if all digits (#8542)
  * [inputs.github] Add query of pull-request statistics (#8500)
  * New Intel PowerStat input plugin (#8488)
  * Update string parsing of allocatable cpu cores in kube_inventory (#8512)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.17.3:
  * plugins/filestat: Skip missing files (#7316)
  * Update go version to 1.15.8 (#8868)
  * Bump github.com/gopcua/opcua from 0.1.12 to 0.1.13 (#8744)
  * outputs/warp10: url encode comma in tags value (#8657)
  * inputs.x509_cert: Fix timeout issue  (#8824)
  * update min Go version in Telegraf readme (#8846)
  * Fix reconnection issues mqtt (#8821)
  * Validate the response from InfluxDB after writing/creating a database to avoid json parsing panics/errors (#8775)
  * Expose v4/v6-only connection-schemes through GosnmpWrapper (#8804)
  * adds missing & to flush_jitter output ref (#8838)
  * Sort and timeout is deadline (#8839)
  * Update README for inputs.ping with correct cmd for native ping on Linux (#8787)
  * Update go-ping to latest version (#8771)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.17.2:
  * Set interface for native (#8770)
  * Resolve regression, re-add missing function (#8764)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.17.1:
  * avoid issues with vendored dependencies when running make
  * [outputs.influxdb_v2] add exponential backoff, and respect client error responses (#8662)
  * add line about measurement being specified in docs (#8734)
  * Fix issue with elasticsearch output being really noisy about some errors (#8748)
  * Add geoip external project reference
  * improve mntr regex to match user specific keys. (#7533)
  * Fix crash in lustre2 input plugin, when field name and value (#7967)
  * Update grok-library to v1.0.1 with dots and dash-patterns fixed. (#8673)
  * Use go-ping for "native" execution in Ping plugin (#8679)
  * fix x509 cert timeout issue (#8741)
  * Add setting to enable caching in ipmitool (#8335)
  * Bump github.com/nsqio/go-nsq from 1.0.7 to 1.0.8 (#8714)
  * Bump github.com/Shopify/sarama from 1.27.1 to 1.27.2 (#8715)
  * add kafka connect example to jolokia2 input (#8709)
  * Bump github.com/newrelic/newrelic-telemetry-sdk-go from 0.2.0 to 0.5.1 (#8712)
  * Add Event Log support for Windows (#8616)
  * update readme: prometheus remote write (#8683)
  * GNMI plugin should not take off the first character of field keys when no 'alias path' exists. (#8659)
  * Use the 'measurement' json field from the particle webhook as the measurment name, or if it's blank, use the 'name' field of the event's json. (#8609)
  * Procstat input plugin should use the same timestamp in all metrics in the same Gather() cycle. (#8658)
  * update data formats output docs (#8674)
  * Add timestamp column support to postgresql_extensible (#8602)
  * Added ability to define skip values in csv parser (#8627)
  * fix some annoying tests due to ports in use
  * Optimize SeriesGrouper & aggregators.merge (#8391)
  * Using mime-type in prometheus parser to handle protocol-buffer responses (#8545)
  * Input SNMP plugin - upgrade gosnmp library to version 1.29.0 (#8588)
  * Upgrade circle-ci config to v2.1 (#8621)
  * remove redundant reference to docs in data formats docs (#8652)
  * alphabetize external plugins list (#8647)
  * Open Hardware Monitor (#8646)
  * outputs/http: add option to control idle connection timeout (#8055)
  * update influxdb_v2 config documentation in main (#8618)
  * update intel powerstat readme (#8600)
  * common/tls: Allow specifying SNI hostnames (#7897)
  * Fix spelling and clarify docs (#8164)
  * fixed formatting (+1 squashed commit) (#8541)
  * Provide method to include core count when reporting cpu_usage in procstat input (#6165)
  * Add support for an inclusive job list in Jenkins plugin (#8287)
  * improve the error log message for snmp trap (#8552)
  * [http_listener_v2] Stop() succeeds even if fails to start (#8502)
  * Unify comments style in the CPU input (#8605)
  * Fix readme link for line protocol in influx parser (#8610)
  * Add hex_key parameter for IPMI input plugin connection (#8524)
  * Add more verbose errors to influxdb output (#6061)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.17.0:
  * Allow globs (wildcards) in config for tags/fields in enum processor (#8598)
  * [ethtool] interface_up field added (#8590)
  * changed TestThreadStats acc to wait for 2 and added warning comment (#8592)
  * Add wildcard tags json parser support (#8579)
  * update inputs.influxdb readme (#8569)
  * update etc/telegraf.conf
  * Revert "Update grok package to support for field names containing '-' and '.' (#8276)"
  * Revert "disable flakey grok test for now"
  * fix potential issue with race condition (#8577)
  * fix issue with mqtt concurrent map write (#8562)
  * Added Glob pattern matching for "Windows Services" plugin (#8575)
  * Add prometheus remote write serializer (#8360)
  * Typo in INPUTS.md (#8573)
  * Remove duplicated field "revision" from ecs_task because it's already defined as a tag there (#8574)
  * fix crash when socket_listener receiving invalid data (#8551)
  * Graphite tags parser (#8564)
  * Update json parser readme (#8532)
  * Add per user metrics to mysql input (#6132)
  * Fix typo in CONTRIBUTING.md (#8528)
  * Fixing issue with missing metrics when pod has only pending containers (#8472)
  * fix edge case in aerospike plugin where an expected hex string was converted to integer if all digits (#8542)
  * [inputs.github] Add query of pull-request statistics (#8500)
  * New Intel PowerStat input plugin (#8488)
  * Update string parsing of allocatable cpu cores in kube_inventory (#8512)
  * disable flakey grok test for now
  * Fixed misspelled check for datacenter (#8505)
  * feat: add build number field to jenkins_job measurement (#8038)
  * Add percentiles to the ping plugin (#7345)
  * Added tags for monitoring readable secondaries for Azure SQL MI (#8369)
  * SQL Server HA/DR Availability Group queries (#8379)
  * Add initialization example to mock-plugin. (#8520)
  * Add support to convert snmp hex strings to integers (#8426)
  * Update kube_inventory readme (#8510)
  * Update circleci mac golang version (#8516)
  * Adding support for new lines in influx line protocol fields. (#8499)
  * Add configurable Max TTL duration for statsd input plugin entries (#8509)
  * Fix carbon2 tests (#8254)
  * fixed network test (#8498)
  * Add configurable timeout to bind input plugin http call (#8508)
  * Added is_primary_replica for monitoring readable secondaries for Azure SQL DB (#8368)
  * sqlAzureMIRequests - remove duplicate column [session_db_name] (#8462)
  * Add column measurement_db_type to output of all queries if not empty (#8464)
  * Add node groups to opcua input plugin (#8389)
  * Add a parser plugin for prometheus (#7778)
  * Update grok package to support for field names containing '-' and '.' (#8276)
  * add to starlark readme
  * add support for linux/ppc64le (#8432)
  * Add FLOAT64-IEEE support to inputs.modbus (#8361) (by @Nemecsek) (#8474)
  * Add the shared state to the global scope to get previous data (#8447)
  * Log SubscribeResponse_Error message and code. #8482 (#8483)
  * Removed outdated information about Windows support (#7971)
  * Add dataset metrics to zfs input (#8383)
  * add log warning to starlark drop-fields example
  * update godirwalk to v1.16.1 (#7987)
  * Support Riemann-Protobuff Listener (#8163)
  * Starlark example dropbytype (#8438)
  * Added "name" parameter to NATS output plugin (#8429)
  * proxy support for http input (#8477)
  * Translate snmp field values (#8466)
  * Update CONTRIBUTING.md
  * Fix typo in column name (#8468)
  * [php-fpm] Fix possible "index out of range" (#8461)
  * Enable kafka zstd compression and idempotent writes (#8435)
  * Fix tests for Windows - part 1 (#8414)
  * Add response_time to monit plugin (#8056)
  * update to go 1.15.5 (#8446)
  * Add rate and interval to the basicstats aggregator plugin (#8428)
  * Update mdlayher/apcupsd dependency (#8444)
  * Show how to return a custom error with the Starlark processor (#8439)
  * keep field name as is for csv timestamp column (#8440)
  * Add DriverVersion and CUDA Version to output (#8436)
  * Show how to return several metrics with the Starlark processor (#8423)
  * fix config issue with tags (#8419)
  * Support logging in starlark (#8408)
  * add kinesis output to external plugins list (#8315)
  * Add non-retryable debug logging (#8406)
  * Wavefront output should distinguish between retryable and non-retryable errors (#8404)
  * Allow to catch errors that occur in the apply function (#8401)
  * Fix parsing of multiple files with different headers (#6318). (#8400)
  * proxmox: ignore QEMU templates and iron out a few bugs (#8326)
  * systemd_units: add --plain to command invocation (#7990) (#7991)
  * fix links in external plugins readme (#8307)
  * Fix minor typos in readmes (#8370)
  * Revert "fix to start Telegraf from Linux systemd.service"
  * Fix SMART plugin to recognize all devices from config (#8374)
  * fix to start Telegraf from Linux systemd.service
  * Add OData-Version header to requests (#8288)
  * fixes config issue #8362 (#8364)
  * shorten config (#7583)
  * Prydin issue 8169 (#8357)
  * On-prem fix for #8324 (#8356)
  * [output.wavefront] Introduced "immediate_flush" flag (#8165)
  * Initial Yandex.Cloud monitoring (#8296)
  * added support for bytes encoding (#7938)
  * Update jwt-go module to address CVE-2020-26160 (#8337)
  * fix plugins/input/ras test (#8350)
  * Fixed a bug with the state map in Dynatrace Plugin (#8329)
  * SQL Server Azure PerfCounters Fix (#8331)
  * kafka sasl-mechanism auth support for SCRAM-SHA-256, SCRAM-SHA-512, GSSAPI (#8318)
  * SQL Server - PerformanceCounters - removed synthetic counters (#8325)
  * SQL Server - server_properties added sql_version_desc (#8324)
  * Disable RAS input plugin on specific Linux architectures: mips64, mips64le, ppc64le, riscv64 (#8317)
  * processes: fix issue with stat no such file/dir (#8309)
  * fix issue with PDH_CALC_NEGATIVE_DENOMINATOR error (#8308)
  * RAS plugin - fix for too many open files handlers (#8306)
  * A new Logz.io output plugin (#8202)
  * Get the build version from a static file
  * Update next_version to 1.17.0
  * Sumo Logic output plugin: fix unparsable config.Size from sample config (#8243)
  * Fix wrong memory measurements of containers and vms (#8290)
  * New input plugin for RAS with fixed GLIBC issue (#8293)
  * fix issue with phpfpm url usage (#8292)
  * Update sarama library to 1.27.1 (#8289)
  * sqlAzureMIResourceStats - added sorting (#8286)
  * Fix using empty string as the namespace prefix in azure_monitor output plugin (#8282)
  * Fix Event timestamps (#8216)
  * Add support for fields and protocol lookups in port_name. (#8157)
  * fix flakey proc test (#8279)
  * Skip statically linked program during glibc version check (#8280)
  * remove unused dependency from list
  * Add glibc version check for linux builds (#8278)
  * go mod tidy
  * temporarily remove RAS plugin
  * http_response: match on status code (#8032)
  * turn gzip on by default for InfluxDB v1 output (#8269)
  * Dynatrace Output Plugin: Fixed behaviour when state map is cleared (#8251)
  * Add the Timestream Output Plugin  (#8239)
  * fix issue with loading processor config from execd (#8274)
  * cleanup Intel RDT readme (#8268)
  * fix(exec): fix typo in exec readme (#8265)
  * fix(ras): update readme title (#8266)
  * add plugin documentation
  * execd-systemd-timings: Add telegraf-execd-systemd-timings to the list (#8263)
  * Sumo Logic output plugin: only support HTTP POST (#8262)
  * New sql server queries (on-prem) - refactoring and formatting (#8172)
  * Update README.md (#8049)
  * fix ci test
  * add converter test
  * fix flakey tests
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.16.3:
  * Log SubscribeResponse_Error message and code. #8482 (#8483)
  * add log warning to starlark drop-fields example
  * update godirwalk to v1.16.1 (#7987)
  * Starlark example dropbytype (#8438)
  * Fix typo in column name (#8468)
  * [php-fpm] Fix possible "index out of range" (#8461)
  * Update mdlayher/apcupsd dependency (#8444)
  * Show how to return a custom error with the Starlark processor (#8439)
  * keep field name as is for csv timestamp column (#8440)
  * Add DriverVersion and CUDA Version to output (#8436)
  * Show how to return several metrics with the Starlark processor (#8423)
  * Support logging in starlark (#8408)
  * add kinesis output to external plugins list (#8315)
  * Add non-retryable debug logging (#8406)
  * Wavefront output should distinguish between retryable and non-retryable errors (#8404)
  * Allow to catch errors that occur in the apply function (#8401)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.16.2:
  * Fix parsing of multiple files with different headers (#6318). (#8400)
  * proxmox: ignore QEMU templates and iron out a few bugs (#8326)
  * systemd_units: add --plain to command invocation (#7990) (#7991)
  * fix links in external plugins readme (#8307)
  * Fix minor typos in readmes (#8370)
  * Fix SMART plugin to recognize all devices from config (#8374)
  * Add OData-Version header to requests (#8288)
  * misc tests
  * Prydin issue 8169 (#8357)
  * On-prem fix for #8324 (#8356)
  * [output.wavefront] Introduced "immediate_flush" flag (#8165)
  * added support for bytes encoding (#7938)
  * Update jwt-go module to address CVE-2020-26160 (#8337)
  * fix plugins/input/ras test (#8350)
  * Fixed a bug with the state map in Dynatrace Plugin (#8329)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.16.1:
  * common.kafka kafka sasl-mechanism auth support for SCRAM-SHA-256, SCRAM-SHA-512, GSSAPI (#8318)
  * inputs.sqlserver SQL Server Azure PerfCounters Fix (#8331)
  * inputs.sqlserver SQL Server - PerformanceCounters - removed synthetic counters (#8325)
  * inputs.sqlserver SQL Server - server_properties added sql_version_desc (#8324)
  * inputs.ras Disable RAS input plugin on specific Linux architectures: mips64, mips64le, ppc64le, riscv64 (#8317)
  * inputs.processes processes: fix issue with stat no such file/dir (#8309)
  * inputs.win_perf_counters fix issue with PDH_CALC_NEGATIVE_DENOMINATOR error (#8308)
  * inputs.ras RAS plugin - fix for too many open files handlers (#8306)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.16.0:
  * Set 1.16.0 release date
  * Update etc/telegraf.conf
  * go mod tidy
  * Sumo Logic output plugin: fix unparsable config.Size from sample config (#8243)
  * Fix wrong memory measurements of containers and vms (#8290)
  * New input plugin for RAS with fixed GLIBC issue (#8293)
  * fix issue with phpfpm url usage (#8292)
  * Add support for fields and protocol lookups in port_name. (#8157)
  * go mod tidy
  * turn gzip on by default for InfluxDB v1 output (#8269)
  * fix(exec): fix typo in exec readme (#8265)
  * Update README.md (#8049)
  * fix ci test
  * add converter test
  * Update sarama library to 1.27.1 (#8289)
  * sqlAzureMIResourceStats - added sorting (#8286)
  * Fix using empty string as the namespace prefix in azure_monitor output plugin (#8282)
  * Fix Event timestamps (#8216)
  * fix flakey tests
  * fix flakey proc test (#8279)
  * Skip statically linked program during glibc version check (#8280)
  * remove unused dependency from list
  * Add glibc version check for linux builds (#8278)
  * go mod tidy
  * temporarily remove RAS plugin
  * http_response: match on status code (#8032)
  * Dynatrace Output Plugin: Fixed behaviour when state map is cleared (#8251)
  * Add the Timestream Output Plugin  (#8239)
  * fix issue with loading processor config from execd (#8274)
  * cleanup Intel RDT readme (#8268)
  * execd-systemd-timings: Add telegraf-execd-systemd-timings to the list (#8263)
  * Sumo Logic output plugin: only support HTTP POST (#8262)
  * add plugin documentation
  * New sql server queries (on-prem) - refactoring and formatting (#8172)
  * Update etc/telegraf.conf
  * Add agent host tag configuration option (#8082)
  * Fixed almost all bugs found by LGTM analysis platform (#8240)
  * fix carbon tests
  * Multiple escaping occurs on Jenkins URLs at certain folder depth (#8048)
  * Fix bool serialization when using carbon2 (#8162)
  * add plugin authors to changelog
  * remote duplicate changelog entries
  * update to go 1.15 (#8220)
  * New sql server queries (Azure) - refactoring and formatting (#8186)
  * change influxdb port 9999 to 8086 (#8198)
  * input consul - added metric_version flag (#7875)
  * Fix carbon2 serializer not falling through to field separate when carbon2_format field is unset (#8201)
  * Fixed Query mapping (#8200)
  * add min telegraf to plugin readme (#8223)
  * New input plugin for RAS (Reliability, Availability and Serviceability) (#8114)
  * New input plugin for Intel RDT (Intel Resource Director Technology) (#8150)
  * Update telegraf.conf
  * update gopsutil: fix procstat performance regression (#8210)
  * fix(win_eventlog): fixing config (#8209)
  * Add note about json processing to docs
  * Missing ServiceNow metrics in DATA_FORMATS_OUTPUT.md (#8205)
  * Dynatrace Output: change handling of monotonic counters (#8159)
  * fix: plugins/parsers/influx: avoid ParseError.Error panic (#8177)
  * Fix vulnerabilities found in BDBA scan (#8199)
  * feat: add functionality to get values from redis commands (#8196)
  * Implement AWS CloudWatch Input Plugin ListMetrics API calls to use Active Metric Filter (#7894)
  * add json parsing support to starlark (#8168)
  * Sumo Logic output plugin: carbon2 default to include field in metric (#8132)
  * If the community string is available, add it as a tag (#8189)
  * Windows eventlog input plugin (based on #7020) (#8000)
  * Semigroupoid multiline (#8167) (#8190)
  * fix panic on streaming processers using logging (#8176)
  * Add more missing NVMe attributes to smart plugin (#8113)
  * Fix Sumo Logic output plugin not splitting requests properly (#25) (#8115)
  * Added more performance counters to SqlServer input plugin (#8120)
  * Starlark readme url fix
  * minor docs cleanup
  * update shim docs to point users in the right direction
  * Increasing the metric buffer (#8145)
  * Remove Event field as it is causing issues with pre-trained source types (#8039)
  * influxdb_v2_listener - add /ready route (#8133)
  * Add octoprint to list (#8131)
  * add influxdata slack icon to telegraf readme (#8126)
  * Sort plugin name lists for output (#8127)
  * Doc update: Fix main.go shim example link (#8123)
  * Influxdb v2 listener (#7828)
  * Fix bug fix typo in changelog (#8117)
  * update 1.16 changelog with new plugins (#8107)
  * SNMP input plugin: document partial table collection (#8104)
  * Carbon2 configuration option - include field in metric name (#8094)
  * Sumo Logic output plugin (#8023)
  * Revert "update influxdb v2 port"
  * update influxdb v2 port
  * Database_type config to Split up sql queries by engine type (#7934)
  * added force_document_id option to ES output enable resend data and avoiding duplicated ES documents, fix #7891 (#8019)
  * [fix] add missing error check for HTTP req failure (#8071)
  * add nsd input plugin (#7822)
  * Fix external plugin docs links (#8081)
  * Opcua cleanup (#8076)
  * update opcua readme (#8075)
  * add tagpass/tagdrop note in docs (#8053)
  * add guidelines run to external plugins with execd (#8054)
  * Fix docker-image make target (#8005)
  * Add OPC UA input plugin (#8009)
  * Update gopsutils to v.2.20.7 (#8073)
  * Fix CI AppVeyor 'make check' errors for go 1.15 on windows (#8061)
  * fix bug in shim logger affecting AddError (#8052)
  * fix docker build. update dockerfiles to Go 1.14 (#8051)
  * Add set, and histogram reporting to aerospike telegraf plugin (#8025)
  * Create external plugins doc file and update contributing guide (#8001)
  * Add addTag debugging in ifname plugin (#8018)
  * vSphere Fixed missing clustername issue 7878 (#8026)
  * Fix string to int conversion in eventhub consumer (#8006)
  * improve the quality of starlark docs by executing them as tests (#8020)
  * Fix InsecureSkipVerify in Dynatrace Plugin (#8015)
  * Fix Ping Input plugin for FreeBSD's ping6 (#7861)
  * add example input/outputs to starlark examples (#7980)
  * Fix configuration.md formatting (#7965)
  * [agent] Cleanup duplicates in loaded plugins list (#7852)
  * [outputs.application_insights] Added the ability to set the endpoint url (#7134)
  * fix issue with shim use of config.Duration (#7996)
  * fix minor agent race condition around error messages (#7999)
  * fix flakey ticker test (#7997)
  * Dynatrace Plugin - Updated Documentation (#7994)
  * http_listener_v2: make http header tags case insensitive (#7986)
  * fix(readmes): updates to internal and proxmox readmes (#7982)
  * Update Support.md
  * Create Support.md
  * add label to feature request.
  * Update Bug_report.md
  * Proxmox plugin (#7922)
  * Dynatrace output plugin (#7881)
  * add additional metrics to clickhouse input plugin (#7904)
  * add pivot example for starlark processor (#7976)
  * fix(puppet): update broken link (#7977)
  * fix(ipmi): update link in readme (#7975)
  * chore: extend gitignore to ignore .DS_Store (#7974)
  * fix(readmes): standarize first line of readmes (#7973)
  * Updated http_response input plugin README.md (#7962)
  * fix(readmes): adding code block annotations (#7963)
  * rabbitmq: remove deprecated healthcheck (#7823) (#7920)
  * added new counter - Lock Timeouts (timeout > 0)/sec (#7808)
  * fix cloudwatch tests
  * Support for AWS Cloudwatch Alarms #7931 (#7932)
  * cleanup cloudwatch plugin (#7928)
  * Add details to connect to InfluxDB OSS 2 and Cloud 2 (#7953)
  * JSON does not support values NaN and Inf (#7908)
  * Add descriptions for measurement & fields (#7902)
  * Fixed title on New Relic README.md (#7948)
  * Fix tail following on EOF (#7927)
  * fix broken link to proc.c (#7918)
  * fixes issue with rpm /var/log/telegraf permissions (#7909)
  * MongoDB: Added new metric "pages written from cache" (#7870)
  * Fix/extend support of fixed point values on input (modbus plugin) (#7869)
  * jolokia: add some error message context (#7906)
  * fixed cgroups docu (#7889)
  * Fix arch name in deb/rpm builds (#7877)
  * shim logger improvements (#7865)
  * Fix defaults processor readme typos (#7873)
  * Recv next message after send returns EOF (#7872)
  * Update docker FAQ (#7868)
  * fix issue with execd restart_delay being ignored (#7867)
  * Add logic starlark example (#7864)
  * clarify docs and add warning if execd is misconfigured (#7866)
  * Print configuration for downloads page (#7862)
  * prefer testify error funcs over nil checks (#7857)
  * Fix suricata input docs (#7856)
  * ifname: avoid unpredictable conditions in getMap test (#7848)
  * Log after interval has elapsed; skip short intervals (#7854)
  * Initialize aggregation processors (#7853)
  * Update redfish docs with link (#7846)
  * Update telegraf.conf
  * ifname processor: expire old cached entries (#7838)
  * update go versions: 1.14.5, 1.13.13 (#7837)
  * Edit Starlark README (#7832)
  * Send metrics in FIFO order (#7814)
  * Add github.com/inabagumi/youtube-telegraf-plugin to list of external plugins (#7825)
  * Set log output before starting plugin (#7820)
  * fix bug with loading plugins in shim with no config (#7816)
  * Fix darwin package build flags (#7818)
  * Close file to ensure it has been flushed (#7819)
  * documentation: typo outputs cloud_pubsub (#7817)
  * fix typo in cloud_pubsub docs (#7815)
  * Add minimum version for new plugins (#7810)
  * Fix markdown syntax (#7806)
  * Fix typo in 1.15 release notes (#7804)
  * Fix tag package version
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.15.4:
  * fix issue with loading processor config from execd (#8274)
  * fix panic on streaming processers using logging (#8176)
* Sat Sep 12 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- BuildRequires: golang(API) >= 1.13
  * Recommended format selects latest Provides: golang(API) = %%{api_version}
    satisfied by either go metapackage or go1.1x packages.
* Sat Sep 12 2020 dmueller@suse.com
- Update to version 1.15.3:
  * Revert "fix cloudwatch tests"
  * Update etc/telegraf.conf
  * [fix] add missing error check for HTTP req failure (#8071)
  * add tagpass/tagdrop note in docs (#8053)
  * Fix docker-image make target (#8005)
  * Fix CI AppVeyor 'make check' errors for go 1.15 on windows (#8061)
  * add release notes
  * fix bug in shim logger affecting AddError (#8052)
  * fix docker build. update dockerfiles to Go 1.14 (#8051)
  * docs fix
  * Create external plugins doc file and update contributing guide (#8001)
  * Add addTag debugging in ifname plugin (#8018)
  * vSphere Fixed missing clustername issue 7878 (#8026)
  * Fix string to int conversion in eventhub consumer (#8006)
  * improve the quality of starlark docs by executing them as tests (#8020)
  * Fix Ping Input plugin for FreeBSD's ping6 (#7861)
  * add example input/outputs to starlark examples (#7980)
  * Fix configuration.md formatting (#7965)
  * [outputs.application_insights] Added the ability to set the endpoint url (#7134)
  * fix issue with shim use of config.Duration (#7996)
  * fix minor agent race condition around error messages (#7999)
  * http_listener_v2: make http header tags case insensitive (#7986)
  * add pivot example for starlark processor (#7976)
  * fix(puppet): update broken link (#7977)
  * fix(ipmi): update link in readme (#7975)
  * chore: extend gitignore to ignore .DS_Store (#7974)
  * fix(readmes): standarize first line of readmes (#7973)
  * Updated http_response input plugin README.md (#7962)
  * added new counter - Lock Timeouts (timeout > 0)/sec (#7808)
  * fix cloudwatch tests
  * Support for AWS Cloudwatch Alarms #7931 (#7932)
  * Add details to connect to InfluxDB OSS 2 and Cloud 2 (#7953)
  * JSON does not support values NaN and Inf (#7908)
  * Add descriptions for measurement & fields (#7902)
  * Fixed title on New Relic README.md (#7948)
  * fix broken link to proc.c (#7918)
  * Fix/extend support of fixed point values on input (modbus plugin) (#7869)
  * jolokia: add some error message context (#7906)
  * fixed cgroups docu (#7889)
  * Update docker FAQ (#7868)
  * fixes issue with rpm /var/log/telegraf permissions (#7909)
  * Fix tail following on EOF (#7927)
  * Fix arch name in deb/rpm builds (#7877)
  * Set 1.15.0 release date
  * Add logic starlark example (#7864)
  * shim logger improvements (#7865)
  * Fix defaults processor readme typos (#7873)
  * Recv next message after send returns EOF (#7872)
  * fix issue with execd restart_delay being ignored (#7867)
  * clarify docs and add warning if execd is misconfigured (#7866)
  * fix bug with loading plugins in shim with no config (#7816)
  * Fix suricata input docs (#7856)
  * ifname: avoid unpredictable conditions in getMap test (#7848)
  * Log after interval has elapsed; skip short intervals (#7854)
  * Initialize aggregation processors (#7853)
  * Update redfish docs with link (#7846)
  * Update telegraf.conf
  * ifname processor: expire old cached entries (#7838)
  * update go versions: 1.14.5, 1.13.13 (#7837)
  * Edit Starlark README (#7832)
  * Send metrics in FIFO order (#7814)
  * Set log output before starting plugin (#7820)
  * Fix darwin package build flags (#7818)
  * Close file to ensure it has been flushed (#7819)
  * Add minimum version for new plugins (#7810)
  * Fix markdown syntax (#7806)
  * Fix typo in 1.15 release notes (#7804)
  * Fix tag package version
  * Update sample configuration
  * Add ifname processor plugin (#7763)
  * Traverse redfish api using resource links (#7722)
  * Fix test race in kafka_consumer (#7797)
  * Support utf-16 in file and tail inputs (#7792)
  * Add v3 metadata support to ecs input (#7154)
  * Fix inputs.execd readme links (#7791)
  * Fix data race in input plugin ping_windows
  * streaming processors docs update (#7786)
  * switch mac tests to Go 1.14 (#7784)
  * Fix flakey processors.execd test
  * Do not enable -race for GOARCH=386
  * Run all Go tests with flag -race
  * Fix data race in plugin output pubsub tests (#7782)
  * Shim refactor to support processors and output
  * Fix data race in tail input tests (#7780)
  * Update CHANGELOG.md
  * execd output (#7761)
  * Set user agent when requesting http config (#7752)
  * Accept decimal point when parsing kibana uptime (#7768)
  * Update common/tls import path
  * Update nginx_sts plugin readme
  * Add nginx_sts input plugin (#7205)
  * Rename cisco_telemetry_gnmi input to gnmi (#7695)
  * Allow overriding the collection_jitter and precision per input (#7762)
  * Fix data race in phpfpm initializing http client (#7738)
  * Set 1.14.5 release date
  * Allow histograms with no buckets and summary without quantiles (#7740)
  * Fix typo in elasticsearch input docs (#7764)
  * Only set version ldflags on tags
  * Update release notes
  * Allow any key usage type on x509 certificate (#7760)
  * Build packages in makefile (#7759)
  * Update github.com/tidwall/gjson (#7756)
  * reverse dns lookup processor (#7639)
  * remove streaming processors docs
  * clean up tests
  * address feedback
  * Return on toml parse errors instead of logging (#7751)
  * Update tls import path
  * Export internal/tls package for use in execd plugins (#7697)
  * Add laundry to mem input plugin on FreeBSD (#7736)
  * Fix data race in plugins/inputs/stackdriver/stackdriver_test.go (#7744)
  * Fix data race in plugins/inputs/suricata/suricata_test.go (#7745)
  * Fix data race in kafka_consumer_test.go (#7737)
  * Fix SNMP trap test race (#7731)
  * Fix incorrect Azure SQL DB server properties (#7715)
  * fix race
  * fix after rebase
  * remove processors/execd/examples/count.go
  * execd processor
  * Fix license check
  * Add starlark processor (#7660)
  * Add missing nvme attributes to smart plugin (#7575)
  * Add counter type to perfmon collector (#7712)
  * Skip overs errors in the output of the sensors command (#7718)
  * Remove master/slave terminology from tests (#7719)
  * Fix ping exit code handling on non-Linux (#7658)
  * Add redfish input plugin (#7082)
  * Add ability to add selectors as tags in kube_inventory (#7267)
  * Document that string fields do not produce prometheus metrics (#7644)
  * Remove trailing backslash management in sqlserver input (#7700)
  * Link to GJSON playground in json parser documentation (#7698)
  * Add 'batch' to mqtt output optional parameters (#7690)
  * Fail check-deps when differences are found (#7694)
  * Add state and readiness to kube_inventory pod metrics (#7691)
  * update CHANGELOG.md
  * procstat performance enhancement (#7686)
  * Mark unused agent options as deprecated
  * Fix processor initialization (#7693)
  * Update gNMI plugin readme (#7685)
  * Remove trailing backslash from tag keys/values (#7652)
  * Improve sqlserver input compatibility with older server versions (#7495)
  * Fix race issue in tick_test.go (#7663)
  * Flaky shim test (#7656)
  * link to glob pattern docs (#7657)
  * Set 1.14.4 release date
  * Add ability to collect response body as field with http_response (#7596)
  * Add timezone configuration to csv data format (#7619)
  * Change rpm dist packaging type for arm64 to aarch64 (#7645)
  * Update to github.com/shirou/gopsutil v2.20.5 (#7641)
  * Fix source field for icinga2 plugin (#7651)
  * Add video codec stats to nvidia-smi (#7646)
  * Update CHANGELOG.md
  * fix issue with stream parser blocking when data is in buffer (#7631)
  * add support for streaming processors (#7634)
  * Add tags to snmp_trap input for context name and engine ID (#7633)
  * Clarify use of multiple mqtt broker servers
  * Add SNMPv3 trap support to snmp_trap input plugin (#7294)
  * Add support for Solus distribution to maintainer scripts (#7585)
  * Fix typo in queue depth example of diskio plugin (#7613)
  * Add support for env variables to shim config (#7603)
  * Add support for once mode; run processors and aggregators during test (#7474)
  * Update AGGREGATORS_AND_PROCESSORS.md (#7599)
  * Add github.com/inabagumi/twitter-telegraf-plugin to list of external plugins
  * Fix segmentation violation on connection failed (#7593)
  * Add processor to look up service name by port (#7540)
  * make sure parse error includes offending text (#7561)
  * Update docs for newrelic output
  * Add newrelic output plugin  (#7019)
  * Allow collection of HTTP Headers in http_response input (#7405)
  * Update to Go 1.14.3 with testing using 1.13.11 (#7564)
  * Exclude csv_timestamp_column and csv_measurement_column from fields (#7572)
  * fix go version check (#7562)
  * Fix the typo in `gcc_pu_fraction` to `gc_cpu_fraction` (#7573)
  * Fix numeric to bool conversion in converter (#7579)
  * Add defaults processor to set default field values (#7370)
  * Add option to disable mongodb cluster status (#7515)
  * Fix typos in sqlserver input (#7524)
  * Use updated clock package to resolve test failures (#7516)
  * fix randomly failing CI test (#7514)
  * Add cluster state integer to mongodb input (#7489)
  * Add configurable separator graphite serializer and output (#7545)
  * Fix instance name resolution in performance counter query (#7526)
  * Set 1.14.3 release date
  * Close HTTP2 connections on timeout in influxdb outputs (#7517)
  * Fix negative value parsing in impi_sensor input (#7541)
  * Fix assorted spelling mistakes (#7507)
  * Fix documentation of percent_packet_loss field (#7510)
  * Update docs for execd plugins (#7465)
  * Update procstat pid_tag documentation
  * Fix spelling errors in comments and documentation (#7492)
  * Add truncate_tags setting to wavefront output (#7503)
  * Add authentication support to the http_response input plugin (#7491)
  * Handle multiple metrics with the same timestamp in dedup processor (#7439)
  * Add additional fields to mongodb input (#7321)
  * Add integer support to enum processor (#7483)
  * Fix typo in Windows service description (#7486)
  * Add field creation to date processor and integer unix time support (#7464)
  * Add cpu query to sqlserver input (#7359)
  * Rework plugin tickers to prevent drift and spread write ticks (#7390)
  * Update datadog output documentation (#7467)
  * Use docker log timestamp as metric time (#7434)
  * fix issue with execd-multiline influx line protocol (#7463)
  * Add information about HEC JSON format limitations and workaround (#7459)
  * Rename measurement to sqlserver_volume_space (#7457)
  * shim improvements for docs, clean quit, and slow readers (#7452)
  * Fix gzip support in socket_listener with tcp sockets (#7446)
  * Remove debug fields from spunkmetric serializer (#7455)
  * Fix filepath processor link in changelog (#7454)
  * Support Go execd plugins with shim (#7283)
  * Add filepath processor plugin (#7418)
  * Add ContentEncoder to socket_writer for datagram sockets (#7417)
  * Sflow rework (#7253)
  * Use same timestamp for all objects in arrays in the json parser (#7412)
  * Set 1.14.2 release date
  * Allow CR and FF inside of string fields and fix parser panic (#7427)
  * Fix typo in name of gc_cpu_fraction field (#7425)
  * Run create database query once per database (#7333)
  * Ignore fields with NaN or Inf floats in the JSON serializer (#7426)
  * Fix interfaces with pointers (#7411)
  * Document distinction between file and tail inputs (#7353)
  * Update changelog
  * Fix shard indices reporting in elasticsearch input (#7332)
  * Update changelog
  * Fix string to int64 conversion for SNMP input (#7407)
  * Update nvidia-smi README for Windows users (#7399)
  * Extract target as a tag for each rule in iptables input (#7391)
  * Fix dimension limit on azure_monitor output (#7336)
  * Use new higher per request limit for cloudwatch GetMetricData (#7335)
  * Add support for MDS and RGW sockets to ceph input (#6915)
  * Add option to save retention policy as tag in influxdb_listener (#7356)
  * Trim instance tag in the sqlserver performance counters query (#7351)
  * Fix vSphere 6.7 missing data issue (#7233)
  * Update modbus readme
  * Add retry when slave is busy to modbus input (#7271)
  * fix issue with closing flush signal channel (#7384)
  * Use the product token for the user agent in more locations (#7378)
  * Update github.com/aws/aws-sdk-go (#7373)
  * add support for SIGUSR1 to trigger flush (#7366)
  * add another grok example for custom timestamps (#7367)
  * Fibaro input: for battery operated devices, add battery level scraping (#7319)
  * Deprecate logparser input and recommend tail input as replacement (#7352)
  * Adjust heading level in the filtering examples to allow linking
  * Set 1.14.1 release date
  * Add reading bearer token from a file to http input (#7304)
  * Fix exclude database and retention policy tags is shared (#7323)
  * Fix status path when using globs in phpfpm (#7324)
  * Regenerate telegraf.conf
  * Fix error in docs about exclude_retention_policy_tag (#7311)
  * Fix Name field in template processor (#7258)
  * Deploy telegraf configuration as a "non config" file (#7250)
  * Fix export timestamp not working for prometheus on v2 (#7289)
  * Sql Server - Disk Space Measurement (#7214)
  * Add series cardinality warning to sflow readme (#7285)
  * Improve documentation for the Metric interface (#7256)
  * Update permission docs on postfix input (#7255)
  * Document kapacitor_alert and kapacitor_cluster measurements (#7278)
  * Add OPTION RECOMPILE for perf reasons due to temp table (#7242)
  * Support multiple templates for graphite serializers (#7136)
  * Add possibility to specify measurement per register (#7231)
  * Add limit to number of undelivered lines to read ahead in tail (#7210)
  * Add docs for how to handle errors in check-deps script (#7243)
  * Add support for 64-bit integer types to modbus input (#7225)
  * Set 1.14.0 release date
  * Apply ping deadline to dns lookup (#7140)
  * Add ability to specify HTTP Headers in http_listener_v2 which will added as tags (#7223)
  * Fix 'nil' file created by Makefile on Windows (#7224)
  * Add additional concurrent transaction information (#7193)
  * Add commands stats to mongodb input plugin (#6905)
  * Fix url encoding of job names in jenkins input plugin (#7211)
  * Update next_version on master to 1.15.0
  * Update etc/telegraf.conf
  * Fix datastore_include option in vsphere input readme
  * Update github.com/prometheus/client_golang to latest (#7200)
  * Update etc/telegraf.conf
  * Update google.cloud.go to latest (#7199)
* Wed May 27 2020 tuukka.pasanen@ilmi.fi
- Update to use _service file to make depency building easier
- Require GO version 1.12 if it in future gets too old it should we
  set to correct version
- Update to version 1.14.3:
  * Set 1.14.3 release date
  * Update changelog
  * Close HTTP2 connections on timeout in influxdb outputs (#7517)
  * Fix negative value parsing in impi_sensor input (#7541)
  * Update changelog
  * Handle multiple metrics with the same timestamp in dedup processor (#7439)
  * Update changelog
  * Use same timestamp for all objects in arrays in the json parser (#7412)
  * Set 1.14.2 release date
  * Update changelog
* Fri Apr  3 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- Remove carried patch for Generic SQL output plugin. The upstream PR
  https://github.com/influxdata/telegraf/pull/4205 that is the source of this
  patch hasn't accepted it since 2018, with no recent activity. Dropping the
  patch as there are no known users.
  * drop 0001-Generic-SQL-output-plugin-for-Telegraf.patch unified original
  * drop 0001-plugins-outputs-all-all.go-Generic-SQL-output-plugin.patch split
  * drop 0002-plugins-outputs-sql-README.md-Generic-SQL-output-plu.patch split
  * drop 0003-plugins-outputs-sql-sql.go-Generic-SQL-output-plugin.patch split
  * drop 0004-plugins-outputs-sql-sql_test.go-Generic-SQL-output-p.patch split
  * drop 0005-README.md-Generic-SQL-output-plugin-for-Telegraf-pat.patch split
  * packaging: telegraf-1.13.4 still uses the dep dependency tool, now
    documented as a comment in the .spec. An upcoming telegraf release will
    complete the transition to go modules, at which point packaging will be
    updated accordingly.
* Wed Mar  4 2020 Johannes Kastl <kastl@b1-systems.de>
- create directory /etc/telegraf/telegraf.d/
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.4
  Bugfixes
  - #6988: Parse NaN values from summary types in prometheus input.
  - #6820: Fix pgbouncer input when used with newer pgbouncer versions.
  - #6913: Support up to 8192 stats in the ethtool input.
  - #7060: Fix perf counters collection on named instances in sqlserver input.
  - #6926: Use add time for prometheus expiration calculation.
  - #7057: Fix inconsistency with input error counting in internal input.
  - #7063: Use the same timestamp per call if no time is provided in prometheus input.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.3
  Bugfixes
  - #5744: Fix kibana input with Kibana versions greater than 6.4.
  - #6960: Fix duplicate TrackingIDs can be returned in queue consumer plugins.
  - #6913: Support up to 4096 stats in the ethtool input.
  - #6973: Expire metrics on query in addition to on add.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.2
  Bugfixes
  - #2652: Warn without error when processes input is started on Windows.
  - #6890: Only parse certificate blocks in x509_cert input.
  - #6883: Add custom attributes for all resource types in vsphere input.
  - #6899: Fix URL agent address form with udp in snmp input.
  - #6619: Change logic to allow recording of device fields when attributes is false.
  - #6903: Do not add invalid timestamps to kafka messages.
  - #6906: Fix json_strict option and set default of true.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.1
  Bugfixes
  - #6788: Fix ServerProperty query stops working on Azure after failover.
  - #6803: Add leading period to OID in SNMP v1 generic traps.
  - #6823: Fix missing config fields in prometheus serializer.
  - #6694: Fix panic on connection loss with undelivered messages in mqtt_consumer.
  - #6679: Encode query hash fields as hex strings in sqlserver input.
  - #6345: Invalidate diskio cache if the metadata mtime has changed.
  - #6800: Show platform not supported warning only on plugin creation.
  - #6814: Fix rabbitmq cannot complete gather after request error.
  - #6846: Fix /sbin/init --version executed on Telegraf startup.
  - #6847: Use last path element as field key if path fully specified.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.0
  - rebased patch 0005-README.md-Generic-SQL-output-plugin-for-Telegraf-pat.patch
  - changelog:
    Release Notes
  - Official packages built with Go 1.13.5.
  - The prometheus input and prometheus_client output have a new mapping to
  - and from Telegraf metrics, which can be enabled by setting metric_version = 2.
  - The original mapping is deprecated. When both plugins have the same setting,
  - passthrough metrics will be unchanged. Refer to the prometheus input for
  - details about the mapping.
    New Inputs
  - azure_storage_queue - Contributed by @mjiderhamn
  - ethtool - Contributed by @philippreston
  - snmp_trap - Contributed by @influxdata
  - suricata - Contributed by @satta
  - synproxy - Contributed by @rfrenayworldstream
  - systemd_units - Contributed by @benschweizer
    New Processors
  - clone - Contributed by @adrianlzt
    New Aggregators
  - merge - Contributed by @influxdata
    Features
  - #6326: Add per node memory stats to rabbitmq input.
  - #6361: Add ability to read query from file to postgresql_extensible input.
  - #5921: Add replication metrics to the redis input.
  - #6177: Support NX-OS telemetry extensions in cisco_telemetry_mdt.
  - #6415: Allow graphite parser to create Inf and NaN values.
  - #6434: Use prefix base detection for ints in grok parser.
  - #6465: Add more performance counter metrics to sqlserver input.
  - #6476: Add millisecond unix time support to grok parser.
  - #6473: Add container id as optional source tag to docker and docker_log input.
  - #6504: Add lang parameter to OpenWeathermap input plugin.
  - #6540: Log file open errors at debug level in tail input.
  - #6553: Add timeout option to cloudwatch input.
  - #6549: Support custom success codes in http input.
  - #6530: Improve ipvs input error strings and logging.
  - #6532: Add strict mode to JSON parser that can be disable to ignore invalid items.
  - #6543: Add support for Kubernetes 1.16 and remove deprecated API usage.
  - #6283: Add gathering of RabbitMQ federation link metrics.
  - #6356: Add bearer token defaults for Kubernetes plugins.
  - #5870: Add support for SNMP over TCP.
  - #6603: Add support for per output flush jitter.
  - #6650: Add a nameable file tag to file input plugin.
  - #6640: Add Splunk MultiMetric support.
  - #6680: Add support for sending HTTP Basic Auth in influxdb input
  - #5767: Add ability to configure the url tag in the prometheus input.
  - #5767: Add prometheus metric_version=2 mapping to internal metrics/line protocol.
  - #6703: Add prometheus metric_version=2 support to prometheus_client output.
  - #6660: Add content_encoding compression support to socket_listener.
  - #6689: Add high resolution metrics support to CloudWatch output.
  - #6716: Add SReclaimable and SUnreclaim to mem input.
  - #6695: Allow multiple certificates per file in x509_cert input.
  - #6686: Add additional tags to the x509 input.
  - #6703: Add batch data format support to file output.
  - #6688: Support partition assignement strategy configuration in kafka_consumer.
  - #6731: Add node type tag to mongodb input.
  - #6669: Add uptime_ns field to mongodb input.
  - #6735: Support resolution of symlinks in filecount input.
  - #6746: Set message timestamp to the metric time in kafka output.
  - #6740: Add base64decode operation to string processor.
  - #6790: Add option to control collecting global variables to mysql input.
    Bugfixes
  - #6484: Show correct default settings in mysql sample config.
  - #6583: Use 1h or 3h rain values as appropriate in openweathermap input.
  - #6573: Fix not a valid field error in Windows with nvidia input.
  - #6614: Fix influxdb output serialization on connection closed.
  - #6690: Fix ping skips remaining hosts after dns lookup error.
  - #6684: Log mongodb oplog auth errors at debug level.
  - #6705: Remove trailing underscore trimming from json flattener.
  - #6421: Revert change causing cpu usage to be capped at 100 percent.
  - #6523: Accept any media type in the prometheus input.
  - #6769: Fix unix socket dial arguments in uwsgi input.
  - #6757: Replace colon chars in prometheus output labels with metric_version=1.
  - #6773: Set TrimLeadingSpace when TrimSpace is on in csv parser.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- split up patch 0001-Generic-SQL-output-plugin-for-Telegraf.patch
  (from https://github.com/influxdata/telegraf/pull/4205)
  into multiple patches:
  0001-plugins-outputs-all-all.go-Generic-SQL-output-plugin.patch
  0002-plugins-outputs-sql-README.md-Generic-SQL-output-plu.patch
  0003-plugins-outputs-sql-sql.go-Generic-SQL-output-plugin.patch
  0004-plugins-outputs-sql-sql_test.go-Generic-SQL-output-p.patch
  0005-README.md-Generic-SQL-output-plugin-for-Telegraf-pat.patch
* Wed Dec 18 2019 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to release 1.12.6
  Refs boo#1159288 SLES customer request for updated version
  * v1.12.6 [2019-11-19]
  * telegraf#6666: Fix many plugin errors are logged at debug logging level
  * telegraf#6652: Use nanosecond precision in docker_log input
  * telegraf#6642: Fix interface option with method = native in ping input
  * telegraf#6680: Fix panic in mongodb input if shard connection pool stats are unreadable (telegraf#6680)
  * v1.12.5 [2019-11-12]
  * telegraf#6576: Fix incorrect results in ping input plugin
  * telegraf#6610: Add missing character replacement to sql_instance tag
  * telegraf#6337: Change no metric error message to debug level in cloudwatch input
  * telegraf#6602: Add missing ServerProperties query to sqlserver input docs
  * telegraf#6643: Fix mongodb connections_total_created field loading
  * telegraf#6627: Fix metric creation when node is offline in jenkins input
  * telegraf#6649: Fix docker uptime_ns calculation when container has been restarted
  * telegraf#6647: Fix mysql field type conflict in conversion of gtid_mode to an integer
  * telegraf#5529: Fix mysql field type conflict with ssl_verify_depth and ssl_ctx_verify_depth
  * v1.12.4 [2019-10-23]
  * telegraf#6521: Fix metric generation with ping input native method
  * telegraf#6541: Exclude alias tag if unset from plugin internal stats
  * telegraf#6564: Fix socket_mode option in powerdns_recursor input
  * v1.12.3 [2019-10-07]
  * telegraf#6445: Use batch serialization format in exec output
  * telegraf#6464: Use case insensitive serial numer match in smart input
  * telegraf#6469: Add auth header only when env var is set
  * telegraf#6468: Fix running multiple mysql and sqlserver plugin instances
  * telegraf#6471: Fix database routing on retry with exclude_database_tag
  * telegraf#6488: Fix logging panic in exec input with nagios data format
  * v1.12.2 [2019-09-24]
  * telegraf#6386: Fix detection of layout timestamps in csv and json parser
  * telegraf#6394: Fix parsing of BATTDATE in apcupsd input
  * telegraf#6398: Keep boolean values listed in json_string_fields
  * telegraf#6393: Disable Go plugin support in official builds
  * telegraf#6391: Fix path handling issues in cisco_telemetry_gnmi
  * v1.12.1 [2019-09-10]
  * telegraf#6344: fix depends on glibc_2.14 symbol version
  * telegraf#6329: fix filecount for paths with trailing slash
  * telegraf#6331: convert check state to an integer in icinga2 input
  * telegraf#6354: fix could not mark message delivered error in kafka_consumer
  * telegraf#6362: skip collection stats when disabled in mongodb input
  * telegraf#6366: fix error reading closed response body on redirect in http_response
  * telegraf#6373: fix apcupsd documentation to reflect plugin
  * telegraf#6375: display retry log message only when retry after is received
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Trim future goals from description, it is not in the scope
  of openSUSE package descriptions.
* Mon Sep  9 2019 Stephan Kulow <coolo@suse.com>
- disable pie on power as it seems to cause problems on go
* Mon Sep  9 2019 Stephan Kulow <coolo@suse.com>
- Update to release 1.12
  Release Notes
  The cluster health related fields in the elasticsearch input have been split
  out from the elasticsearch_indices mesasurement into the new
  elasticsearch_cluster_health_indices measurement as they were originally
  combined by error.
  New Inputs
  apcupsd - Contributed by @jonaz
  docker_log - Contributed by @prashanthjbabu
  fireboard - Contributed by @ronnocol
  logstash - Contributed by @lkmcs @dmitryilyin @arkady-emelyanov
  marklogic - Contributed by @influxdata
  openntpd - Contributed by @aromeyer
  uwsgi - Contributed by @blaggacao
  New Parsers
  form_urlencoded - Contributed by @byonchev
  New Processors
  date - Contributed by @influxdata
  pivot - Contributed by @influxdata
  tag_limit - Contributed by @memory
  unpivot - Contributed by @influxdata
  New Outputs
  exec - Contributed by @Jaeyo
- Update to release 1.11
  Release Notes
  The uptime_format field in the system input has been deprecated, use the
  uptime field instead.
  The cloudwatch input has been updated to use a more efficient API, it now
  requires GetMetricData permissions instead of GetMetricStatistics. The
  units tag is not available from this API and is no longer collected.
  New Inputs
  bind - Contributed by @dswarbrick & @danielllek
  cisco_telemetry_gnmi - Contributed by @sbyx
  cisco_telemetry_mdt - Contributed by @sbyx
  ecs - Contributed by @rbtr
  github - Contributed by @influxdata
  openweathermap - Contributed by @regel
  powerdns_recursor - Contributed by @dupondje
  New Aggregators
  final - Contributed by @oplehto
  New Outputs
  syslog - Contributed by @javicrespo
  health - Contributed by @influxdata
  New Serializers
  wavefront - Contributed by @puckpuck
- Update to release 1.10
  New Inputs
  cloud_pubsub - Contributed by @emilymye
  cloud_pubsub_push - Contributed by @influxdata
  kinesis_consumer - Contributed by @influxdata
  kube_inventory - Contributed by @influxdata
  neptune_apex - Contributed by @MaxRenaud
  nginx_upstream_check - Contributed by @dmitryilyin
  multifile - Contributed by @martin2250
  stackdriver - Contributed by @WuHan0608
  New Outputs
  cloud_pubsub - Contributed by @emilymye
  New Serializers
  nowmetric - Contributed by @JefMuller
  carbon2 - Contributed by @frankreno
- Update to release 1.9
  Release Notes
  The http_listener input plugin has been renamed to influxdb_listener and
  use of the original name is deprecated. The new name better describes the
  intended use of the plugin as a InfluxDB relay. For general purpose
  transfer of metrics in any format via HTTP, it is recommended to use
  http_listener_v2 instead.
  Input plugins are no longer limited from adding metrics when the output is
  writing, and new metrics will move into the metric buffer as needed. This
  will provide more robust degradation and recovery when writing to a slow
  output at high throughput.
  To avoid over consumption when reading from queue consumers: kafka_consumer,
  amqp_consumer, mqtt_consumer, nats_consumer, and nsq_consumer use
  the new option max_undelivered_messages to limit the number of outstanding
  unwritten metrics.
  New Inputs
  http_listener_v2 - Contributed by @jul1u5
  ipvs - Contributed by @amoghe
  jenkins - Contributed by @influxdata & @lpic10
  nginx_plus_api - Contributed by @Bugagazavr
  nginx_vts - Contributed by @monder
  wireless - Contributed by @jamesmaidment
  New Outputs
  stackdriver - Contributed by @jamesmaidment
* Wed Mar 27 2019 Jan Engelhardt <jengelh@inai.de>
- Add systemd-rpm-macros and %%systemd_ordering for %%service_*.
* Wed Mar 27 2019 Stephan Kulow <coolo@suse.com>
- Remove consul/website from the deps - their license is fishy
  and we don't need it to build telegraf
* Thu Nov 15 2018 <nsinger@suse.com>
- Enable PIE for build
- Include systemd service file from upstream
- Drop feature_passive_amqp_exchange.patch
  * Changelog entry tracking dropped patch retroactively added
    by Jeff Kowalczyk <jkowalczyk@suse.com> contemporaneous to
    OBS change devel:languages:go/telegraf r7
- Add 0001-Generic-SQL-output-plugin-for-Telegraf.patch
  * Plugin inserts metric values to databases: mssql, mysql, postgres
  * Changelog entry tracking carried patch retroactively added
    by Jeff Kowalczyk <jkowalczyk@suse.com> contemporaneous to
    OBS change devel:languages:go/telegraf r7
* Thu Nov  1 2018 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to release 1.8.3
  - Update deps package
  * v1.8.3 [2018-10-30]
    [#4873]: Add DN attributes as tags in x509_cert input to avoid series overwrite.
    [#4921]: Prevent connection leak by closing unused connections in amqp output.
    [#4904]: Use default partition key when tag does not exist in kinesis output.
    [#4901]: Log the correct error in jti_openconfig.
    [#4937]: Handle panic when ipmi_sensor input gets bad input.
    [#4930]: Don't add unserializable fields to jolokia2 input.
    [#4866]: Fix version check in postgresql_extensible.
  * v1.8.2 [2018-10-17]
  - Bugfixes
    [#4844]: Update write path to match updated InfluxDB v2 API.
    [#4840]: Fix missing timeouts in vsphere input.
    [#4851]: Support uint fields in aerospike input.
    [#4854]: Use container name from list if no name in container stats.
    [#4850]: Prevent panic in filecount input on error in file stat.
    [#4846]: Fix mqtt_consumer connect and reconnect.
    [#4849]: Fix panic in logparser input.
    [#4869]: Lower authorization errors to debug level in mongodb input.
    [#4875]: Return correct response code on ping input.
    [#4874]: Fix segfault in x509_cert input.
  * v1.8.1 [2018-10-03]
  - Bugfixes
    [#4750]: Fix hardware_type may be truncated in sqlserver input.
    [#4723]: Improve performance in basicstats aggregator.
    [#4747]: Add hostname to TLS config for SNI support.
    [#4675]: Don't add tags with empty values to opentsdb output.
    [#4765]: Fix panic during network error in vsphere input.
    [#4766]: Unify http_listener error response with InfluxDB.
    [#4769]: Add UUID to VMs in vSphere input.
    [#4758]: Skip tags with empty values in cloudwatch output.
    [#4783]: Fix missing non-realtime samples in vSphere input.
    [#4799]: Fix case of timezone/grok_timezone options.
  * v1.8 [2018-09-21]
  - New Inputs
    activemq - Contributed by @mlabouardy
    beanstalkd - Contributed by @44px
    filecount - Contributed by @sometimesfood
    file - Contributed by @maxunt
    icinga2 - Contributed by @mlabouardy
    kibana - Contributed by @lpic10
    pgbouncer - Contributed by @nerzhul
    temp - Contributed by @pytimer
    tengine - Contributed by @ertaoxu
    vsphere - Contributed by @prydin
    x509_cert - Contributed by @jtyr
  - New Processors
    enum - Contributed by @KarstenSchnitter
    parser - Contributed by @Ayrdrie & @maxunt
    rename - Contributed by @goldibex
    strings - Contributed by @bsmaldon
  - New Aggregators
    valuecounter - Contributed by @piotr1212
  - New Outputs
    azure_monitor - Contributed by @influxdata
    influxdb_v2 - Contributed by @influxdata
  - New Parsers
    csv - Contributed by @maxunt
    grok - Contributed by @maxunt
    logfmt - Contributed by @Ayrdrie & @maxunt
    wavefront - Contributed by @puckpuck
  - New Serializers
    splunkmetric - Contributed by @ronnocol
  - Features
    [#4236]: Add SSL/TLS support to redis input.
    [#4160]: Add tengine input plugin.
    [#4262]: Add power draw field to nvidia_smi plugin.
    [#4271]: Add support for solr 7 to the solr input.
    [#4281]: Add owner tag on partitions in burrow input.
    [#4259]: Add container status tag to docker input.
    [#3523]: Add valuecounter aggregator plugin.
    [#4307]: Add new measurement with results of pgrep lookup to procstat input.
    [#4311]: Add support for comma in logparser timestamp format.
    [#4292]: Add path tag to tail input plugin.
    [#4322]: Add log message when tail is added or removed from a file.
    [#4267]: Add option to use of counter time in win perf counters.
    [#4343]: Add energy and power field and device id tag to fibaro input.
    [#4347]: Add http path configuration for OpenTSDB output.
    [#4352]: Gather IPMI metrics concurrently.
    [#4362]: Add mongo document and connection metrics.
    [#3772]: Add enum processor plugin.
    [#4386]: Add user tag to procstat input.
    [#4403]: Add support for multivalue metrics to collectd parser.
    [#4418]: Add support for setting kafka client id.
    [#4332]: Add file input plugin and grok parser.
    [#4320]: Improve cloudwatch output performance.
    [#3768]: Add x509_cert input plugin.
    [#4471]: Add IPSIpAddress syntax to ipaddr conversion in snmp plugin.
    [#4363]: Add filecount input plugin.
    [#4485]: Add support for configuring an AWS endpoint_url.
    [#4491]: Send all messages before waiting for results in kafka output.
    [#4492]: Add support for lz4 compression to kafka output.
    [#4450]: Split multiple sensor keys in ipmi input.
    [#4364]: Support StatisticValues in cloudwatch output plugin.
    [#4431]: Add ip restriction for the prometheus_client output.
    [#3918]: Add pgbouncer input plugin.
    [#2689]: Add ActiveMQ input plugin.
    [#4402]: Add wavefront parser plugin.
    [#4528]: Add rename processor plugin.
    [#4537]: Add message 'max_bytes' configuration to kafka input.
    [#4546]: Add gopsutil meminfo fields to mem plugin.
    [#4285]: Document how to parse telegraf logs.
    [#4542]: Use dep v0.5.0.
    [#4433]: Add ability to set measurement from matched text in grok parser.
    [#4565]: Drop message batches in kafka output if too large.
    [#4579]: Add support for static and random routing keys in kafka output.
    [#4539]: Add logfmt parser plugin.
    [#4551]: Add parser processor plugin.
    [#4559]: Add Icinga2 input plugin.
    [#4351]: Add name, time, path and string field options to JSON parser.
    [#4571]: Add forwarded records to sqlserver input.
    [#4585]: Add Kibana input plugin.
    [#4439]: Add csv parser plugin.
    [#4598]: Add read_buffer_size option to statsd input.
    [#4089]: Add azure_monitor output plugin.
    [#4628]: Add queue_durability parameter to amqp_consumer input.
    [#4476]: Add strings processor.
    [#4536]: Add OAuth2 support to HTTP output plugin.
    [#4633]: Add Unix epoch timestamp support for JSON parser.
    [#4657]: Add options for basic auth to haproxy input.
    [#4411]: Add temp input plugin.
    [#4272]: Add Beanstalkd input plugin.
    [#4669]: Add means to specify server password for redis input.
    [#4339]: Add Splunk Metrics serializer.
    [#4141]: Add input plugin for VMware vSphere.
    [#4667]: Align metrics window to interval in cloudwatch input.
    [#4642]: Improve Azure Managed Instance support + more in sqlserver input.
    [#4682]: Allow alternate binaries for iptables input plugin.
    [#4645]: Add influxdb_v2 output plugin.
  - Bugfixes
    [#3438]: Fix divide by zero in logparser input.
    [#4499]: Fix instance and object name in performance counters with backslashes.
    [#4646]: Reset/flush saved contents from bad metric.
    [#4520]: Document all supported cli arguments.
    [#4674]: Log access denied opening a service at debug level in win_services.
    [#4588]: Add support for Kafka 2.0.
    [#4087]: Fix nagios parser does not support ranges in performance data.
    [#4088]: Fix nagios parser does not strip quotes from performance data.
    [#4688]: Fix null value crash in postgresql_extensible input.
    [#4681]: Remove the startup authentication check from the cloudwatch output.
    [#4644]: Support tailing files created after startup in tail input.
    [#4706]: Fix csv format configuration loading.
* Tue Sep 18 2018 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to release 1.7.4
  - Update deps package
  * v1.7.4 [2018-08-29]
  - Bugfixes
    [#4534]: Skip unserializable metric in influxDB UDP output.
    [#4554]: Fix powerdns input tests.
    [#4584]: Fix burrow_group offset calculation for burrow input.
    [#4550]: Add result_code value for errors running ping command.
    [#4605]: Remove timeout deadline for udp syslog input.
    [#4601]: Ensure channel closed if an error occurs in cgroup input.
    [#4544]: Fix sending of basic auth credentials in http output.
    [#4526]: Use the correct GOARM value in the armel package.
  * v1.7.3 [2018-08-07]
  - Bugfixes
    [#4434]: Reduce required docker API version.
    [#4498]: Keep leading whitespace for messages in syslog input.
    [#4470]: Skip bad entries on interrupt input.
    [#4501]: Preserve metric type when using filters in output plugins.
    [#3794]: Fix error message if URL is unparseable in influxdb output.
    [#4059]: Use explicit zpool properties to fix parse error on FreeBSD 11.2.
    [#4514]: Lock buffer when adding metrics.
  * v1.7.2 [2018-07-18]
  - Bugfixes
    [#4381]: Use localhost as default server tag in zookeeper input.
    [#4374]: Don't set values when pattern doesn't match in regex processor.
    [#4416]: Fix output format of printer processor.
    [#4422]: Fix metric can have duplicate field.
    [#4389]: Return error if NewRequest fails in http output.
    [#4335]: Reset read deadline for syslog input.
    [#4375]: Exclude cached memory on docker input plugin.
  * v1.7.1 [2018-07-03]
  - Bugfixes
    [#4277]: Treat sigterm as a clean shutdown signal.
    [#4284]: Fix selection of tags under nested objects in the JSON parser.
    [#4135]: Fix postfix input handling multi-level queues.
    [#4334]: Fix syslog timestamp parsing with single digit day of month.
    [#2910]: Handle mysql input variations in the user_statistics collecting.
    [#4293]: Fix minmax and basicstats aggregators to use uint64.
    [#4290]: Document swap input plugin.
    [#4316]: Fix incorrect precision being applied to metric in http_listener.
  * v1.7 [2018-06-12]
  - Release Notes
    The cassandra input plugin has been deprecated in favor of the jolokia2
    input plugin which is much more configurable and more performant.
    There is an example configuration to help you get started.
    For plugins supporting TLS, you can now specify the certificate and keys
    using tls_ca, tls_cert, tls_key. These options behave the same as the,
    now deprecated, ssl forms.
  - New Inputs
    aurora - Contributed by @influxdata
    burrow - Contributed by @arkady-emelyanov
    fibaro - Contributed by @dynek
    jti_openconfig_telemetry - Contributed by @ajhai
    mcrouter - Contributed by @cthayer
    nvidia_smi - Contributed by @jackzampolin
    syslog - Contributed by @influxdata
  - New Processors
    converter - Contributed by @influxdata
    regex - Contributed by @44px
    topk - Contributed by @mirath
  - New Outputs
    http - Contributed by @Dark0096
    application_insights: Contribute by @karolz-ms
  - Features
    [#3964]: Add repl_oplog_window_sec metric to mongodb input.
    [#3819]: Add per-host shard metrics in mongodb input.
    [#3999]: Skip files with leading .. in config directory.
    [#4021]: Add TLS support to socket_writer and socket_listener plugins.
    [#4025]: Add snmp input option to strip non fixed length index suffixes.
    [#4035]: Add server version tag to docker input.
    [#4044]: Add support for LeoFS 1.4 to leofs input.
    [#4068]: Add parameter to force the interval of gather for sysstat.
    [#3877]: Support busybox ping in the ping input.
    [#4077]: Add input plugin for McRouter.
    [#4096]: Add topk processor plugin.
    [#4114]: Add cursor metrics to mongodb input.
    [#3455]: Add tag/integer pair for result to net_response.
    [#4010]: Add application_insights output plugin.
    [#4167]: Added several important elasticsearch cluster health metrics.
    [#4094]: Add batch mode to mqtt output.
    [#4158]: Add aurora input plugin.
    [#3839]: Add regex processor plugin.
    [#4165]: Add support for Graphite 1.1 tags.
    [#4162]: Add timeout option to sensors input.
    [#3489]: Add burrow input plugin.
    [#3969]: Add option to unbound module to use threads as tags.
    [#4183]: Add support for TLS and username/password auth to aerospike input.
    [#4190]: Add special syslog timestamp parser to grok parser that uses current year.
    [#4181]: Add syslog input plugin.
    [#4212]: Print the enabled aggregator and processor plugins on startup.
    [#3994]: Add static routing_key option to amqp output.
    [#3995]: Add passive mode exchange declaration option to amqp consumer input.
    [#4216]: Add counter fields to pf input.
  - Bugfixes
    [#4018]: Write to working file outputs if any files are not writeable.
    [#4036]: Add all win_perf_counters fields for a series in a single metric.
    [#4118]: Report results of dns_query instead of 0ms on timeout.
    [#4155]: Add consul service tags to metric.
    [#2879]: Fix wildcards and multi instance processes in win_perf_counters.
    [#2468]: Fix crash on 32-bit Windows in win_perf_counters.
    [#4198]: Fix win_perf_counters not collecting at every interval.
    [#4227]: Use same flags for all BSD family ping variants.
    [#4266]: Remove tags with empty values from Wavefront output.
  * v1.6.4 [2018-06-05]
  - Bugfixes
    [#4203]: Fix snmp overriding of auto-configured table fields.
    [#4218]: Fix uint support in cloudwatch output.
    [#4188]: Fix documentation of instance_name option in varnish input.
    [#4195]: Revert to previous aerospike library version due to memory leak.
* Sun May 27 2018 tuukka.pasanen@ilmi.fi
- Update to release 1.6.0
  - Update deps package
  * v1.6.3 [2018-05-21]
  - Bugfixes
    [#4127]: Fix intermittent panic in aerospike input.
    [#4130]: Fix connection leak in jolokia2_agent.
    [#4136]: Fix jolokia2 timeout parsing.
    [#4142]: Fix error parsing dropwizard metrics.
    [#4149]: Fix librato output support for uint and bool.
    [#4176]: Fix waitgroup deadlock if url is incorrect in apache input.
  * v1.6.2 [2018-05-08]
  - Bugfixes
    [#4078]: Use same timestamp for fields in system input.
    [#4091]: Fix handling of uint64 in datadog output.
    [#4099]: Ignore UTF8 BOM in JSON parser.
    [#4104]: Fix case for slave metrics in mysql input.
    [#4110]: Fix uint support in cratedb output.
  * v1.6.1 [2018-04-23]
  - Bugfixes
    [#3835]: Report mem input fields as gauges instead counters.
    [#4030]: Fix graphite outputs unsigned integers in wrong format.
    [#4043]: Report available fields if utmp is unreadable.
    [#4039]: Fix potential "no fields" error writing to outputs.
    [#4037]: Fix uptime reporting in system input when ran inside docker.
    [#3750]: Fix mem input "cannot allocate memory" error on FreeBSD based systems.
    [#4056]: Fix duplicate tags when overriding an existing tag.
    [#4062]: Add server argument as first argument in unbound input.
    [#4063]: Fix handling of floats with multiple leading zeroes.
    [#4064]: Return errors in mongodb SSL/TLS configuration.
* Tue Apr 24 2018 mschnitzer@suse.com
- Fix dependency package: The dependency package contained the
  telegraf source code which has overwritten the patched files.
* Wed Apr 18 2018 mschnitzer@suse.com
- Release 1.6.0
  * Release Notes
  - The mysql input plugin has been updated fix a number of type convertion issues. This may cause a field type error when inserting
    into InfluxDB due the change of types.
  - To address this we have introduced a new metric_version option to control enabling the new format. For in depth recommendations on
    upgrading please reference the mysql plugin documentation.
  - It is encouraged to migrate to the new model when possible as the old version is deprecated and will be removed in a future version.
  - The postgresql plugins now defaults to using a persistent connection to the database. In environments where TCP connections are
    terminated the max_lifetime setting should be set less than the collection interval to prevent errors.
  - The sqlserver input plugin has a new query and data model that can be enabled by setting query_version = 2. It is encouraged to
    migrate to the new model when possible as the old version is deprecated and will be removed in a future version.
  - An option has been added to the openldap input plugin that reverses metric name to improve grouping. This change is enabled
    when reverse_metric_names = true is set. It is encouraged to enable this option when possible as the old ordering is deprecated.
  - The new http input configured with data_format = "json" can perform the same task as the, now deprecated, httpjson input.
  * New Inputs
    http - Thanks to @grange74
    ipset - Thanks to @sajoupa
    nats - Thanks to @mjs & @levex
  * New Processors
    override - Thanks to @KarstenSchnitter
  * New Parsers
    dropwizard - Thanks to @atzoum
  * Features
    [#3551]: Add health status mapping from string to int in elasticsearch input.
    [#3580]: Add control over which stats to gather in basicstats aggregator.
    [#3596]: Add messages_delivered_get to rabbitmq input.
    [#3632]: Add wired field to mem input.
    [#3619]: Add support for gathering exchange metrics to the rabbitmq input.
    [#3565]: Add support for additional metrics on Linux in zfs input.
    [#3524]: Add available_entropy field to kernel input plugin.
    [#3643]: Add user privilege level setting to IPMI sensors.
    [#2701]: Use persistent connection to postgresql database.
    [#2846]: Add support for dropwizard input format.
    [#3666]: Add container health metrics to docker input.
    [#3687]: Add support for using globs in devices list of diskio input plugin.
    [#2754]: Allow running as console application on Windows.
    [#3703]: Add listener counts and node running status to rabbitmq input.
    [#3674]: Add NATS Monitoring Input Plugin.
    [#3702]: Add ability to select which queues will be gathered in rabbitmq input.
    [#3726]: Add support for setting bsd source address to the ping input.
    [#3346]: Add Ipset input plugin.
    [#3719]: Add TLS and HTTP basic auth to prometheus_client output.
    [#3618]: Add new sqlserver output data model.
    [#3559]: Add native Go method for finding pids to procstat.
    [#3722]: Add additional metrics and reverse metric names option to openldap.
    [#3769]: Add TLS support to the mesos input plugin.
    [#3546]: Add http input plugin.
    [#3781]: Add keep alive support to the TCP mode of statsd.
    [#3783]: Support deadline in ping plugin.
    [#3765]: Add option to disable labels in prometheus output for string fields.
    [#3808]: Add shard server stats to the mongodb input plugin.
    [#3713]: Add server option to unbound plugin.
    [#3804]: Convert boolean metric values to float in datadog output.
    [#3799]: Add Solr 3 compatibility.
    [#3797]: Add sum stat to basicstats aggregator.
    [#3626]: Add ability to override proxy from environment in http response.
    [#3853]: Add host to ping timeout log message.
    [#3773]: Add override processor.
    [#3814]: Add status_code and result tags and result_type field to http_response input.
    [#3880]: Added config flag to skip collection of network protocol metrics.
    [#3927]: Add TLS support to kapacitor input.
    [#3496]: Add HTTP basic auth support to the http_listener input.
    [#3452]: Tags in output InfluxDB Line Protocol are now sorted.
    [#3631]: InfluxDB Line Protocol parser now accepts DOS line endings.
    [#2496]: An option has been added to skip database creation in the InfluxDB output.
    [#3366]: Add support for connecting to InfluxDB over a unix domain socket.
    [#3946]: Add optional unsigned integer support to the influx data format.
    [#3811]: Add TLS support to zookeeper input.
    [#2737]: Add filters for container state to docker input.
  * Bugfixes
    [#1896]: Fix various mysql data type conversions.
    [#3810]: Fix metric buffer limit in internal plugin after reload.
    [#3801]: Fix panic in http_response on invalid regex.
    [#3973]: Fix socket_listener setting ReadBufferSize on tcp sockets.
    [#1575]: Add tag for target url to phpfpm input.
    [#3868]: Fix cannot unmarshal object error in DC/OS input.
    [#3648]: Fix InfluxDB output not able to reconnect when server address changes.
    [#3957]: Fix parsing of dos line endings in the smart input.
    [#3754]: Fix precision truncation when no timestamp included.
    [#3655]: Fix SNMPv3 connection with Cisco ASA 5515 in snmp input.
    [#3981]: Export all vars defined in /etc/default/telegraf.
    [#4004]: Allow grok pattern to contain newlines.
* Fri Mar 23 2018 mschnitzer@suse.com
- Release 1.5.3
  * Bugfixes
    [#3729]: Set path to / if HOST_MOUNT_PREFIX matches full path.
    [#3739]: Remove userinfo from url tag in prometheus input.
    [#3778]: Fix ping plugin not reporting zero durations.
    [#3807]: Fix memory leak in postgresql_extensible.
    [#3697]: Disable keepalive in mqtt output to prevent deadlock.
    [#3786]: Fix collation difference in sqlserver input.
    [#3871]: Fix uptime metric in passenger input plugin.
    [#3851]: Add output of stderr in case of error to exec log message.
* Mon Feb 12 2018 mschnitzer@suse.com
- Add feature_passive_amqp_exchange.patch:
  * This patch allows to enable the exchange passive mode for the
    AMQP consumer plugin. This is required for RabbitMQ servers
  that rely on that (like the openSUSE ones)
  * Upstream pull request is not possible because it requires you
    to sign a CLA, but it's requested here:
  https://github.com/influxdata/telegraf/issues/3785
* Thu Feb  8 2018 mschnitzer@suse.com
- Release 1.5.2
  * Bugfixes
    [#3684]: Ignore empty lines in Graphite plaintext.
    [#3604]: Fix index out of bounds error in solr input plugin.
    [#3680]: Reconnect before sending graphite metrics if disconnected.
    [#3693]: Align aggregator period with internal ticker to avoid skipping metrics.
    [#3629]: Fix a potential deadlock when using aggregators.
    [#3697]: Limit wait time for writes in mqtt output.
    [#3698]: Revert change in graphite output where dot in field key was replaced by underscore.
    [#3710]: Add timeout to wavefront output write.
    [#3725]: Exclude master_replid fields from redis input.
